@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -45,7 +43,6 @@
 #include <string.h>
 #include <lber.h>
 #include <ldap.h>
-#include <iconv.h>
 
 #ifdef HAVE_CYRUS_SASL
 #include <sasl.h>
@@ -399,7 +396,7 @@ libbalsa_address_book_ldap_load(LibBalsaAddressBook * ab,
          * we use the asynchronous lookup to fetch the results in chunks
          * in case we exceed administrative limits.
          */ 
-        /* g_print("Performing full lookup...\n"); */
+        /* g_print("Performing full lookup…\n"); */
         ldap_filter = filter 
             ? g_strdup_printf("(&(objectClass=organizationalPerson)(mail=*)"
                               "(|(cn=%s*)(sn=%s*)(mail=%s*@*)))",
@@ -661,7 +658,7 @@ libbalsa_address_book_ldap_add_address(LibBalsaAddressBook *ab,
 	}
         /* fall through */
         default:
-            fprintf(stderr, "ldap_add for dn=\"%s\" failed[0x%x]: %s\n",
+            fprintf(stderr, "ldap_add for dn=“%s” failed[0x%x]: %s\n",
                     dn, rc, ldap_err2string(rc));
         }
     } while(cnt++<1);
@@ -704,7 +701,7 @@ libbalsa_address_book_ldap_remove_address(LibBalsaAddressBook *ab,
 	    }
             /* fall through */
         default:
-            fprintf(stderr, "ldap_delete for dn=\"%s\" failed[0x%x]: %s\n",
+            fprintf(stderr, "ldap_delete for dn=“%s” failed[0x%x]: %s\n",
                     dn, rc, ldap_err2string(rc));
         }
     } while(cnt++<1);
@@ -816,7 +813,7 @@ libbalsa_address_book_ldap_modify_address(LibBalsaAddressBook *ab,
 	    }
             /* fall through */
         default:
-            fprintf(stderr, "ldap_modify for dn=\2%s\" failed[0x%x]: %s\n",
+            fprintf(stderr, "ldap_modify for dn=“%s” failed[0x%x]: %s\n",
                     dn, rc, ldap_err2string(rc));
         }
     } while(cnt++<1);
