@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -440,7 +438,7 @@ lbab_text_open_temp(LibBalsaAddressBookText * ab_text, gchar ** path,
     *stream = fopen(*path, "w");
     if (*stream == NULL) {
 #if DEBUG
-        g_message("Failed to open temporary address book file \"%s\"\n"
+        g_message("Failed to open temporary address book file “%s”\n"
                   " changes not saved", *path);
 #endif                          /* DEBUG */
         g_free(*path);
@@ -457,8 +455,8 @@ lbab_text_close_temp(LibBalsaAddressBookText * ab_text, const gchar * path)
     if (unlink(ab_text->path) < 0
         && g_file_error_from_errno(errno) != G_FILE_ERROR_NOENT) {
 #if DEBUG
-        g_message("Failed to unlink address book file \"%s\"\n"
-                  " new address book file saved as \"%s\"", ab_text->path,
+        g_message("Failed to unlink address book file “%s”\n"
+                  " new address book file saved as “%s”", ab_text->path,
                   path);
         perror("TEXT");
 #endif                          /* DEBUG */
@@ -467,7 +465,7 @@ lbab_text_close_temp(LibBalsaAddressBookText * ab_text, const gchar * path)
 
     if (rename(path, ab_text->path) < 0) {
 #if DEBUG
-        g_message("Failed to rename temporary address book file \"%s\"\n",
+        g_message("Failed to rename temporary address book file “%s”\n",
                   path);
 #endif                          /* DEBUG */
         return LBABERR_CANNOT_WRITE;
@@ -661,7 +659,7 @@ libbalsa_address_book_text_modify_address(LibBalsaAddressBook * ab,
         res = lbab_text_close_temp(ab_text, path);
 #if DEBUG
     else
-        g_message("Failed to write to temporary address book file \"%s\"\n"
+        g_message("Failed to write to temporary address book file “%s”\n"
                   " changes not saved", path);
 #endif                          /* DEBUG */
     g_free(path);
