@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -160,11 +158,9 @@ enum LibBalsaAddressViewMatchType_ {
 /* Must be consistent with LibBalsaAddressType enum: */
 const gchar *const libbalsa_address_view_types[] = {
     N_("To:"),
-    N_("Cc:"),
-    N_("Bcc:"),
-#if !defined(ENABLE_TOUCH_UI)
+    N_("CC:"),
+    N_("BCC:"),
     N_("Reply To:"),
-#endif                          /* ENABLE_TOUCH_UI */
 };
 
 /* Pixbufs */
