@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -366,8 +364,13 @@ libbalsa_message_body_save_temporary(LibBalsaMessageBody * body, GError **err)
                             LIBBALSA_MAILBOX_TEMPDIR_ERROR,
                             "Failed to create temporary directory");
             } else {
+                gchar *basename;
+
+                basename = g_path_get_basename(filename);
                 body->temp_filename =
-                    g_build_filename(tempdir, filename, NULL);
+                    g_build_filename(tempdir, basename, NULL);
+                g_free(basename);
+
                 fd = open(body->temp_filename,
                           O_WRONLY | O_EXCL | O_CREAT,
                           S_IRUSR);
