@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /*  GMime GIO stream module
- *  Written/Copyright (c) by Albrecht Dre <albrecht.dress@arcor.de>
+ *  Written/Copyright (c) by Albrecht Dreß <albrecht.dress@arcor.de>
  *  The basic structure of this file has been shamelessly stolen from the
  *  gmime-stream-fs module, written by Jeffrey Stedfast.
  *
@@ -51,11 +51,7 @@ static gint64 stream_seek(GMimeStream *stream,
 			  gint64 offset,
 			  GMimeSeekWhence whence);
 static gint64 stream_tell(GMimeStream *stream);
-#if defined(HAVE_GMIME_2_6)
 static gint64 stream_length(GMimeStream *stream);
-#else                           /* HAVE_GMIME_2_6 */
-static ssize_t stream_length(GMimeStream *stream);
-#endif                          /* HAVE_GMIME_2_6 */
 static GMimeStream *stream_substream(GMimeStream *stream,
 				     gint64 start,
 				     gint64 end);
@@ -383,11 +379,7 @@ stream_tell (GMimeStream *stream)
     return stream->position;
 }
 
-#if defined(HAVE_GMIME_2_6)
 static gint64
-#else                           /* HAVE_GMIME_2_6 */
-static ssize_t
-#endif                          /* HAVE_GMIME_2_6 */
 stream_length(GMimeStream *stream)
 {
     goffset bound_end;
