@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -79,6 +77,57 @@ lbh_get_body_content(LibBalsaMessageBody * body, gchar ** buf)
 }
 
 # if defined(HAVE_WEBKIT)
+
+#ifdef HTML2TEXT
+
+/* common function for all Webkit versions */
+static void
+html2text(gchar ** text, gsize len)
+{
+    gchar *html2text[] = { HTML2TEXT, NULL, NULL };
+    GFile *html_data;
+    GFileIOStream *stream;
+    GError *err = NULL;
+
+    html_data = g_file_new_tmp("balsa-conv-XXXXXX.html", &stream, &err);
+    if (html_data != NULL) {
+        gsize bytes_written;
+        GOutputStream *ostream =
+            g_io_stream_get_output_stream(G_IO_STREAM(stream));
+
+        if (g_output_stream_write_all(ostream, *text, len,
+                                      &bytes_written, NULL, &err)) {
+            gchar *result = NULL;
+
+            g_output_stream_flush(ostream, NULL, NULL);
+            html2text[1] = g_file_get_path(html_data);
+            if (g_spawn_sync(NULL, html2text, NULL,
+                             G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL,
+                             &result, NULL, NULL, &err)) {
+                g_free(*text);
+                *text = result;
+            }
+            g_free(html2text[1]);
+        }
+        g_output_stream_close(ostream, NULL, NULL);
+        g_object_unref(G_OBJECT(stream));
+        g_file_delete(html_data, NULL, NULL);
+        g_object_unref(G_OBJECT(html_data));
+    }
+    if (err != NULL) {
+        libbalsa_information(LIBBALSA_INFORMATION_ERROR,
+                             _("Could not convert HTML part to text: %s"),
+                             err ? err->message : "Unknown error");
+        g_error_free(err);
+    }
+}
+
+#else
+
+#define html2text(p, l)
+
+#endif
+
 #  if defined(USE_WEBKIT2)
 
 /*
@@ -207,33 +256,34 @@ static void
 lbh_navigation_policy_decision(WebKitPolicyDecision * decision,
                                gpointer               data)
 {
+    LibBalsaWebKitInfo *info = data;
     WebKitNavigationPolicyDecision *navigation_decision;
     WebKitNavigationAction *navigation_action;
-    LibBalsaWebKitInfo *info = data;
+    WebKitNavigationType navigation_type;
     WebKitURIRequest *request;
+    const gchar *uri;
 
     navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION(decision);
     navigation_action =
-         webkit_navigation_policy_decision_get_navigation_action
-            (navigation_decision);
-    switch (webkit_navigation_action_get_navigation_type
-            (navigation_action)) {
+        webkit_navigation_policy_decision_get_navigation_action
+        (navigation_decision);
+    navigation_type =
+        webkit_navigation_action_get_navigation_type(navigation_action);
+    request = webkit_navigation_action_get_request(navigation_action);
+    uri = webkit_uri_request_get_uri(request);
+
+    switch (navigation_type) {
     case WEBKIT_NAVIGATION_TYPE_OTHER:
     case WEBKIT_NAVIGATION_TYPE_RELOAD:
-        d(g_print("%s type %d, used\n", __func__,
-                  webkit_navigation_action_get_navigation_type
-                  (navigation_action)));
+        d(g_print("%s uri %s, type %d, used\n", __func__, uri,
+                  navigation_type));
         webkit_policy_decision_use(decision);
         break;
     case WEBKIT_NAVIGATION_TYPE_LINK_CLICKED:
-        request = webkit_navigation_action_get_request(navigation_action);
-        d(g_print("%s clicked %s\n", __func__,
-                  webkit_uri_request_get_uri(request)));
-        (*info->clicked_cb) (webkit_uri_request_get_uri(request));
+        d(g_print("%s clicked %s\n", __func__, uri));
+        (*info->clicked_cb) (uri);
     default:
-        d(g_print("%s type %d, ignored\n", __func__,
-                  webkit_navigation_action_get_navigation_type
-                  (navigation_action)));
+        d(g_print("%s type %d, ignored\n", __func__, navigation_type));
         webkit_policy_decision_ignore(decision);
     }
 }
@@ -392,25 +442,48 @@ lbh_info_bar(LibBalsaWebKitInfo * info)
 /*
  * Callback for the "resource-load-started" signal
  */
+static void
+lbh_resource_notify_response_cb(WebKitWebResource * resource,
+                                GParamSpec        * pspec,
+                                gpointer            data)
+{
+    LibBalsaWebKitInfo *info = data;
+    const gchar *mime_type;
+    WebKitURIResponse *response;
+
+    response = webkit_web_resource_get_response(resource);
+    mime_type = webkit_uri_response_get_mime_type(response);
+    d(g_print("%s mime-type %s\n", __func__, mime_type));
+    if (g_ascii_strncasecmp(mime_type, "image/", 6) != 0)
+        return;
+
+    if (info->info_bar) {
+        d(g_print("%s %s destroy info_bar\n", __func__,
+                  webkit_web_resource_get_uri(resource)));
+        /* web_view is loading an image from its cache, so we do not
+         * need to ask the user for permission to download */
+        gtk_widget_destroy(info->info_bar);
+        info->info_bar = NULL;
+    } else {
+        d(g_print("%s %s null info_bar\n", __func__,
+                  webkit_web_resource_get_uri(resource)));
+    }
+}
+
 static void
 lbh_resource_load_started_cb(WebKitWebView     * web_view,
                              WebKitWebResource * resource,
                              WebKitURIRequest  * request,
                              gpointer            data)
 {
-    LibBalsaWebKitInfo *info = data;
     const gchar *uri;
 
     uri = webkit_uri_request_get_uri(request);
     if (!g_ascii_strcasecmp(uri, "about:blank"))
         return;
 
-    if (info->info_bar) {
-        /* web_view is loading an image from its cache, so we do not
-         * need to ask the user for permission to download */
-        gtk_widget_destroy(info->info_bar);
-        info->info_bar = NULL;
-    }
+    g_signal_connect(resource, "notify::response",
+                     G_CALLBACK(lbh_resource_notify_response_cb), data);
 }
 
 /*
@@ -543,6 +616,7 @@ libbalsa_html_new(LibBalsaMessageBody * body,
         webkit_web_context_register_uri_scheme(context, "cid", lbh_cid_cb,
                                                &info, NULL);
         have_registered_cid = TRUE;
+        d(g_print("%s registered cid: scheme\n", __func__));
     }
 
     settings = webkit_web_view_get_settings(web_view);
@@ -570,6 +644,7 @@ libbalsa_html_new(LibBalsaMessageBody * body,
     if (g_regex_match_simple(src_regex, text, G_REGEX_CASELESS, 0)) {
         info->info_bar = lbh_info_bar(info);
         gtk_box_pack_start(GTK_BOX(vbox), info->info_bar, FALSE, FALSE, 0);
+        d(g_print("%s shows info_bar\n", __func__));
     }
 
     webkit_web_view_load_html(web_view, text, NULL);
@@ -581,9 +656,8 @@ libbalsa_html_new(LibBalsaMessageBody * body,
 void
 libbalsa_html_to_string(gchar ** text, size_t len)
 {
-    return; /* this widget does not support conversion to a string. The
-             * string won't be altered. Other alternative would be to set
-             * it to an empty string. */
+    /* this widget does not support conversion to a string. */
+    html2text(text, len);
 }
 
 /*
@@ -949,7 +1023,7 @@ lbh_navigation_policy_decision_requested_cb(WebKitWebView             * web_view
     else if (web_view == info->web_view
              && frame != info->frame
              && reason == WEBKIT_WEB_NAVIGATION_REASON_OTHER) {
-        g_message("%s new frame ignored:\n URI=\"%s\"", __func__, 
+        g_message("%s new frame ignored:\n URI=“%s”", __func__, 
                   webkit_network_request_get_uri(request));
         webkit_web_policy_decision_ignore(decision);
         return TRUE;
@@ -1233,9 +1307,8 @@ libbalsa_html_new(LibBalsaMessageBody * body,
 void
 libbalsa_html_to_string(gchar ** text, size_t len)
 {
-    return; /* this widget does not support conversion to a string. The
-             * string won't be altered. Other alternative would be to set
-             * it to an empty string. */
+    /* this widget does not support conversion to a string. */
+    html2text(text, len);
 }
 
 static gboolean
@@ -1490,7 +1563,9 @@ libbalsa_html_print(GtkWidget * widget)
 #  endif                        /* defined(USE_WEBKIT2) */
 # else                          /* defined(HAVE_WEBKIT) */
 
-/* Common code for both GtkHtml widgets. */
+/* Code for GtkHTML-4 */
+#include <gtkhtml/gtkhtml.h>
+#include <gtkhtml/gtkhtml-stream.h>
 
 /* Forward reference. */
 static gboolean libbalsa_html_url_requested(GtkWidget * html,
@@ -1525,13 +1600,6 @@ lbh_hovering_over_link_cb(GtkWidget   * widget,
         (*info->hover_cb) (uri);
 }
 
-# ifdef HAVE_GTKHTML4
-
-/* Code for GtkHTML-4 */
-
-#  include <gtkhtml/gtkhtml.h>
-#  include <gtkhtml/gtkhtml-stream.h>
-
 /* Callback for exporting an HTML part as text/plain. */
 static gboolean
 libbalsa_html_receiver_fn(gpointer engine, const gchar * data, size_t len,
@@ -1751,179 +1819,6 @@ libbalsa_html_print(GtkWidget * widget)
     g_object_unref(operation);
 }
 
-# else				/* HAVE_GTKHTML4 */
-
-/* Code for GtkHtml-2 */
-
-#  include <libgtkhtml/gtkhtml.h>
-
-/* Widget-dependent helper. */
-static void
-libbalsa_html_write_mime_stream(HtmlStream * stream, 
-                                GMimeStream * mime_stream)
-{
-    gint i;
-    char buf[4096];
-
-    while ((i = g_mime_stream_read(mime_stream, buf, sizeof(buf))) > 0)
-	html_stream_write(stream, buf, i);
-    html_stream_close(stream);
-}
-
-static void
-lbh_size_request_cb(GtkWidget      * widget,
-                    GtkRequisition * requisition,
-                    gpointer         data)
-{
-    GtkAdjustment *hadjustment, *vadjustment;
-
-    g_object_get(G_OBJECT(widget), "hadjustment", &hadjustment,
-                                   "vadjustment", &vadjustment, NULL);
-    requisition->width  = gtk_adjustment_get_upper(hadjustment);
-    requisition->height = gtk_adjustment_get_upper(vadjustment);
-}
-
-/* Create a new HtmlView widget:
- * text			the HTML source;
- * len			length of text;
- * body        		LibBalsaMessageBody that belongs to the
- *                      LibBalsaMessage from which to extract any
- *                      HTML objects (by url);
- * hover_cb             callback for the "on-url" signal;
- * link_clicked_cb	callback for the "link-clicked" signal;
- */
-
-GtkWidget *
-libbalsa_html_new(LibBalsaMessageBody  * body,
-                  LibBalsaHtmlCallback   hover_cb,
-                  LibBalsaHtmlCallback   link_clicked_cb)
-{
-    HtmlDocument *document;
-    LibBalsaHTMLInfo *info;
-    GtkWidget *html;
-    gssize len;
-    gchar *text;
-
-    len = lbh_get_body_content(body, &text);
-    if (len < 0)
-        return NULL;
-
-    document = html_document_new();
-    info = g_new(LibBalsaHTMLInfo, 1);
-    g_object_weak_ref(G_OBJECT(document), (GWeakNotify) g_free, info);
-
-    g_signal_connect(document, "request-url",
-                     G_CALLBACK(libbalsa_html_url_requested),
-                     body->message);
-
-    info->clicked_cb = link_clicked_cb;
-    g_signal_connect(document, "link-clicked",
-                     G_CALLBACK(lbh_navigation_requested_cb), info);
-
-    /* We need to first set_document and then do *_stream() operations
-     * or gtkhtml2 will crash. */
-    html = html_view_new();
-    html_view_set_document(HTML_VIEW(html), document);
-
-    info->hover_cb = hover_cb;
-    g_signal_connect(html, "on-url",
-                     G_CALLBACK(lbh_hovering_over_link_cb), info);
-
-    g_signal_connect(html, "size-request",
-                     G_CALLBACK(lbh_size_request_cb), info);
-
-    html_document_open_stream(document, "text/html");
-    html_document_write_stream(document, text, len);
-    g_free(text);
-    html_document_close_stream(document);
-
-    return html;
-}
-
-void
-libbalsa_html_to_string(gchar ** text, size_t len)
-{
-    return; /* this widget does not support conversion to a string. The
-             * string won't be altered. Other alternative would be to set
-             * it to an empty string. */
-}
-
-/*
- * Does the widget support zoom?
- */
-gboolean
-libbalsa_html_can_zoom(GtkWidget * widget)
-{
-    return HTML_IS_VIEW(widget);
-}
-
-/*
- * Zoom the widget.
- */
-void
-libbalsa_html_zoom(GtkWidget * widget, gint in_out)
-{
-    switch (in_out) {
-    case +1:
-	html_view_zoom_in(HTML_VIEW(widget));
-	break;
-    case -1:
-	html_view_zoom_out(HTML_VIEW(widget));
-	break;
-    case 0:
-	html_view_zoom_reset(HTML_VIEW(widget));
-	break;
-    default:
-	break;
-    }
-}
-
-/*
- * HtmlView doesn't support selecting text.
- */
-gboolean
-libbalsa_html_can_select(GtkWidget * widget)
-{
-    return FALSE;
-}
-
-/*
- * Do nothing.
- */
-void
-libbalsa_html_select_all(GtkWidget * widget)
-{
-}
-
-/*
- * Do nothing.
- */
-void
-libbalsa_html_copy(GtkWidget * widget)
-{
-}
-
-/*
- * HtmlView doesn't support printing.
- */
-gboolean
-libbalsa_html_can_print(GtkWidget * widget)
-{
-    return FALSE;
-}
-
-/*
- * Do nothing.
- */
-void
-libbalsa_html_print(GtkWidget * widget)
-{
-}
-
-# endif				/* HAVE_GTKHTML4 */
-
-/* Common code for both widgets. */
-
 static gboolean
 libbalsa_html_url_requested(GtkWidget * html, const gchar * url,
 			    gpointer stream, LibBalsaMessage * msg)
