@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -355,7 +353,7 @@ libbalsa_identity_get_signature(LibBalsaIdentity* identity, GtkWindow *parent)
             fclose(fp);
         } else
             libbalsa_information_parented(parent, LIBBALSA_INFORMATION_ERROR,
-                                          _("Cannot open signature file '%s' "
+                                          _("Cannot open signature file “%s” "
                                             "for reading"),
                                           identity->signature_path);
     }
@@ -484,7 +482,7 @@ libbalsa_identity_select_dialog(GtkWindow * parent,
     sdi->dialog = dialog =
         gtk_dialog_new_with_buttons(prompt, parent,
                                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     _("_OK"),     GTK_RESPONSE_OK,
                                     NULL);
@@ -1004,7 +1002,7 @@ setup_ident_frame(GtkDialog * dialog, gboolean createp, gpointer tree)
     /* create the "Messages" tab */
     grid = append_ident_notebook_page(notebook, _("Messages"), NULL);
     row = 0;
-    ident_dialog_add_entry(grid, row++, dialog, _("_Bcc:"),
+    ident_dialog_add_entry(grid, row++, dialog, _("_BCC:"),
                            "identity-bcc");
     ident_dialog_add_entry(grid, row++, dialog, _("Reply _string:"),
                            "identity-replystring");
@@ -1729,7 +1727,7 @@ libbalsa_identity_config_dialog(GtkWindow *parent, GList **identities,
         gtk_dialog_new_with_buttons(_("Manage Identities"),
                                     parent, /* must NOT be modal */
                                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Help"),   IDENTITY_RESPONSE_HELP,
                                     _("_New"),    IDENTITY_RESPONSE_NEW,
                                     _("_Remove"), IDENTITY_RESPONSE_REMOVE,
@@ -2216,3 +2214,64 @@ ident_dialog_get_value(GObject * dialog, const gchar * key)
 
     return g_ptr_array_index(values, value);
 }
+
+GtkWidget *
+libbalsa_identity_combo_box(GList       * identities,
+                            const gchar * active_name,
+                            GCallback     changed_cb,
+                            gpointer      changed_data)
+{
+    GList *list;
+    GtkListStore *store;
+    GtkWidget *combo_box;
+    GtkCellLayout *layout;
+    GtkCellRenderer *renderer;
+
+    /* For each identity, store the address, the identity name, and a
+     * ref to the identity in a combo-box.
+     * Note: we can't depend on identities staying in the same
+     * order while the combo-box is open, so we need a ref to the
+     * actual identity. */
+    store = gtk_list_store_new(3,
+                               G_TYPE_STRING,
+                               G_TYPE_STRING,
+                               G_TYPE_OBJECT);
+    combo_box = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
+
+    for (list = identities; list != NULL; list = list->next) {
+        LibBalsaIdentity *ident;
+        gchar *from;
+        gchar *name;
+        GtkTreeIter iter;
+
+        ident = list->data;
+        from = internet_address_to_string(ident->ia, FALSE);
+	name = g_strconcat("(", ident->identity_name, ")", NULL);
+
+        gtk_list_store_append(store, &iter);
+        gtk_list_store_set(store, &iter,
+                           0, from,
+                           1, name,
+                           2, ident,
+                           -1);
+
+        if (active_name && strcmp(active_name, name) == 0)
+            gtk_combo_box_set_active_iter(GTK_COMBO_BOX(combo_box), &iter);
+
+        g_free(from);
+        g_free(name);
+    }
+    g_object_unref(store);
+
+    layout = GTK_CELL_LAYOUT(combo_box);
+    renderer = gtk_cell_renderer_text_new();
+    gtk_cell_layout_pack_start(layout, renderer, TRUE);
+    gtk_cell_layout_set_attributes(layout, renderer, "text", 0, NULL);
+    renderer = gtk_cell_renderer_text_new();
+    gtk_cell_layout_pack_start(layout, renderer, FALSE);
+    gtk_cell_layout_set_attributes(layout, renderer, "text", 1, NULL);
+
+    g_signal_connect(combo_box, "changed", changed_cb, changed_data);
+
+    return combo_box;
+}
