@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -32,10 +30,9 @@
 
 #include "libbalsa.h"
 
-#ifdef __cplusplus
-extern "C" 
-{
-#endif /* __cplusplus */
+
+G_BEGIN_DECLS
+
 
     GType libbalsa_identity_get_type(void);
 
@@ -145,11 +142,16 @@ extern "C"
                                          LibBalsaIdentity * initial_id,
                                          LibBalsaIdentityCallback update,
                                          gpointer data);
+    GtkWidget * libbalsa_identity_combo_box(GList       * identities,
+                                            const gchar * active_name,
+                                            GCallback     changed_cb,
+                                            gpointer      changed_data);
 
     LibBalsaIdentity* libbalsa_identity_new_config(const gchar* name);
     void libbalsa_identity_save(LibBalsaIdentity* id, const gchar* prefix);
 
-#ifdef __cplusplus
-}
-#endif
+
+G_END_DECLS
+
+
 #endif /* __LIBBALSA_IDENTITY_H__ */
