@@ -1,5 +1,5 @@
 /* libimap library.
- * Copyright (C) 2003-2013 Pawel Salek.
+ * Copyright (C) 2003-2016 Pawel Salek.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,9 +12,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #define _POSIX_C_SOURCE 199506L
@@ -355,11 +353,7 @@ imap_write_key_date(ImapMboxHandle *handle, ImapSearchDateRange range,
   static const char *month[] = 
     { "Jan", "Feb", "Mar", "Apr", "May",
       "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
-#if GLIB_CHECK_VERSION(2,10,0)
   GDate date;
-#else
-  struct tm date;
-#endif
   if(!internal) sio_write(handle->sio, "SENT", 4);
   switch(range) {
   case IMSE_D_BEFORE : sio_write(handle->sio, "BEFORE ", 7); break;
@@ -367,15 +361,9 @@ imap_write_key_date(ImapMboxHandle *handle, ImapSearchDateRange range,
   default: /* which is -2, the only remaining option */
   case IMSE_D_SINCE  : sio_write(handle->sio, "SINCE " , 6); break;
   }
-#if GLIB_CHECK_VERSION(2,10,0)
   g_date_set_time_t(&date, tm);
   sio_printf(handle->sio, "%02d-%s-%04d",
 	     date.day, month[date.month - 1], date.year);
-#else
-  localtime_r(&tm, &date);
-  sio_printf(handle->sio, "%02d-%s-%04d",
-             date.tm_mday, month[date.tm_mon], date.tm_year + 1900);
-#endif
 }
 
 static void
@@ -561,9 +549,9 @@ imap_search_exec(ImapMboxHandle *h, gboolean uid,
 {
   ImapResponse rc;
 
-  HANDLE_LOCK(h);
+  g_mutex_lock(&h->mutex);
   rc = imap_search_exec_unlocked(h, uid, s, cb, cb_arg);
-  HANDLE_UNLOCK(h);
+  g_mutex_unlock(&h->mutex);
 
   return rc;
 }
