@@ -1,5 +1,5 @@
 /* libimap library.
- * Copyright (C) 2003-2013 Pawel Salek.
+ * Copyright (C) 2003-2016 Pawel Salek.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,9 +12,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 /** @file imap_tst.c tests some IMAP capabilities. It is very useful
     for stress-testing the imap part of balsa. */
@@ -648,10 +646,6 @@ process_options(int argc, char *argv[])
 
 int
 main(int argc, char *argv[]) {
-#if !GLIB_CHECK_VERSION(2, 35, 0)
-  g_type_init();
-#endif                          /* !GLIB_CHECK_VERSION(2, 35, 0) */
-
   if(argc<=1) {
     test_envelope_strings();
     test_body_strings();
