@@ -5,7 +5,7 @@
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
-#define g_marshal_value_peek_char(v)     g_value_get_char (v)
+#define g_marshal_value_peek_char(v)     g_value_get_schar (v)
 #define g_marshal_value_peek_uchar(v)    g_value_get_uchar (v)
 #define g_marshal_value_peek_int(v)      g_value_get_int (v)
 #define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:INT,INT,POINTER (libimap-marshal.list:1) */
+/* VOID:INT,INT,POINTER (../../libbalsa/imap/libimap-marshal.list:1) */
 void
 libimap_VOID__INT_INT_POINTER (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -64,9 +64,9 @@ libimap_VOID__INT_INT_POINTER (GClosure     *closure,
                                                       gint         arg_2,
                                                       gpointer     arg_3,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
