@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -64,7 +62,7 @@ lbc_readfile(const gchar * filename)
 
     if (!g_file_get_contents(filename, &buf, NULL, NULL)) {
 #if DEBUG
-        g_message("Failed to read \"%s\"\n", filename);
+        g_message("Failed to read “%s”\n", filename);
 #endif                          /* DEBUG */
         return NULL;
     }
@@ -112,8 +110,8 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
         old_path =
             g_build_filename(g_get_home_dir(), old_dir, "balsa", NULL);
 #if DEBUG
-        g_message("Could not load config from \"%s\":\n %s\n"
-                  " trying \"%s\"", conf->path, error->message, old_path);
+        g_message("Could not load config from “%s”:\n %s\n"
+                  " trying “%s”", conf->path, error->message, old_path);
 #endif                          /* DEBUG */
         g_clear_error(&error);
 
@@ -130,7 +128,7 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
         }
         if (!buf || error) {
 #if DEBUG
-            g_message("Could not load key file from file \"%s\": %s",
+            g_message("Could not load key file from file “%s”: %s",
                       old_path,
                       error ? error->message : g_strerror(errno));
 #endif                          /* DEBUG */
@@ -142,22 +140,18 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
                                  _("Your Balsa configuration "
                                    "is now stored in "
-                                   "\"~/.balsa/config\"."));
+                                   "“~/.balsa/config”."));
     }
 }
 
-#ifdef BALSA_USE_THREADS
 static GRecMutex lbc_mutex;
-#endif                          /* BALSA_USE_THREADS */
 
 static void
 lbc_lock(void)
 {
     static gboolean initialized = FALSE;
 
-#ifdef BALSA_USE_THREADS
     g_rec_mutex_lock(&lbc_mutex);
-#endif                          /* BALSA_USE_THREADS */
     if (!initialized) {
         lbc_init(&lbc_conf, "config", ".gnome2");
         lbc_init(&lbc_conf_priv, "config-private", ".gnome2_private");
@@ -168,9 +162,7 @@ lbc_lock(void)
 static void
 lbc_unlock(void)
 {
-#ifdef BALSA_USE_THREADS
     g_rec_mutex_unlock(&lbc_mutex);
-#endif                          /* BALSA_USE_THREADS */
 }
 
 /* 
@@ -497,7 +489,7 @@ lbc_sync(LibBalsaConf * conf)
     buf = g_key_file_to_data(conf->key_file, &len, &error);
     if (error) {
 #if DEBUG
-        g_message("Failed to sync config file \"%s\": %s\n"
+        g_message("Failed to sync config file “%s”: %s\n"
                   " changes not saved", conf->path, error->message);
 #endif                          /* DEBUG */
         g_error_free(error);
@@ -509,13 +501,13 @@ lbc_sync(LibBalsaConf * conf)
     if (!g_file_set_contents(conf->path, buf, len, &error)) {
         if (error) {
 #if DEBUG
-            g_message("Failed to rewrite config file \"%s\": %s\n"
+            g_message("Failed to rewrite config file “%s”: %s\n"
                       " changes not saved", conf->path, error->message);
 #endif                          /* DEBUG */
             g_error_free(error);
 #if DEBUG
         } else {
-                g_message("Failed to rewrite config file \"%s\";"
+                g_message("Failed to rewrite config file “%s”;"
                           " changes not saved", conf->path);
 #endif                          /* DEBUG */
         }
@@ -525,16 +517,12 @@ lbc_sync(LibBalsaConf * conf)
 }
 
 static guint lbc_sync_idle_id;
-#ifdef BALSA_USE_THREADS
 G_LOCK_DEFINE_STATIC(lbc_sync_idle_id);
-#endif                          /* BALSA_USE_THREADS */
 
 void
 libbalsa_conf_sync(void)
 {
-#ifdef BALSA_USE_THREADS
     G_LOCK(lbc_sync_idle_id);
-#endif                          /* BALSA_USE_THREADS */
 #if DEBUG
     g_print("%s id %d, will be cleared\n", __func__, lbc_sync_idle_id);
 #endif                          /* DEBUG */
@@ -542,9 +530,7 @@ libbalsa_conf_sync(void)
         g_source_remove(lbc_sync_idle_id);
         lbc_sync_idle_id = 0;
     }
-#ifdef BALSA_USE_THREADS
     G_UNLOCK(lbc_sync_idle_id);
-#endif                          /* BALSA_USE_THREADS */
     lbc_lock();
     lbc_sync(&lbc_conf);
     lbc_sync(&lbc_conf_priv);
@@ -562,9 +548,7 @@ libbalsa_conf_sync_idle_cb(gpointer data)
 void
 libbalsa_conf_queue_sync(void)
 {
-#ifdef BALSA_USE_THREADS
     G_LOCK(lbc_sync_idle_id);
-#endif                          /* BALSA_USE_THREADS */
 #if DEBUG
     g_print("%s id %d, will be set if zero\n", __func__, lbc_sync_idle_id);
 #endif                          /* DEBUG */
@@ -574,7 +558,5 @@ libbalsa_conf_queue_sync(void)
 #if DEBUG
     g_print("%s id now %d\n", __func__, lbc_sync_idle_id);
 #endif                          /* DEBUG */
-#ifdef BALSA_USE_THREADS
     G_UNLOCK(lbc_sync_idle_id);
-#endif                          /* BALSA_USE_THREADS */
 }
