@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -28,11 +26,6 @@
 #include <locale.h>
 #endif
 
-#ifdef BALSA_USE_THREADS
-#include <pthread.h>
-#include "misc.h"
-#endif
-
 #if HAVE_MACOSX_DESKTOP
 #include "macosx-helpers.h"
 #endif
@@ -168,8 +161,8 @@ libbalsa_gpgme_init(gpgme_passphrase_cb_t get_passphrase,
 #endif
 
     /* remember callbacks */
-    select_key = select_key_cb;
-    accept_low_trust = accept_low_trust_cb;
+    select_key_cb = select_key;
+    accept_low_trust_cb = accept_low_trust;
 }
 
 
@@ -327,9 +320,8 @@ libbalsa_gpgme_sign(const gchar * userid, GMimeStream * istream,
 			 protocol == GPGME_PROTOCOL_CMS, GPGME_MD_NONE);
 
     /* create the GpgME context */
-    if ((err =
-	 gpgme_new_with_protocol(&ctx, protocol, parent,
-				 error)) != GPG_ERR_NO_ERROR)
+    if (gpgme_new_with_protocol(&ctx, protocol, parent,
+				 error) != GPG_ERR_NO_ERROR)
 	return GPGME_MD_NONE;
 
     /* set the signature mode */
@@ -402,13 +394,13 @@ libbalsa_gpgme_sign(const gchar * userid, GMimeStream * istream,
  *        to ask the user whether a low-trust key shall be accepted.
  * \param parent Parent window to be passed to the callback functions.
  * \param error Filled with error information on error.
- * \return 0 on success, or -1 on error.
+ * \return TRUE on success, or FALSE on error.
  *
  * Encrypt the passed matter and write the result to the output stream.
  * Combined signing and encryption is allowed for single-part OpenPGP mode
  * only.
  */
-int
+gboolean
 libbalsa_gpgme_encrypt(GPtrArray * recipients, const char *sign_for,
 		       GMimeStream * istream, GMimeStream * ostream,
 		       gpgme_protocol_t protocol, gboolean singlepart_mode,
@@ -428,17 +420,16 @@ libbalsa_gpgme_encrypt(GPtrArray * recipients, const char *sign_for,
     };
 
     /* paranoia checks */
-    g_return_val_if_fail(recipients != NULL, -1);
-    g_return_val_if_fail(GMIME_IS_STREAM(istream), -1);
-    g_return_val_if_fail(GMIME_IS_STREAM(ostream), GPGME_MD_NONE);
+    g_return_val_if_fail(recipients != NULL, FALSE);
+    g_return_val_if_fail(GMIME_IS_STREAM(istream), FALSE);
+    g_return_val_if_fail(GMIME_IS_STREAM(ostream), FALSE);
     g_return_val_if_fail(protocol == GPGME_PROTOCOL_OpenPGP ||
-			 protocol == GPGME_PROTOCOL_CMS, -1);
+			 protocol == GPGME_PROTOCOL_CMS, FALSE);
 
     /* create the GpgME context */
-    if ((err =
-	 gpgme_new_with_protocol(&ctx, protocol, parent,
-				 error)) != GPG_ERR_NO_ERROR)
-	return -1;
+    if (gpgme_new_with_protocol(&ctx, protocol, parent,
+				 error) != GPG_ERR_NO_ERROR)
+	return FALSE;
 
     /* sign & encrypt is valid only for single-part OpenPGP */
     if (sign_for != NULL
@@ -448,13 +439,13 @@ libbalsa_gpgme_encrypt(GPtrArray * recipients, const char *sign_for,
 			_
 			("combined signing and encryption is defined only for RFC 2440"));
 	gpgme_release(ctx);
-	return -1;
+	return FALSE;
     }
 
     /* if requested, find the secret key for "userid" */
     if (sign_for && !gpgme_add_signer(ctx, sign_for, parent, error)) {
 	gpgme_release(ctx);
-	return -1;
+	return FALSE;
     }
 
     /* build the list of recipients */
@@ -463,7 +454,7 @@ libbalsa_gpgme_encrypt(GPtrArray * recipients, const char *sign_for,
 	 gpgme_build_recipients(ctx, recipients, trust_all_keys, parent,
 				error))) {
 	gpgme_release(ctx);
-	return -1;
+	return FALSE;
     }
 
     /* create the data objects */
@@ -481,7 +472,7 @@ libbalsa_gpgme_encrypt(GPtrArray * recipients, const char *sign_for,
 			       _("could not get data from stream"));
 	release_keylist(rcpt_keys);
 	gpgme_release(ctx);
-	return -1;
+	return FALSE;
     }
     if ((err =
 	 gpgme_data_new_from_cbs(&crypt, &cbs,
@@ -491,7 +482,7 @@ libbalsa_gpgme_encrypt(GPtrArray * recipients, const char *sign_for,
 	release_keylist(rcpt_keys);
 	gpgme_data_release(plain);
 	gpgme_release(ctx);
-	return -1;
+	return FALSE;
     }
 
     /* do the encrypt or sign and encrypt operation
@@ -517,9 +508,9 @@ libbalsa_gpgme_encrypt(GPtrArray * recipients, const char *sign_for,
 				   _("signing and encryption failed"));
 	else
 	    g_set_error_from_gpgme(error, err, _("encryption failed"));
-	return -1;
+	return FALSE;
     } else
-	return 0;
+	return TRUE;
 }
 
 
@@ -561,9 +552,8 @@ libbalsa_gpgme_decrypt(GMimeStream * crypted, GMimeStream * plain,
 			 protocol == GPGME_PROTOCOL_CMS, NULL);
 
     /* create the GpgME context */
-    if ((err =
-	 gpgme_new_with_protocol(&ctx, protocol, parent,
-				 error)) != GPG_ERR_NO_ERROR)
+    if (gpgme_new_with_protocol(&ctx, protocol, parent,
+				 error) != GPG_ERR_NO_ERROR)
 	return NULL;
 
     /* create the data streams */
@@ -606,16 +596,23 @@ libbalsa_gpgme_decrypt(GMimeStream * crypted, GMimeStream * plain,
 
 /* ---- local stuff ---------------------------------------------------- */
 
-#define UTF8_VALID_STR(s)						\
-    do {								\
-	if ((s) && !g_utf8_validate(s, -1, NULL)) {			\
-	    gsize bwr;							\
-	    gchar * newstr = g_locale_to_utf8(s, -1, NULL, &bwr, NULL);	\
-									\
-	    g_free(s);							\
-	    s = newstr;							\
-	}								\
-    } while (0)
+static gchar *
+utf8_valid_str(const char *gpgme_str)
+{
+	gchar *result;
+
+	if (gpgme_str != NULL) {
+		if (g_utf8_validate(gpgme_str, -1, NULL)) {
+			result = g_strdup(gpgme_str);
+		} else {
+			gsize bytes_written;
+			result = g_locale_to_utf8(gpgme_str, -1, NULL, &bytes_written, NULL);
+		}
+	} else {
+		result = NULL;
+	}
+	return result;
+}
 
 
 /*
@@ -625,20 +622,19 @@ static void
 g_set_error_from_gpgme(GError ** error, gpgme_error_t gpgme_err,
 		       const gchar * message)
 {
-    gchar *errstr;
-    gchar *srcstr;
+    if (error != NULL) {
+    	gchar errbuf[4096];		/* should be large enough... */
+        gchar *errstr;
+        gchar *srcstr;
 
-    if (!error)
-	return;
-
-    srcstr = g_strdup(gpgme_strsource(gpgme_err));
-    UTF8_VALID_STR(srcstr);
-    errstr = g_strdup(gpgme_strerror(gpgme_err));
-    UTF8_VALID_STR(errstr);
-    g_set_error(error, GPGME_ERROR_QUARK, gpgme_err, "%s: %s: %s", srcstr,
-		message, errstr);
-    g_free(srcstr);
-    g_free(errstr);
+        srcstr = utf8_valid_str(gpgme_strsource(gpgme_err));
+        gpgme_strerror_r(gpgme_err, errbuf, sizeof(errbuf));
+        errstr = utf8_valid_str(errbuf);
+        g_set_error(error, GPGME_ERROR_QUARK, gpgme_err, "%s: %s: %s", srcstr,
+        	message, errstr);
+        g_free(srcstr);
+        g_free(errstr);
+    }
 }
 
 
@@ -694,7 +690,7 @@ gpgme_new_with_protocol(gpgme_ctx_t * ctx, gpgme_protocol_t protocol,
     } else {
 	if ((err = gpgme_set_protocol(*ctx, protocol)) != GPG_ERR_NO_ERROR) {
 	    gchar *errmsg =
-		g_strdup_printf(_("could not set protocol '%s'"),
+		g_strdup_printf(_("could not set protocol “%s”"),
 				gpgme_get_protocol_name(protocol));
 
 	    g_set_error_from_gpgme(error, err, errmsg);
@@ -709,6 +705,32 @@ gpgme_new_with_protocol(gpgme_ctx_t * ctx, gpgme_protocol_t protocol,
     return err;
 }
 
+/* return TRUE if the passed key is not expired, not revoked, not disabled
+ * and not invalid, and has at least one subkey which can be used for signing
+ * if secret is TRUE, or one subkey which can be used for encryption if secret
+ * is FALSE, and the particular subkey is not expired, not revoked, not
+ * disabled and not invalid */
+static gboolean
+check_key(const gpgme_key_t key, gboolean secret, time_t now)
+{
+	gboolean result = FALSE;
+
+	if (!key->expired && !key->revoked && !key->disabled && !key->invalid) {
+		gpgme_subkey_t subkey = key->subkeys;
+
+		while (!result && (subkey != NULL)) {
+			if (((secret && subkey->can_sign) || (!secret && subkey->can_encrypt)) &&
+				!subkey->expired && !subkey->revoked && !subkey->disabled && !subkey->invalid &&
+				(subkey->expires == 0 || subkey->expires > now)) {
+				result = TRUE;
+			} else {
+				subkey = subkey->next;
+			}
+		}
+	}
+
+	return result;
+}
 
 /*
  * Get a key for name. If secret_only is set, choose only secret (private)
@@ -717,8 +739,6 @@ gpgme_new_with_protocol(gpgme_ctx_t * ctx, gpgme_protocol_t protocol,
  * no matching key could be found or if any error occurs, return NULL and
  * set error.
  */
-#define KEY_IS_OK(k)   (!((k)->expired || (k)->revoked || \
-                          (k)->disabled || (k)->invalid))
 static gpgme_key_t
 get_key_from_name(gpgme_ctx_t ctx, const gchar * name, gboolean secret,
 		  gboolean accept_all, GtkWindow * parent, GError ** error)
@@ -733,7 +753,7 @@ get_key_from_name(gpgme_ctx_t ctx, const gchar * name, gboolean secret,
     if ((err =
 	 gpgme_op_keylist_start(ctx, name, secret)) != GPG_ERR_NO_ERROR) {
 	gchar *msg =
-	    g_strdup_printf(_("could not list keys for \"%s\""), name);
+	    g_strdup_printf(_("could not list keys for “%s”"), name);
 
 	g_set_error_from_gpgme(error, err, msg);
 	g_free(msg);
@@ -743,25 +763,15 @@ get_key_from_name(gpgme_ctx_t ctx, const gchar * name, gboolean secret,
     found_bad = FALSE;
     while ((err = gpgme_op_keylist_next(ctx, &key)) == GPG_ERR_NO_ERROR) {
 	/* check if this key and the relevant subkey are usable */
-	if (KEY_IS_OK(key)) {
-	    gpgme_subkey_t subkey = key->subkeys;
-
-	    while (subkey && ((secret && !subkey->can_sign) ||
-			      (!secret && !subkey->can_encrypt)))
-		subkey = subkey->next;
-
-	    if (subkey && KEY_IS_OK(subkey) &&
-		(subkey->expires == 0 || subkey->expires > now))
+	if (check_key(key, secret, now)) {
 		keys = g_list_append(keys, key);
-	    else
-		found_bad = TRUE;
 	} else
 	    found_bad = TRUE;
     }
 
     if (gpg_err_code(err) != GPG_ERR_EOF) {
 	gchar *msg =
-	    g_strdup_printf(_("could not list keys for \"%s\""), name);
+	    g_strdup_printf(_("could not list keys for “%s”"), name);
 
 	g_set_error_from_gpgme(error, err, msg);
 	g_free(msg);
@@ -807,8 +817,9 @@ get_key_from_name(gpgme_ctx_t ctx, const gchar * name, gboolean secret,
     if (g_list_length(keys) > 1) {
 	if (select_key_cb)
 	    key =
-		select_key_cb(name, secret, keys, gpgme_get_protocol(ctx),
-			      parent);
+		select_key_cb(name,
+					  secret ? LB_SELECT_PRIVATE_KEY : LB_SELECT_PUBLIC_KEY_USER,
+					  keys, gpgme_get_protocol(ctx), parent);
 	else {
 	    if (error)
 		g_set_error(error, GPGME_ERROR_QUARK,
@@ -859,7 +870,7 @@ get_key_from_name(gpgme_ctx_t ctx, const gchar * name, gboolean secret,
 		if (error)
 		    g_set_error(error, GPGME_ERROR_QUARK,
 				GPG_ERR_KEY_SELECTION,
-				_("%s: insufficient validity for uid %s"),
+				_("%s: insufficient validity for UID %s"),
 				"gmime-gpgme", name);
 	    }
 	}
@@ -869,6 +880,57 @@ get_key_from_name(gpgme_ctx_t ctx, const gchar * name, gboolean secret,
 }
 
 
+static gpgme_key_t
+get_pubkey(gpgme_ctx_t ctx, const gchar * name, gboolean accept_all,
+	GtkWindow * parent, GError ** error)
+{
+	GList *keys = NULL;
+	gpgme_key_t key;
+	gpgme_error_t err;
+	time_t now = time(NULL);
+
+	/* let gpgme list keys */
+	if ((err = gpgme_op_keylist_start(ctx, NULL, 0)) != GPG_ERR_NO_ERROR) {
+		gchar *msg = g_strdup_printf(_("could not list keys"));
+
+		g_set_error_from_gpgme(error, err, msg);
+		g_free(msg);
+		return NULL;
+	}
+
+	while ((err = gpgme_op_keylist_next(ctx, &key)) == GPG_ERR_NO_ERROR) {
+		/* check if this key and the relevant subkey are usable */
+		if (check_key(key, 0, now))
+			keys = g_list_append(keys, key);
+	}
+
+	if (gpg_err_code(err) != GPG_ERR_EOF || !keys) {
+		gchar *msg = g_strdup_printf(_("could not list keys"));
+
+		g_set_error_from_gpgme(error, err, msg);
+		g_free(msg);
+		gpgme_op_keylist_end(ctx);
+		g_list_foreach(keys, (GFunc) gpgme_key_unref, NULL);
+		g_list_free(keys);
+		return NULL;
+	}
+	gpgme_op_keylist_end(ctx);
+
+	/* let the user select a key from the list, even if there is only one */
+	if (select_key_cb)
+		key = select_key_cb(name, LB_SELECT_PUBLIC_KEY_ANY, keys,
+							gpgme_get_protocol(ctx), parent);
+	else
+		key = NULL;
+	if (key) {
+		gpgme_key_ref(key);
+		g_list_foreach(keys, (GFunc) gpgme_key_unref, NULL);
+	}
+	g_list_free(keys);
+	return key;
+}
+
+
 /*
  * Add signer to ctx's list of signers and return TRUE on success or FALSE
  * on error.
@@ -877,19 +939,20 @@ static gboolean
 gpgme_add_signer(gpgme_ctx_t ctx, const gchar * signer, GtkWindow * parent,
 		 GError ** error)
 {
-    gpgme_key_t key = NULL;
+	gboolean result = FALSE;
+	gpgme_key_t key;
 
     /* note: private (secret) key has never low trust... */
-    if (!
-	(key = get_key_from_name(ctx, signer, TRUE, FALSE, parent, error)))
-	return FALSE;
+	key = get_key_from_name(ctx, signer, TRUE, FALSE, parent, error);
+	if (key != NULL) {
+		/* set the key (the previous operation guaranteed that it exists, no
+		 * need 2 check return values...) */
+		gpgme_signers_add(ctx, key);
+		gpgme_key_unref(key);
+		result = TRUE;
+	}
 
-    /* set the key (the previous operation guaranteed that it exists, no
-     * need 2 check return values...) */
-    gpgme_signers_add(ctx, key);
-    gpgme_key_unref(key);
-
-    return TRUE;
+    return result;
 }
 
 
@@ -911,12 +974,13 @@ gpgme_build_recipients(gpgme_ctx_t ctx, GPtrArray * rcpt_list,
 	gchar *name = (gchar *) g_ptr_array_index(rcpt_list, num_rcpts);
 	gpgme_key_t key;
 
-	if (!
-	    (key =
-	     get_key_from_name(ctx, name, FALSE, accept_low_trust, parent,
-			       error))) {
-	    release_keylist(rcpt);
-	    return NULL;
+		key = get_key_from_name(ctx, name, FALSE, accept_low_trust, parent, error);
+		if (key == NULL) {
+			key = get_pubkey(ctx, name, accept_low_trust, parent, error);
+			if (key == NULL) {
+				release_keylist(rcpt);
+				return NULL;
+			}
 	}
 
 	/* set the recipient */
