@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -33,6 +31,9 @@
 #include <sys/stat.h>
 #include <stdarg.h>
 #include <unistd.h>
+#include <openssl/ssl.h>
+#include <openssl/x509.h>
+#include <openssl/err.h>
 
 #ifdef HAVE_NOTIFY
 #include <libnotify/notify.h>
@@ -47,27 +48,19 @@
 #endif                          /* HAVE_COMPFACE */
 
 #if HAVE_GTKSOURCEVIEW
-#include <gtksourceview/gtksourceview.h>
-#include <gtksourceview/gtksourcebuffer.h>
-/* note GtkSourceview 1 and 2 have a slightly different API */
-#if (HAVE_GTKSOURCEVIEW == 1)
-#  include <gtksourceview/gtksourcetag.h>
-#  include <gtksourceview/gtksourcetagstyle.h>
-#else
-#  include <gtksourceview/gtksourcelanguage.h>
-#  include <gtksourceview/gtksourcelanguagemanager.h>
-#  include <gtksourceview/gtksourcestylescheme.h>
-#  include <gtksourceview/gtksourcestyleschememanager.h>
+#include <gtksourceview/gtksource.h>
 #endif
+
+#if HAVE_GCR
+#define GCR_API_SUBJECT_TO_CHANGE
+#include <gcr/gcr.h>
 #endif
 
 #include "misc.h"
 #include "missing.h"
 #include <glib/gi18n.h>
 
-#ifdef BALSA_USE_THREADS
-static pthread_t main_thread_id;
-#endif
+static GThread *main_thread_id;
 
 
 void
@@ -90,9 +83,7 @@ libbalsa_init(LibBalsaInformationFunc information_callback)
     notify_init("Basics");
 #endif
 
-#ifdef BALSA_USE_THREADS
-    main_thread_id = pthread_self();
-#endif
+    main_thread_id = g_thread_self();
 
     uname(&utsname);
 
@@ -133,6 +124,9 @@ libbalsa_init(LibBalsaInformationFunc information_callback)
 #if HAVE_RUBRICA
     LIBBALSA_TYPE_ADDRESS_BOOK_RUBRICA;
 #endif
+#if HAVE_OSMO
+    LIBBALSA_TYPE_ADDRESS_BOOK_OSMO;
+#endif
 }
 
 
@@ -260,23 +254,23 @@ gboolean libbalsa_ldap_exists(const gchar *server)
 }
 
 gchar*
-libbalsa_date_to_utf8(const time_t *date, const gchar *date_string)
+libbalsa_date_to_utf8(const time_t date, const gchar *date_string)
 {
-    struct tm footime;
-    gchar rettime[128];
+	gchar *result;
 
-    g_return_val_if_fail(date != NULL, NULL);
     g_return_val_if_fail(date_string != NULL, NULL);
 
-    if (!*date)
+    if (date == (time_t) 0) {
         /* Missing "Date:" field?  It is required by RFC 2822. */
-        return NULL;
+        result = NULL;
+    } else {
+    	GDateTime *footime;
 
-    localtime_r(date, &footime);
-
-    strftime(rettime, sizeof(rettime), date_string, &footime);
-
-    return g_locale_to_utf8(rettime, -1, NULL, NULL, NULL);
+    	footime = g_date_time_new_from_unix_local(date);
+    	result = g_date_time_format(footime, date_string);
+    	g_date_time_unref(footime);
+    }
+    return result;
 }
 
 LibBalsaMessageStatus
@@ -297,13 +291,12 @@ libbalsa_get_icon_from_flags(LibBalsaMessageFlag flags)
 }
 
 
-#ifdef BALSA_USE_THREADS
-#include <pthread.h>
 typedef struct {
-    pthread_mutex_t lock;
-    pthread_cond_t condvar;
+    GMutex lock;
+    GCond condvar;
     int (*cb)(void *arg);
     void *arg;
+    gboolean done;
     int res;
 } AskData;
 
@@ -317,8 +310,9 @@ ask_idle(gpointer data)
     printf("ask_idle: ENTER %p\n", data);
     gdk_threads_enter();
     ad->res = (ad->cb)(ad->arg);
+    ad->done = TRUE;
     gdk_threads_leave();
-    pthread_cond_signal(&ad->condvar);
+    g_cond_signal(&ad->condvar);
     printf("ask_idle: LEAVE %p\n", data);
     return FALSE;
 }
@@ -332,7 +326,7 @@ libbalsa_ask(gboolean (*cb)(void *arg), void *arg)
 {
     AskData ad;
 
-    if (pthread_self() == main_thread_id) {
+    if (!libbalsa_am_i_subthread()) {
         int ret;
         printf("Main thread asks the following question.\n");
         gdk_threads_enter();
@@ -341,35 +335,29 @@ libbalsa_ask(gboolean (*cb)(void *arg), void *arg)
         return ret;
     }
     printf("Side thread asks the following question.\n");
-    pthread_mutex_init(&ad.lock, NULL);
-    pthread_cond_init(&ad.condvar, NULL);
+    g_mutex_init(&ad.lock);
+    g_cond_init(&ad.condvar);
     ad.cb  = cb;
     ad.arg = arg;
+    ad.done = FALSE;
 
-    pthread_mutex_lock(&ad.lock);
-    pthread_cond_init(&ad.condvar, NULL);
+    g_mutex_lock(&ad.lock);
     g_idle_add(ask_idle, &ad);
-    pthread_cond_wait(&ad.condvar, &ad.lock);
+    while (!ad.done) {
+    	g_cond_wait(&ad.condvar, &ad.lock);
+    }
 
-    pthread_cond_destroy(&ad.condvar);
-    pthread_mutex_unlock(&ad.lock);
+    g_cond_clear(&ad.condvar);
+    g_mutex_unlock(&ad.lock);
     return ad.res;
 }
-#else /* BALSA_USE_THREADS */
-static gboolean
-libbalsa_ask(gboolean (*cb)(void *arg), void *arg)
-{
-    return cb(arg);
-}
-#endif /* BALSA_USE_THREADS */
 
 
-#if defined(USE_SSL)
-#include <openssl/ssl.h>
-#include <openssl/x509.h>
-#include <openssl/err.h>
 static int libbalsa_ask_for_cert_acceptance(X509 *cert,
 					    const char *explanation);
+
+#ifndef HAVE_GCR
+
 static char*
 asn1time_to_string(ASN1_UTCTIME *tm)
 {
@@ -426,25 +414,19 @@ x509_fingerprint (char *s, unsigned len, X509 * cert)
     s[i] = '\0';
 }
 
-static GList *accepted_certs = NULL; /* certs accepted for this session */
+#endif  /* HAVE_GCR */
 
-#ifdef BALSA_USE_THREADS
-static pthread_mutex_t certificate_lock = PTHREAD_MUTEX_INITIALIZER;
-#define LOCK_CERTIFICATES   pthread_mutex_lock(&certificate_lock)
-#define UNLOCK_CERTIFICATES pthread_mutex_unlock(&certificate_lock)
-#else
-#define LOCK_CERTIFICATES
-#define UNLOCK_CERTIFICATES
-#endif
+static GList *accepted_certs = NULL; /* certs accepted for this session */
+static GMutex certificate_lock;
 
 void
 libbalsa_certs_destroy(void)
 {
-    LOCK_CERTIFICATES;
+	g_mutex_lock(&certificate_lock);
     g_list_foreach(accepted_certs, (GFunc)X509_free, NULL);
     g_list_free(accepted_certs);
     accepted_certs = NULL;
-    UNLOCK_CERTIFICATES;
+    g_mutex_unlock(&certificate_lock);
 }
 
 /* compare Example 10-7 in the OpenSSL book */
@@ -457,11 +439,11 @@ libbalsa_is_cert_known(X509* cert, long vfy_result)
     gboolean res = FALSE;
     GList *lst;
 
-    LOCK_CERTIFICATES;
+    g_mutex_lock(&certificate_lock);
     for(lst = accepted_certs; lst; lst = lst->next) {
         int res = X509_cmp(cert, lst->data);
         if(res == 0) {
-	    UNLOCK_CERTIFICATES;
+        	g_mutex_unlock(&certificate_lock);
             return TRUE;
 	}
     }
@@ -485,12 +467,12 @@ libbalsa_is_cert_known(X509* cert, long vfy_result)
         ERR_clear_error();
         fclose(fp);
     }
-    UNLOCK_CERTIFICATES;
+    g_mutex_unlock(&certificate_lock);
     
     if(!res) {
 	const char *reason = X509_verify_cert_error_string(vfy_result);
 	res = libbalsa_ask_for_cert_acceptance(cert, reason);
-	LOCK_CERTIFICATES;
+	g_mutex_lock(&certificate_lock);
 	if(res == 2) {
 	    cert_name = g_strconcat(g_get_home_dir(),
 				    "/.balsa/certificates", NULL);
@@ -506,7 +488,7 @@ libbalsa_is_cert_known(X509* cert, long vfy_result)
 	if(res == 1)
 	    accepted_certs = 
 		g_list_prepend(accepted_certs, X509_dup(cert));
-	UNLOCK_CERTIFICATES;
+	g_mutex_unlock(&certificate_lock);
     }
 
     return res;
@@ -525,6 +507,69 @@ struct AskCertData {
     const char *explanation;
 };
 
+#if HAVE_GCR
+
+static int
+ask_cert_real(void *data)
+{
+    struct AskCertData *acd = (struct AskCertData*)data;
+    GtkWidget *dialog;
+    GtkWidget *cert_widget;
+    GString *str;
+    unsigned i;
+    unsigned char *der_buf = NULL;
+    int der_len;
+    GcrCertificate *gcr_cert;
+    GtkWidget *label;
+
+    dialog = gtk_dialog_new_with_buttons(_("SSL/TLS certificate"),
+                                         NULL, /* FIXME: NULL parent */
+                                         GTK_DIALOG_MODAL |
+                                         libbalsa_dialog_flags(),
+                                         _("_Accept Once"), 0,
+                                         _("Accept & _Save"), 1,
+                                         _("_Reject"), GTK_RESPONSE_CANCEL,
+                                         NULL);
+    gtk_window_set_role(GTK_WINDOW(dialog), "tls_cert_dialog");
+    der_len = i2d_X509(acd->certificate, &der_buf);
+    gcr_cert = gcr_simple_certificate_new(der_buf, der_len);
+    OPENSSL_free(der_buf);
+    cert_widget = GTK_WIDGET(gcr_certificate_widget_new(gcr_cert));
+    g_object_unref(G_OBJECT(gcr_cert));
+
+    str = g_string_new("");
+    g_string_printf(str, _("<big><b>Authenticity of this certificate "
+                           "could not be verified.</b></big>\n"
+                           "Reason: %s"),
+                    acd->explanation);
+    label = gtk_label_new(str->str);
+    g_string_free(str, TRUE);
+    gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
+                       label, FALSE, FALSE, 1);
+    gtk_widget_show(label);
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
+                       cert_widget, TRUE, TRUE, 1);
+    gtk_widget_show(cert_widget);
+
+    switch(gtk_dialog_run(GTK_DIALOG(dialog))) {
+    case 0:
+    	i = 1;
+    	break;
+    case 1:
+    	i = 2;
+    	break;
+    case GTK_RESPONSE_CANCEL:
+    default:
+    	i = 0;
+    	break;
+    }
+    gtk_widget_destroy(dialog);
+    return i;
+}
+
+#else
+
 static int
 ask_cert_real(void *data)
 {
@@ -585,12 +630,12 @@ ask_cert_real(void *data)
     dialog = gtk_dialog_new_with_buttons(_("SSL/TLS certificate"),
                                          NULL, /* FIXME: NULL parent */
                                          GTK_DIALOG_MODAL |
-                                         GTK_DIALOG_USE_HEADER_BAR,
+                                         libbalsa_dialog_flags(),
                                          _("_Accept Once"), 0,
-                                         _("Accept&_Save"), 1,
+                                         _("Accept & _Save"), 1,
                                          _("_Reject"), GTK_RESPONSE_CANCEL, 
                                          NULL);
-    gtk_window_set_wmclass(GTK_WINDOW(dialog), "tls_cert_dialog", "Balsa");
+    gtk_window_set_role(GTK_WINDOW(dialog), "tls_cert_dialog");
     label = gtk_label_new(str->str);
     g_string_free(str, TRUE);
     gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
@@ -614,6 +659,8 @@ ask_cert_real(void *data)
     return i;
 }
 
+#endif	/* HAVE_GCR */
+
 static int
 libbalsa_ask_for_cert_acceptance(X509 *cert, const char *explanation)
 {
@@ -622,7 +669,6 @@ libbalsa_ask_for_cert_acceptance(X509 *cert, const char *explanation)
     acd.explanation = explanation;
     return libbalsa_ask(ask_cert_real, &acd);
 }
-#endif /* WITH_SSL */
 
 
 static int
@@ -638,7 +684,7 @@ ask_timeout_real(void *data)
                                     GTK_BUTTONS_YES_NO,
                                     _("Connection to %s timed out. Abort?"),
                                     host);
-    gtk_window_set_wmclass(GTK_WINDOW(dialog), "timeout_dialog", "Balsa");
+    gtk_window_set_role(GTK_WINDOW(dialog), "timeout_dialog");
     switch(gtk_dialog_run(GTK_DIALOG(dialog))) {
     case GTK_RESPONSE_YES: i = 1; break;
     case GTK_RESPONSE_NO: i = 0; break;
@@ -667,8 +713,7 @@ libbalsa_abort_on_timeout(const char *host)
 }
 
 
-#ifdef BALSA_USE_THREADS
-pthread_t
+GThread *
 libbalsa_get_main_thread(void)
 {
     return main_thread_id;
@@ -677,14 +722,13 @@ libbalsa_get_main_thread(void)
 gboolean
 libbalsa_am_i_subthread(void)
 {
-    return pthread_self() != main_thread_id;
+    return g_thread_self() != main_thread_id;
 }
-#endif /* BALSA_USE_THREADS */
 
-#ifdef BALSA_USE_THREADS
+
 #include "libbalsa_private.h"	/* for prototypes */
-static pthread_mutex_t mailbox_mutex = PTHREAD_MUTEX_INITIALIZER;
-static pthread_cond_t  mailbox_cond  = PTHREAD_COND_INITIALIZER;
+static GMutex mailbox_mutex;
+static GCond  mailbox_cond;
 
 /* Lock/unlock a mailbox; no argument checking--we'll assume the caller
  * took care of that. 
@@ -693,13 +737,13 @@ static pthread_cond_t  mailbox_cond  = PTHREAD_COND_INITIALIZER;
 void
 libbalsa_lock_mailbox(LibBalsaMailbox * mailbox)
 {
-    pthread_t thread_id = pthread_self();
+	GThread *thread_id = g_thread_self();
 
-    pthread_mutex_lock(&mailbox_mutex);
+    g_mutex_lock(&mailbox_mutex);
 
     if (mailbox->thread_id && mailbox->thread_id != thread_id)
         while (mailbox->lock)
-            pthread_cond_wait(&mailbox_cond, &mailbox_mutex);
+            g_cond_wait(&mailbox_cond, &mailbox_mutex);
 
     /* We'll assume that no-one would destroy a mailbox while we've been
      * trying to lock it. If they have, we have larger problems than
@@ -707,33 +751,32 @@ libbalsa_lock_mailbox(LibBalsaMailbox * mailbox)
     mailbox->lock++;
     mailbox->thread_id = thread_id;
 
-    pthread_mutex_unlock(&mailbox_mutex);
+    g_mutex_unlock(&mailbox_mutex);
 }
 
 void
 libbalsa_unlock_mailbox(LibBalsaMailbox * mailbox)
 {
-    pthread_t self;
+	GThread *self;
 
-    self = pthread_self();
+    self = g_thread_self();
 
-    pthread_mutex_lock(&mailbox_mutex);
+    g_mutex_lock(&mailbox_mutex);
 
     if (mailbox->lock == 0 || self != mailbox->thread_id) {
 	g_warning("Not holding mailbox lock!!!");
-        pthread_mutex_unlock(&mailbox_mutex);
+        g_mutex_unlock(&mailbox_mutex);
 	return;
     }
 
     if(--mailbox->lock == 0) {
         mailbox->thread_id = 0;
-        pthread_cond_broadcast(&mailbox_cond);
+        g_cond_broadcast(&mailbox_cond);
     }
 
-    pthread_mutex_unlock(&mailbox_mutex);
+    g_mutex_unlock(&mailbox_mutex);
 }
 
-#endif				/* BALSA_USE_THREADS */
 
 /* Initialized by the front end. */
 void (*libbalsa_progress_set_text) (LibBalsaProgress * progress,
@@ -901,7 +944,7 @@ libbalsa_source_view_new(gboolean highlight_phrases)
 	    lm_rpaths = g_new0(gchar *, n + 2);
 	    for (n = 0; lm_dpaths[n]; n++)
 		lm_rpaths[n] = g_strdup(lm_dpaths[n]);
-	    lm_rpaths[n] = g_strdup(BALSA_DATA_PREFIX "/gtksourceview-2.0");
+	    lm_rpaths[n] = g_strdup(BALSA_DATA_PREFIX "/gtksourceview-3.0");
 	    gtk_source_language_manager_set_search_path(lm, lm_rpaths);
 	    g_strfreev(lm_rpaths);
 
@@ -911,7 +954,7 @@ libbalsa_source_view_new(gboolean highlight_phrases)
 		GtkSourceStyleSchemeManager *smgr =
 		    gtk_source_style_scheme_manager_new();
 		gchar * sm_paths[] = {
-		    BALSA_DATA_PREFIX "/gtksourceview-2.0",
+		    BALSA_DATA_PREFIX "/gtksourceview-3.0",
 		    NULL };
 	    
 		/* try to load the colouring scheme */
@@ -968,3 +1011,23 @@ libbalsa_image_error_quark(void)
         quark = g_quark_from_static_string("libbalsa-image-error-quark");
     return quark;
 }
+
+#if GTK_CHECK_VERSION(3, 12, 0)
+GtkDialogFlags
+libbalsa_dialog_flags(void)
+{
+	static GtkDialogFlags dialog_flags = GTK_DIALOG_USE_HEADER_BAR;
+	static gint check_done = 0;
+
+	if (g_atomic_int_get(&check_done) == 0) {
+		const gchar *dialog_env;
+
+		dialog_env = g_getenv("BALSA_DIALOG_HEADERBAR");
+		if ((dialog_env != NULL) && (atoi(dialog_env) == 0)) {
+			dialog_flags = (GtkDialogFlags) 0;
+		}
+		g_atomic_int_set(&check_done, 1);
+	}
+	return dialog_flags;
+}
+#endif
