@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __LIBBALSA_H__
@@ -42,6 +40,7 @@ typedef struct _LibBalsaSmtpServer LibBalsaSmtpServer;
 typedef struct _LibbalsaVfs LibbalsaVfs;
 
 
+#include <openssl/ssl.h>
 #include "message.h"
 #include "body.h"
 #include "files.h"
@@ -63,6 +62,9 @@ typedef struct _LibbalsaVfs LibbalsaVfs;
 #if HAVE_RUBRICA
 #include "address-book-rubrica.h"
 #endif
+#if HAVE_OSMO
+#include "address-book-osmo.h"
+#endif
 
 #include "mailbox.h"
 #include "mailbox_local.h"
@@ -129,24 +131,16 @@ gchar *libbalsa_guess_ldap_server(void);
 gchar *libbalsa_guess_imap_inbox(void);
 
 
-gchar* libbalsa_date_to_utf8(const time_t *date, const gchar *date_string);
+gchar* libbalsa_date_to_utf8(time_t date, const gchar *date_string);
 LibBalsaMessageStatus libbalsa_get_icon_from_flags(LibBalsaMessageFlag flags);
 
-#ifdef USE_TLS
-#include <openssl/ssl.h>
 gboolean libbalsa_is_cert_known(X509* cert, long vfy_result);
 void libbalsa_certs_destroy(void);
-#endif
 
 gboolean libbalsa_abort_on_timeout(const char *host);
 
-#ifdef BALSA_USE_THREADS
-#include <pthread.h>
-pthread_t libbalsa_get_main_thread(void);
+GThread *libbalsa_get_main_thread(void);
 gboolean libbalsa_am_i_subthread(void);
-#else
-#define libbalsa_am_i_subthread() FALSE
-#endif /* BALSA_USE_THREADS */
 #if defined(BALSA_DEBUG_THREADS)
 #define gdk_threads_enter()                       \
     do if (libbalsa_am_i_subthread())             \
@@ -157,10 +151,7 @@ gboolean libbalsa_am_i_subthread(void);
 #endif
 #define gdk_threads_leave()
 void libbalsa_message(const char *fmt, ...)
-#ifdef __GNUC__
-    __attribute__ ((format (printf, 1, 2)))
-#endif
-;
+	G_GNUC_PRINTF(1, 2);
 gchar * libbalsa_rot(const gchar * pass);
 
 typedef enum {
@@ -210,6 +201,12 @@ enum LibBalsaImageError {
 #endif                          /* HAVE_COMPFACE */
 };
 
+#if GTK_CHECK_VERSION(3, 12, 0)
+GtkDialogFlags libbalsa_dialog_flags(void);
+#else
+#define libbalsa_dialog_flags()		(GtkDialogFlags) (0)
+#endif
+
 #if HAVE_GTKSOURCEVIEW
 GtkWidget *libbalsa_source_view_new(gboolean highlight_phrases);
 #endif                          /* HAVE_GTKSOURCEVIEW */
