@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -563,7 +561,7 @@ lbm_local_save_tree(LibBalsaMailboxLocal * local)
                              save_info.array->len *
                              sizeof(LibBalsaMailboxLocalTreeInfo), &err)) {
         libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                             _("Failed to save cache file \"%s\": %s."),
+                             _("Failed to save cache file “%s”: %s."),
                              filename, err->message);
         g_error_free(err);
     }
@@ -720,15 +718,7 @@ lbm_local_save_tree_real(LibBalsaMailboxLocal * local)
 static gboolean
 lbm_local_save_tree_idle(LibBalsaMailboxLocal * local)
 {
-#if 0 && defined(BALSA_USE_THREADS)
-    pthread_t save_tree_thread;
-
-    pthread_create(&save_tree_thread, NULL,
-                   (void *) lbm_local_save_tree_real, local);
-    pthread_detach(save_tree_thread);
-#else                           /* BALSA_USE_THREADS */
     lbm_local_save_tree_real(local);
-#endif                          /* BALSA_USE_THREADS */
 
     return FALSE;
 }
@@ -856,10 +846,8 @@ message_match_real(LibBalsaMailbox *mailbox, guint msgno,
         info  = g_ptr_array_index(local->threading_info, msgno - 1);
     }
 
-#if defined(BALSA_USE_THREADS)
     if (entry->idle_pending)
         return FALSE;   /* Can't match. */
-#endif                  /* defined(BALSA_USE_THREADS) */
 
     switch (cond->type) {
     case CONDITION_STRING:
@@ -1143,7 +1131,6 @@ lbml_set_threading(LibBalsaMailbox * mailbox,
     }
 }
 
-#ifdef BALSA_USE_THREADS
 typedef struct {
     LibBalsaMailbox *mailbox;
     LibBalsaMailboxThreadingType thread_type;
@@ -1157,7 +1144,6 @@ lbml_set_threading_idle_cb(LbmlSetThreadingInfo * info)
     g_slice_free(LbmlSetThreadingInfo, info);
     return FALSE;
 }
-#endif                          /* BALSA_USE_THREADS */
 
 static void
 libbalsa_mailbox_local_set_threading(LibBalsaMailbox * mailbox,
@@ -1201,7 +1187,6 @@ libbalsa_mailbox_local_set_threading(LibBalsaMailbox * mailbox,
             return;
     }
 
-#ifdef BALSA_USE_THREADS
     if (libbalsa_am_i_subthread()) {
         LbmlSetThreadingInfo *info;
 
@@ -1214,9 +1199,6 @@ libbalsa_mailbox_local_set_threading(LibBalsaMailbox * mailbox,
         lbml_set_threading(mailbox, thread_type);
         gdk_threads_leave();
     }
-#else                           /* BALSA_USE_THREADS */
-    lbml_set_threading(mailbox, thread_type);
-#endif                          /* BALSA_USE_THREADS */
 #if defined(DEBUG_LOADING_AND_THREADING)
     printf("after threading time=%lu\n", (unsigned long) time(NULL));
 #endif
@@ -1860,13 +1842,17 @@ lbml_subject_gather(GNode * node, ThreadingInfo * ti)
     old = g_hash_table_lookup(subject_table, chopped_subject);
 #ifdef MAKE_EMPTY_CONTAINER_FOR_MISSING_PARENT
     if (old == NULL || (node->data == NULL && old->data != NULL)) {
-#else				/* MAKE_EMPTY_CONTAINER_FOR_MISSING_PARENT */
-    if (old == NULL) {
-#endif				/* MAKE_EMPTY_CONTAINER_FOR_MISSING_PARENT */
 	g_hash_table_insert(subject_table, (char *) chopped_subject,
 			    node);
 	return;
     }
+#else				/* MAKE_EMPTY_CONTAINER_FOR_MISSING_PARENT */
+    if (old == NULL) {
+	g_hash_table_insert(subject_table, (char *) chopped_subject,
+			    node);
+	return;
+    }
+#endif				/* MAKE_EMPTY_CONTAINER_FOR_MISSING_PARENT */
 
     old_subject = lbml_get_subject(old, ti);
 
@@ -2164,7 +2150,7 @@ lbm_local_sync_real(LibBalsaMailboxLocal * local)
         MAILBOX_OPEN(mailbox) &&                   /* mailbox still open */
         !libbalsa_mailbox_sync_storage(mailbox, FALSE))   /* cannot sync */
 	libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-			     _("Failed to sync mailbox \"%s\""),
+			     _("Failed to sync mailbox “%s”"),
 			     mailbox->name);
     local->sync_id = 0;
     local->sync_time += time(NULL)-tstart;
@@ -2176,14 +2162,11 @@ lbm_local_sync_real(LibBalsaMailboxLocal * local)
 static gboolean
 lbm_local_sync_idle(LibBalsaMailboxLocal * local)
 {
-#if defined(BALSA_USE_THREADS)
-    pthread_t sync_thread;
+    GThread *sync_thread;
 
-    pthread_create(&sync_thread, NULL, (void *) lbm_local_sync_real, local);
-    pthread_detach(sync_thread);
-#else                           /*BALSA_USE_THREADS */
-    lbm_local_sync_real(local);
-#endif                          /*BALSA_USE_THREADS */
+    sync_thread =
+    	g_thread_new("lbm_local_sync_real", (GThreadFunc) lbm_local_sync_real, local);
+    g_thread_unref(sync_thread);
 
     return FALSE;
 }
