@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -199,7 +197,7 @@ lbm_maildir_check_files(const gchar * path, gboolean create)
 
         if (mkdir(path, S_IRWXU)) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                                 _("Could not create a MailDir directory at %s (%s)"),
+                                 _("Could not create a Maildir directory at %s (%s)"),
                                  path, strerror(errno));
             return -1;
         }
@@ -207,7 +205,7 @@ lbm_maildir_check_files(const gchar * path, gboolean create)
         snprintf(tmp, sizeof(tmp), "%s/cur", path);
         if (mkdir(tmp, S_IRWXU)) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                                 _("Could not create a MailDir at %s (%s)"),
+                                 _("Could not create a Maildir at %s (%s)"),
                                  path, strerror(errno));
             rmdir(path);
             return -1;
@@ -216,7 +214,7 @@ lbm_maildir_check_files(const gchar * path, gboolean create)
         snprintf(tmp, sizeof(tmp), "%s/new", path);
         if (mkdir(tmp, S_IRWXU)) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                                 _("Could not create a MailDir at %s (%s)"),
+                                 _("Could not create a Maildir at %s (%s)"),
                                  path, strerror(errno));
             snprintf(tmp, sizeof(tmp), "%s/cur", path);
             rmdir(tmp);
@@ -227,7 +225,7 @@ lbm_maildir_check_files(const gchar * path, gboolean create)
         snprintf(tmp, sizeof(tmp), "%s/tmp", path);
         if (mkdir(tmp, S_IRWXU)) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                                 _("Could not create a MailDir at %s (%s)"),
+                                 _("Could not create a Maildir at %s (%s)"),
                                  path, strerror(errno));
             snprintf(tmp, sizeof(tmp), "%s/cur", path);
             rmdir(tmp);
@@ -427,7 +425,7 @@ static void lbm_maildir_parse(LibBalsaMailboxMaildir * mdir,
 	    if (FLAGS_REALLY_DIFFER(msg_info->orig_flags, flags)) {
 #undef DEBUG /* #define DEBUG TRUE */
 #ifdef DEBUG
-		g_message("Message flags for \"%s\" changed\n",
+		g_message("Message flags for “%s” changed\n",
                           msg_info->key);
 #endif
 		msg_info->orig_flags = flags;
@@ -709,7 +707,7 @@ maildir_sync_add(struct message_info *msg_info, const gchar * path)
     if (strcmp(orig, new)) {
         while (g_file_test(new, G_FILE_TEST_EXISTS)) {
 #ifdef DEBUG
-	    g_message("File \"%s\" exists, requesting new key.\n", new);
+	    g_message("File “%s” exists, requesting new key.\n", new);
 #endif
             g_free(msg_info->key);
             msg_info->key = lbm_mdir_get_key();
@@ -724,7 +722,7 @@ maildir_sync_add(struct message_info *msg_info, const gchar * path)
 	    msg_info->subdir = subdir;
 	else {
 #ifdef DEBUG
-            g_message("Rename \"%s\" \"%s\": %s\n", orig, new,
+            g_message("Rename “%s” “%s”: %s\n", orig, new,
                       g_strerror(errno));
 #endif
 	    retval = FALSE;
