@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -36,9 +34,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-/* we include time because pthread.h may require it when compiled with c89 */
-#include <time.h>
-
 #include "libbalsa.h"
 #include "libbalsa_private.h"
 #include "misc.h"
@@ -98,10 +93,8 @@ libbalsa_mailbox_mbox_fetch_message_structure(LibBalsaMailbox * mailbox,
                                               LibBalsaFetchFlag flags);
 static guint
 libbalsa_mailbox_mbox_total_messages(LibBalsaMailbox * mailbox);
-#if BALSA_USE_THREADS
 static void libbalsa_mailbox_mbox_lock_store(LibBalsaMailbox * mailbox,
                                              gboolean lock);
-#endif                          /* BALSA_USE_THREADS */
 
 struct _LibBalsaMailboxMboxClass {
     LibBalsaMailboxLocalClass klass;
@@ -112,7 +105,7 @@ struct _LibBalsaMailboxMbox {
 
     GPtrArray *msgno_2_msg_info;
     GMimeStream *gmime_stream;
-    gint size;
+    off_t size;
     gboolean messages_info_changed;
 };
 
@@ -168,9 +161,7 @@ libbalsa_mailbox_mbox_class_init(LibBalsaMailboxMboxClass * klass)
 	libbalsa_mailbox_mbox_fetch_message_structure;
     libbalsa_mailbox_class->total_messages =
 	libbalsa_mailbox_mbox_total_messages;
-#if BALSA_USE_THREADS
     libbalsa_mailbox_class->lock_store = libbalsa_mailbox_mbox_lock_store;
-#endif                          /* BALSA_USE_THREADS */
 
     libbalsa_mailbox_local_class->check_files  = lbm_mbox_check_files;
     libbalsa_mailbox_local_class->remove_files = 
@@ -205,7 +196,7 @@ lbm_mbox_check_files(const gchar * path, gboolean create)
         if (libbalsa_mailbox_type_from_path(path) !=
             LIBBALSA_TYPE_MAILBOX_MBOX) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                                 _("Mailbox %s does not appear to be an Mbox mailbox."),
+                                 _("Mailbox %s does not appear to be an mbox mailbox."),
                                  path);
             return -1;
         }
@@ -214,7 +205,7 @@ lbm_mbox_check_files(const gchar * path, gboolean create)
 
         if ((fd = creat(path, S_IRUSR | S_IWUSR)) == -1) {
             g_warning("An error:\n%s\n occurred while trying to "
-                      "create the mailbox \"%s\"\n",
+                      "create the mailbox “%s”\n",
                       strerror(errno), path);
             return -1;
         } else
@@ -261,7 +252,7 @@ lbm_mbox_stream_seek_to_message(GMimeStream * stream, off_t offset)
             --nread;
         buffer[nread] = 0;
 #if DEBUG_SEEK
-        g_print("%s at %ld failed: read %ld chars, saw \"%s\"\n", __func__,
+        g_print("%s at %ld failed: read %ld chars, saw “%s”\n", __func__,
                 (long) offset, (long) nread, buffer);
 #endif
     }
@@ -436,7 +427,7 @@ lbm_mbox_save(LibBalsaMailboxMbox * mbox)
             (ssize_t) messages_info->len) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
                                  _("Failed to create temporary file "
-                                   "\"%s\": %s"), template,
+                                   "“%s”: %s"), template,
                                  strerror(errno));
             g_free(template);
             g_free(filename);
@@ -447,8 +438,8 @@ lbm_mbox_save(LibBalsaMailboxMbox * mbox)
             || (unlink(filename) != 0 && errno != ENOENT)
             || libbalsa_safe_rename(template, filename) != 0)
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                                 _("Failed to save cache file \"%s\": %s.  "
-                                   "New version saved as \"%s\""),
+                                 _("Failed to save cache file “%s”: %s. "
+                                   "New version saved as “%s”"),
                                  filename, strerror(errno), template);
         g_free(template);
 #endif                          /* !defined(__APPLE__) */
@@ -919,10 +910,10 @@ lbm_mbox_check_file(LibBalsaMailboxMbox * mbox,
 
         if (content_length) {
             /* Seek past the content. */
-            ssize_t remaining;
+            off_t remaining;
 
             buffer->start += content_length;
-            remaining = buffer->end - buffer->start;
+            remaining = (off_t) buffer->end - (off_t) buffer->start;
             if (remaining < 0) {
                 g_mime_stream_seek(buffer->stream, -remaining,
                                    GMIME_STREAM_SEEK_CUR);
@@ -1165,15 +1156,19 @@ static gint
 lbm_mbox_newline(GMimeStream * stream)
 {
     gint retval;
-    gchar buf[1];
-    static gchar newlines[] = "\n\n";
+    static const gchar newlines[] = "\n\n";
 
-    retval = g_mime_stream_seek(stream, -1, GMIME_STREAM_SEEK_CUR);
-    if (retval >= 0)
-	retval = g_mime_stream_read(stream, buf, 1);
-    if (retval == 1)
-	retval =
-	    g_mime_stream_write(stream, newlines, buf[0] == '\n' ? 1 : 2);
+    if (g_mime_stream_seek(stream, -1, GMIME_STREAM_SEEK_CUR) < 0) {
+    	retval = -1;
+    } else {
+        gchar buf;
+
+    	retval = g_mime_stream_read(stream, &buf, 1);
+    	if (retval == 1) {
+    		retval =
+    			g_mime_stream_write(stream, newlines, buf == '\n' ? 1 : 2);
+    	}
+    }
 
     return retval;
 }
@@ -1487,7 +1482,7 @@ libbalsa_mailbox_mbox_sync(LibBalsaMailbox * mailbox, gboolean expunge)
 	if (g_mime_stream_flush(mbox_stream) < 0)
 	    g_warning("can't flush mailbox stream\n");
 	if (fstat(GMIME_STREAM_FS(mbox_stream)->fd, &st))
-	    g_warning("can't stat \"%s\"", path);
+	    g_warning("can't stat “%s”", path);
 	else
             libbalsa_mailbox_set_mtime(mailbox, st.st_mtime);
         lbm_mbox_save(mbox);
@@ -1839,57 +1834,6 @@ static void update_message_status_headers(GMimeMessage *message,
     g_string_free(new_header, TRUE);
 }
 
-#if !defined(HAVE_GMIME_2_6)
-/*
- * Encode text parts as quoted-printable.
- */
-static void
-lbm_mbox_prepare_object(GMimeObject * object)
-{
-    g_mime_object_remove_header(object, "Content-Length");
-
-    if (GMIME_IS_MULTIPART(object)) {
-        /* Do not break crypto */
-        if (!(GMIME_IS_MULTIPART_SIGNED(object) ||
-              GMIME_IS_MULTIPART_ENCRYPTED(object))) {
-            GMimeMultipart *multipart = (GMimeMultipart *) object;
-            gint i, count = g_mime_multipart_get_count(multipart);
-
-            for (i = 0; i < count; ++i)
-                lbm_mbox_prepare_object(g_mime_multipart_get_part
-                                        (multipart, i));
-        }
-    } else if (GMIME_IS_MESSAGE_PART(object))
-        lbm_mbox_prepare_object(GMIME_OBJECT
-                                (((GMimeMessagePart *) object)->message));
-    else if (GMIME_IS_MESSAGE(object))
-        lbm_mbox_prepare_object(((GMimeMessage *) object)->mime_part);
-    else if (GMIME_IS_PART(object)) {
-        GMimePart *mime_part = (GMimePart *) object;
-        GMimeContentEncoding encoding;
-        GMimeContentType *mime_type;
-
-        if (GMIME_IS_MESSAGE_PARTIAL(mime_part))
-            return;
-
-        encoding = g_mime_part_get_content_encoding(mime_part);
-        if (encoding == GMIME_CONTENT_ENCODING_BASE64)
-            return;
-
-        mime_type = g_mime_object_get_content_type(object);
-        if (g_mime_content_type_is_type(mime_type, "text", "plain")) {
-            const gchar *format =
-                g_mime_content_type_get_parameter(mime_type, "format");
-            if (format && !g_ascii_strcasecmp(format, "flowed"))
-                /* Format=Flowed text cannot contain From_ lines. */
-                return;
-        }
-
-        g_mime_part_set_content_encoding
-            (mime_part, GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE);
-    }
-}
-#endif                          /* defined(HAVE_GMIME_2_6) */
 
 static GMimeObject *
 lbm_mbox_armored_object(GMimeStream * stream)
@@ -1900,12 +1844,7 @@ lbm_mbox_armored_object(GMimeStream * stream)
     parser = g_mime_parser_new_with_stream(stream);
     object = GMIME_OBJECT(g_mime_parser_construct_message(parser));
     g_object_unref(parser);
-
-#if defined(HAVE_GMIME_2_6)
     g_mime_object_encode(object, GMIME_ENCODING_CONSTRAINT_7BIT);
-#else                           /* defined(HAVE_GMIME_2_6) */
-    lbm_mbox_prepare_object(object);
-#endif                          /* defined(HAVE_GMIME_2_6) */
 
     return object;
 }
@@ -1949,7 +1888,7 @@ lbm_mbox_add_message(LibBalsaMailboxLocal * local,
     GMimeObject *armored_object;
     GMimeStream *armored_dest;
     GMimeStream *dest;
-    gint retval;
+    off_t retval;
     off_t orig_length;
 
     message = libbalsa_message_new();
@@ -1994,7 +1933,7 @@ lbm_mbox_add_message(LibBalsaMailboxLocal * local,
 	g_free(from);
         g_set_error(err, LIBBALSA_MAILBOX_ERROR,
                     LIBBALSA_MAILBOX_APPEND_ERROR,
-                    _("%s: could not get new mime stream."),
+                    _("%s: could not get new MIME stream."),
                     "MBOX");
 	return FALSE;
     }
@@ -2050,7 +1989,6 @@ libbalsa_mailbox_mbox_total_messages(LibBalsaMailbox * mailbox)
     return mbox->msgno_2_msg_info ? mbox->msgno_2_msg_info->len : 0;
 }
 
-#if BALSA_USE_THREADS
 static void
 libbalsa_mailbox_mbox_lock_store(LibBalsaMailbox * mailbox, gboolean lock)
 {
@@ -2062,4 +2000,3 @@ libbalsa_mailbox_mbox_lock_store(LibBalsaMailbox * mailbox, gboolean lock)
     else
         libbalsa_mime_stream_shared_unlock(stream);
 }
-#endif                          /* BALSA_USE_THREADS */
