@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -169,7 +167,7 @@ lbm_mh_check_files(const gchar * path, gboolean create)
         if (libbalsa_mailbox_type_from_path(path) !=
             LIBBALSA_TYPE_MAILBOX_MH) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                                 _("Mailbox %s does not appear to be a Mh mailbox."),
+                                 _("Mailbox %s does not appear to be an MH mailbox."),
                                  path);
             return -1;
         }
@@ -905,7 +903,7 @@ libbalsa_mailbox_mh_sync(LibBalsaMailbox * mailbox, gboolean expunge)
         if (sequences_fd >= 0)
             libbalsa_unlock_file(sequences_filename, sequences_fd, 1);
 #ifdef DEBUG
-        g_print("MH sync \"%s\": cannot open temp file.\n", path);
+        g_print("MH sync “%s”: cannot open temp file.\n", path);
 #endif
 	return retval;
     }
@@ -953,7 +951,7 @@ libbalsa_mailbox_mh_sync(LibBalsaMailbox * mailbox, gboolean expunge)
         if (sequences_fd >= 0)
             libbalsa_unlock_file(sequences_filename, sequences_fd, 1);
 #ifdef DEBUG
-        g_print("MH sync \"%s\": error finishing sequences line.\n", path);
+        g_print("MH sync “%s”: error finishing sequences line.\n", path);
 #endif
 	return retval;
     }
@@ -968,7 +966,7 @@ libbalsa_mailbox_mh_sync(LibBalsaMailbox * mailbox, gboolean expunge)
     retval = (libbalsa_safe_rename(tmp, sequences_filename) != -1);
 #ifdef DEBUG
     if (!retval)
-        g_print("MH sync \"%s\": error renaming sequences file.\n", path);
+        g_print("MH sync “%s”: error renaming sequences file.\n", path);
 #endif
     if (!retval)
 	unlink (tmp);
