@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -543,7 +541,7 @@ libbalsa_mailbox_pop3_check(LibBalsaMailbox * mailbox)
         if(m->msg_size_limit>0 && msg_size >= (unsigned)m->msg_size_limit) {
             libbalsa_information
                 (LIBBALSA_INFORMATION_WARNING,
-                 _("POP3 message %d oversized: %d kB - skipped."),
+                 _("POP3 message %d oversized: %d kB — skipped."),
                  i, msg_size);
             total_size -= msg_size;
             continue;
