@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* DESIGN NOTES.
@@ -614,7 +612,7 @@ libbalsa_message_change_flags(LibBalsaMessage * message,
 
     if (message->mailbox->readonly) {
         libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-                             _("Mailbox (%s) is readonly: "
+                             _("Mailbox (%s) is read-only: "
                                "cannot change flags."),
                              message->mailbox->name);
         return;
@@ -1110,7 +1108,7 @@ lbmsg_set_header(LibBalsaMessage *message, const gchar *name,
         val = g_mime_utils_header_encode_text(tmp);
         g_free(tmp);
 #ifdef DEBUG
-        g_print("%s: non-ascii \"%s\" header \"%s\" encoded as \"%s\"\n",
+        g_print("%s: non-ascii “%s” header “%s” encoded as “%s”\n",
                 __func__, name, value, val);
 #endif /* DEBUG */
         value = val;
