@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __LIBBALSA_MIME_STREAM_SHARED_H__
@@ -27,8 +25,6 @@
 # error "Include config.h before this file."
 #endif
 
-#if BALSA_USE_THREADS
-
 #include <gmime/gmime-stream-fs.h>
 
 #define LIBBALSA_TYPE_MIME_STREAM_SHARED                           \
@@ -62,12 +58,4 @@ GMimeStream *libbalsa_mime_stream_shared_new(int fd);
 void libbalsa_mime_stream_shared_lock  (GMimeStream * stream);
 void libbalsa_mime_stream_shared_unlock(GMimeStream * stream);
 
-#else                           /* BALSA_USE_THREADS */
-
-#define libbalsa_mime_stream_shared_new(fd) g_mime_stream_fs_new(fd)
-#define libbalsa_mime_stream_shared_lock(stream)
-#define libbalsa_mime_stream_shared_unlock(stream)
-
-#endif                          /* BALSA_USE_THREADS */
-
 #endif                          /* __LIBBALSA_MIME_STREAM_SHARED_H__ */
