@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -593,53 +593,53 @@ libbalsa_utf8_strstr(const gchar *s1, const gchar *s2)
 /* The LibBalsaCodeset enum is not used for anything currently, but this
  * list must be the same length, and should probably be kept consistent: */
 LibBalsaCodesetInfo libbalsa_codeset_info[LIBBALSA_NUM_CODESETS] = {
-    {N_("west european"),       /* WEST_EUROPE          */
+    {N_("West European"),       /* WEST_EUROPE          */
      "iso-8859-1", "windows-1252"} ,
-    {N_("east european"),       /* EAST_EUROPE          */
+    {N_("East European"),       /* EAST_EUROPE          */
      "iso-8859-2", "windows-1250"} ,
-    {N_("south european"),      /* SOUTH_EUROPE         */
+    {N_("South European"),      /* SOUTH_EUROPE         */
      "iso-8859-3"} ,
-    {N_("north european"),      /* NORTH_EUROPE         */
+    {N_("North European"),      /* NORTH_EUROPE         */
      "iso-8859-4"} ,
-    {N_("cyrillic"),            /* CYRILLIC             */
+    {N_("Cyrillic"),            /* CYRILLIC             */
      "iso-8859-5", "windows-1251"} ,
-    {N_("arabic"),              /* ARABIC               */
+    {N_("Arabic"),              /* ARABIC               */
      "iso-8859-6", "windows-1256"} ,
-    {N_("greek"),               /* GREEK                */
+    {N_("Greek"),               /* GREEK                */
      "iso-8859-7", "windows-1253"} ,
-    {N_("hebrew"),              /* HEBREW               */
+    {N_("Hebrew"),              /* HEBREW               */
      "iso-8859-8", "windows-1255"} ,
-    {N_("turkish"),             /* TURKISH              */
+    {N_("Turkish"),             /* TURKISH              */
      "iso-8859-9", "windows-1254"} ,
-    {N_("nordic"),              /* NORDIC               */
+    {N_("Nordic"),              /* NORDIC               */
      "iso-8859-10"} ,
-    {N_("thai"),                /* THAI                 */
+    {N_("Thai"),                /* THAI                 */
      "iso-8859-11"} ,
-    {N_("baltic"),              /* BALTIC               */
+    {N_("Baltic"),              /* BALTIC               */
      "iso-8859-13", "windows-1257"} ,
-    {N_("celtic"),              /* CELTIC               */
+    {N_("Celtic"),              /* CELTIC               */
      "iso-8859-14"} ,
-    {N_("west europe (euro)"),  /* WEST_EUROPE_EURO     */
+    {N_("West European (euro)"),  /* WEST_EUROPE_EURO     */
      "iso-8859-15"} ,
-    {N_("russian"),             /* RUSSIAN              */
+    {N_("Russian"),             /* RUSSIAN              */
      "koi-8r"} ,
-    {N_("ukrainian"),           /* UKRAINE              */
+    {N_("Ukrainian"),           /* UKRAINE              */
      "koi-8u"} ,
-    {N_("japanese"),            /* JAPAN                */
+    {N_("Japanese"),            /* JAPAN                */
      "iso-2022-jp"} ,
-    {N_("korean"),              /* KOREA                */
+    {N_("Korean"),              /* KOREA                */
      "euc-kr"} ,
-    {N_("east european"),       /* EAST_EUROPE_WIN      */
+    {N_("East European"),       /* EAST_EUROPE_WIN      */
      "windows-1250"} ,
-    {N_("cyrillic"),            /* CYRILLIC_WIN         */
+    {N_("Cyrillic"),            /* CYRILLIC_WIN         */
      "windows-1251"} ,
-    {N_("greek"),               /* GREEK_WIN            */
+    {N_("Greek"),               /* GREEK_WIN            */
      "windows-1253"} ,
-    {N_("hebrew"),              /* HEBREW_WIN           */
+    {N_("Hebrew"),              /* HEBREW_WIN           */
      "windows-1255"} ,
-    {N_("arabic"),              /* ARABIC_WIN           */
+    {N_("Arabic"),              /* ARABIC_WIN           */
      "windows-1256"} ,
-    {N_("baltic"),              /* BALTIC_WIN           */
+    {N_("Baltic"),              /* BALTIC_WIN           */
      "windows-1257"} ,
 };
 
@@ -963,7 +963,7 @@ libbalsa_lock_file (const char *path, int fd, int excl, int dot, int timeout)
     prev_sb = sb;
  
     libbalsa_information(LIBBALSA_INFORMATION_MESSAGE,
-			 _("Waiting for fcntl lock... %d"), ++attempt);
+			 _("Waiting for fcntl lock… %d"), ++attempt);
     sleep (1);
 }
 #endif /* USE_FCNTL */
@@ -998,7 +998,7 @@ while (flock (fd, (excl ? LOCK_EX : LOCK_SH) | LOCK_NB) == -1)
  
     prev_sb = sb;
  
-    libbalsa_message (_("Waiting for flock attempt... %d"), ++attempt);
+    libbalsa_message (_("Waiting for flock attempt… %d"), ++attempt);
     sleep (1);
 }
 #endif /* USE_FLOCK */
@@ -1355,3 +1355,104 @@ libbalsa_size_to_gchar(guint64 size)
 
     return g_strdup_printf("%" G_GUINT64_FORMAT, size);
 }
+
+/*
+ * libbalsa_font_string_to_css: construct CSS text corresponding to a
+ * PangoFontDescription string.
+ *
+ * font_string: the PangoFontDescription string;
+ * name:        the name of the widget to which the font is to be applied.
+ *
+ * Returns:     a newly allocated string with the CSS text;
+ *              g_free() when no longer needed.
+ */
+
+gchar *
+libbalsa_font_string_to_css(const gchar * font_string,
+                            const gchar * name)
+{
+#if !GTK_CHECK_VERSION(3, 22,0)
+    g_return_val_if_fail(font_string != NULL, NULL);
+    g_return_val_if_fail(name != NULL, NULL);
+
+    return g_strconcat("#", name, " {font:", font_string, "}", NULL);
+#else                           /* !GTK_CHECK_VERSION(3, 22,0) */
+    PangoFontDescription *desc;
+    PangoFontMask mask;
+    GString *string;
+
+    g_return_val_if_fail(font_string != NULL, NULL);
+    g_return_val_if_fail(name != NULL, NULL);
+
+    desc = pango_font_description_from_string(font_string);
+    mask = pango_font_description_get_set_fields(desc);
+
+    string = g_string_new(NULL);
+    g_string_printf(string, "#%s {\n", name);
+
+    if (mask & PANGO_FONT_MASK_FAMILY) {
+        g_string_append_printf(string, "font-family: \"%s\";\n",
+                               pango_font_description_get_family(desc));
+    }
+    if (mask & PANGO_FONT_MASK_STYLE) {
+        PangoStyle style; /* An enum with default values,
+                           * so use it to index the array. */
+        static const gchar *styles[] = {
+            "normal",
+            "oblique",
+            "italic"
+        };
+
+        style = pango_font_description_get_style(desc);
+        g_string_append_printf(string, "font-style: %s;\n", styles[style]);
+    }
+    if (mask & PANGO_FONT_MASK_VARIANT) {
+        PangoVariant variant; /* An enum with default values,
+                               * so use it to index the array. */
+        static const gchar *variants[] = {
+            "normal",
+            "small-caps"
+        };
+
+        variant = pango_font_description_get_variant(desc);
+        g_string_append_printf(string, "font-variant: %s;\n", variants[variant]);
+    }
+    if (mask & PANGO_FONT_MASK_WEIGHT) {
+        PangoWeight weight; /* An enum with weight values, so use the value. */
+
+        weight = pango_font_description_get_weight(desc);
+        g_string_append_printf(string, "font-weight: %d;\n", weight);
+    }
+    if (mask & PANGO_FONT_MASK_STRETCH) {
+        PangoStretch stretch; /* An enum with default values,
+                               * so use it to index the array. */
+        static const gchar *stretches[] = {
+            "ultra-condensed",
+            "extra-condensed",
+            "condensed",
+            "semi-condensed",
+            "normal",
+            "semi-expanded",
+            "expanded",
+            "extra-expanded",
+            "ultra-expanded"
+        };
+
+        stretch = pango_font_description_get_stretch(desc);
+        g_string_append_printf(string, "font-stretch: %s;\n", stretches[stretch]);
+    }
+    if (mask & PANGO_FONT_MASK_SIZE) {
+        gdouble size;
+        const gchar *units;
+
+        size = (gdouble) pango_font_description_get_size(desc) / PANGO_SCALE;
+        units = pango_font_description_get_size_is_absolute(desc) ? "px" : "pt";
+        g_string_append_printf(string, "font-size: %.1f%s;\n", size, units);
+    }
+    g_string_append_c(string, '}');
+
+    pango_font_description_free(desc);
+
+    return g_string_free(string, FALSE);
+#endif                          /* !GTK_CHECK_VERSION(3, 22,0) */
+}
