@@ -3,7 +3,7 @@
 #define __MISSING_H__ 1
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,9 +17,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -33,13 +31,5 @@
 char * ctime_r(const time_t *clock, char *buf);
 #endif
 
-#if (HAVE_DECL_LOCALTIME_R == 0)
-struct tm * localtime_r(const time_t *clock, struct tm *result);
-#endif
-
-#if (HAVE_DECL_GMTIME_R == 0)
-struct tm * gmtime_r(const time_t *clock, struct tm *result);
-#endif
-
 #endif
 
