@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
 # include "config.h"
@@ -43,11 +41,6 @@
 #  include "gmime-application-pkcs7.h"
 #endif
 
-#ifdef BALSA_USE_THREADS
-#  include <pthread.h>
-#  include "misc.h"
-#endif
-
 #if HAVE_MACOSX_DESKTOP
 #  include "macosx-helpers.h"
 #endif
@@ -228,7 +221,7 @@ libbalsa_sign_mime_object(GMimeObject ** content, const gchar * rfc822_for,
 	return FALSE;
     }
 
-    if (g_mime_gpgme_mps_sign(mps, *content, rfc822_for, protocol, parent, error) != 0) {
+    if (!g_mime_gpgme_mps_sign(mps, *content, rfc822_for, protocol, parent, error)) {
 	g_object_unref(mps);
 	return FALSE;
     }
@@ -251,7 +244,7 @@ libbalsa_encrypt_mime_object(GMimeObject ** content, GList * rfc822_for,
 {
     GMimeObject *encrypted_obj = NULL;
     GPtrArray *recipients;
-    int result = -1;
+    gboolean result = FALSE;
 
     /* paranoia checks */
     g_return_val_if_fail(rfc822_for != NULL, FALSE);
@@ -291,14 +284,13 @@ libbalsa_encrypt_mime_object(GMimeObject ** content, GList * rfc822_for,
     g_ptr_array_free(recipients, FALSE);
 
     /* error checking */
-    if (result != 0) {
+    if (!result) {
 	g_object_unref(encrypted_obj);
-	return FALSE;
     } else {
     g_object_unref(G_OBJECT(*content));
     *content = GMIME_OBJECT(encrypted_obj);
-    return TRUE;
     }
+    return result;
 }
 
 
@@ -382,7 +374,7 @@ libbalsa_body_check_signature(LibBalsaMessageBody * body,
     /* check if the body is really a multipart/signed */
     if (!GMIME_IS_MULTIPART_SIGNED(body->mime_part)
         || (g_mime_multipart_get_count
-            (((GMimeMultipart *) body->mime_part))) < 2)
+            (GMIME_MULTIPART(body->mime_part)) < 2))
         return FALSE;
     if (body->parts->next->sig_info)
 	g_object_unref(G_OBJECT(body->parts->next->sig_info));
@@ -390,7 +382,7 @@ libbalsa_body_check_signature(LibBalsaMessageBody * body,
     /* verify the signature */
     libbalsa_mailbox_lock_store(body->message->mailbox);
     result = g_mime_gpgme_mps_verify(GMIME_MULTIPART_SIGNED(body->mime_part), &error);
-    if (!result || result->status != GPG_ERR_NO_ERROR) {
+    if (!result) {
 	if (error) {
 	    libbalsa_information(LIBBALSA_INFORMATION_ERROR, "%s: %s",
 				 _("signature verification failed"),
@@ -515,7 +507,7 @@ libbalsa_rfc2440_sign_encrypt(GMimePart *part, const gchar *sign_for,
 			      GtkWindow *parent, GError **error)
 {
     GPtrArray *recipients;
-    gint result;
+    gboolean result;
 
     /* paranoia checks */
     g_return_val_if_fail(part != NULL, FALSE);
@@ -541,7 +533,7 @@ libbalsa_rfc2440_sign_encrypt(GMimePart *part, const gchar *sign_for,
     /* clean up */
     if (recipients)
 	g_ptr_array_free(recipients, FALSE);
-    return (result == 0) ? TRUE : FALSE;
+    return result;
 }
 
 
@@ -571,7 +563,7 @@ libbalsa_rfc2440_verify(GMimePart * part, GMimeGpgmeSigstat ** sig_info)
 
     /* verify */
     result = g_mime_part_rfc2440_verify(part, &error);
-    if (!result || result->status != GPG_ERR_NO_ERROR) {
+    if (!result) {
 	if (error) {
 	    libbalsa_information(LIBBALSA_INFORMATION_ERROR, "%s: %s",
 				 _("signature verification failed"),
@@ -685,10 +677,14 @@ libbalsa_gpgme_sig_stat_to_gchar(gpgme_error_t stat)
     case GPG_ERR_TRY_AGAIN:
 	return _
 	    ("GnuPG is rebuilding the trust database and is currently unavailable.");
-    default:
-	g_message("stat %d: %s %s", stat, gpgme_strsource(stat), gpgme_strerror(stat));
+    default: {
+	gchar errbuf[4096];		/* should be large enough... */
+
+	gpgme_strerror_r(stat, errbuf, sizeof(errbuf));
+	g_message("stat %d: %s %s", stat, gpgme_strsource(stat), errbuf);
 	return _("An error prevented the signature verification.");
     }
+    }
 }
 
 
@@ -750,10 +746,10 @@ libbalsa_gpgme_sig_protocol_name(gpgme_protocol_t protocol)
 }
 
 static inline void
-append_time_t(GString *str, const gchar *format, time_t *when,
+append_time_t(GString *str, const gchar *format, time_t when,
               const gchar * date_string)
 {
-    if (*when != (time_t) 0) {
+    if (when != (time_t) 0) {
         gchar *tbuf = libbalsa_date_to_utf8(when, date_string);
         g_string_append_printf(str, format, tbuf);
         g_free(tbuf);
@@ -778,7 +774,7 @@ libbalsa_signature_info_to_gchar(GMimeGpgmeSigstat * info,
     g_string_append_printf(msg, _("\nSignature validity: %s"),
 			   libbalsa_gpgme_validity_to_gchar(info->
 							    validity));
-    append_time_t(msg, _("\nSigned on: %s"), &info->sign_time, date_string);
+    append_time_t(msg, _("\nSigned on: %s"), info->sign_time, date_string);
     if (info->protocol == GPGME_PROTOCOL_OpenPGP && info->key)
 	g_string_append_printf(msg, _("\nKey owner trust: %s"),
 			       libbalsa_gpgme_validity_to_gchar_short
@@ -798,7 +794,7 @@ libbalsa_signature_info_to_gchar(GMimeGpgmeSigstat * info,
 
             uid = info->key->uids;
             if (uid->next) {
-        	msg = g_string_append(msg, _("\nUser ID's:"));
+        	msg = g_string_append(msg, _("\nUser IDs:"));
         	lead_text = "\n\342\200\242";
             } else {
         	msg = g_string_append(msg, _("\nUser ID:"));
@@ -842,9 +838,9 @@ libbalsa_signature_info_to_gchar(GMimeGpgmeSigstat * info,
 
             if (subkey) {
         	append_time_t(msg, _("\nSubkey created on: %s"),
-        		      &subkey->timestamp, date_string);
+        		      subkey->timestamp, date_string);
         	append_time_t(msg, _("\nSubkey expires on: %s"),
-        		      &subkey->expires, date_string);
+        		      subkey->expires, date_string);
         	if (subkey->revoked || subkey->expired || subkey->disabled ||
         	    subkey->invalid) {
        GString * attrs = g_string_new("");
