@@ -1,7 +1,7 @@
 /* -*-mode:c; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -33,10 +31,6 @@
 #include <stdlib.h>
 #include <time.h>
 
-#ifdef BALSA_USE_THREADS
-#include <pthread.h>
-#endif
-
 #include <string.h>
 
 #include "libbalsa.h"
@@ -220,9 +214,6 @@ static LibBalsaMsgCreateResult
 libbalsa_fill_msg_queue_item_from_queu(LibBalsaMessage * message,
                                        MessageQueueItem *mqi);
 
-#ifdef BALSA_USE_THREADS
-void balsa_send_thread(MessageQueueItem * first_message);
-
 GtkWidget *send_progress_message = NULL;
 GtkWidget *send_dialog = NULL;
 GtkWidget *send_dialog_bar = NULL;
@@ -252,14 +243,14 @@ ensure_send_progress_dialog(GtkWindow * parent)
 
     if(send_dialog) return;
 
-    send_dialog = gtk_dialog_new_with_buttons(_("Sending Mail..."), 
+    send_dialog = gtk_dialog_new_with_buttons(_("Sending Mail…"), 
                                               parent,
                                               GTK_DIALOG_DESTROY_WITH_PARENT |
-                                              GTK_DIALOG_USE_HEADER_BAR,
+                                              libbalsa_dialog_flags(),
                                               _("_Hide"), GTK_RESPONSE_CLOSE,
                                               NULL);
-    gtk_window_set_wmclass(GTK_WINDOW(send_dialog), "send_dialog", "Balsa");
-    label = gtk_label_new(_("Sending Mail..."));
+    gtk_window_set_role(GTK_WINDOW(send_dialog), "send_dialog");
+    label = gtk_label_new(_("Sending Mail…"));
     content_box =
         GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(send_dialog)));
     gtk_box_pack_start(content_box, label, FALSE, FALSE, 0);
@@ -278,17 +269,6 @@ ensure_send_progress_dialog(GtkWindow * parent)
     /* Progress bar done */
 }
 
-/* define commands for locking and unlocking: it makes deadlock debugging
- * easier. */
-#define send_lock()   pthread_mutex_lock(&send_messages_lock); 
-#define send_unlock() pthread_mutex_unlock(&send_messages_lock);
-
-#else
-#define ensure_send_progress_dialog(parent)
-#define send_lock()   
-#define send_unlock() 
-#endif
-
 static void
 lbs_set_content(GMimePart * mime_part, gchar * content)
 {
@@ -594,6 +574,8 @@ libbalsa_message_cb (void **buf, int *len, void *arg)
 	return NULL;
     }
 
+    /* note: the following calculation works *only* for messages < 2 GB
+     * due to the limited range of int, but this should be safe... */
     *len = g_mime_stream_length(current_message->stream)
 	    - g_mime_stream_tell(current_message->stream);
     ptr = (char *) mem_stream->buffer->data
@@ -662,15 +644,17 @@ lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
     long estimate;
     guint msgno;
     gchar *host_with_port;
-    send_lock();
+    GThread *send_mail;
+
+    g_mutex_lock(&send_messages_lock);
 
     if (!libbalsa_mailbox_open(outbox, NULL)) {
-	send_unlock();
+    	g_mutex_unlock(&send_messages_lock);
 	return FALSE;
     }
     if (!libbalsa_mailbox_total_messages(outbox)) {
 	libbalsa_mailbox_close(outbox, TRUE);
-	send_unlock();
+	g_mutex_unlock(&send_messages_lock);
 	return TRUE;
     }
     /* We create here the progress bar */
@@ -932,19 +916,17 @@ lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
 
     send_message_info=send_message_info_new(outbox, session, debug);
 
-#if defined(BALSA_USE_THREADS)
     sending_threads++;
-    pthread_create(&send_mail, NULL,
-		   (void *) &balsa_send_message_real, send_message_info);
-    /* Detach so we don't need to pthread_join
+    send_mail =
+    	g_thread_new("balsa_send_message_real",
+    				 (GThreadFunc) balsa_send_message_real,
+					 send_message_info);
+    /* Detach so we don't need to g_thread_join
      * This means that all resources will be
      * reclaimed as soon as the thread exits
      */
-    pthread_detach(send_mail);
-    send_unlock();
-#else				/*non-threaded code */
-    balsa_send_message_real(send_message_info);
-#endif
+    g_thread_unref(send_mail);
+    g_mutex_unlock(&send_messages_lock);
     return TRUE;
 }
 
@@ -988,7 +970,7 @@ handle_successful_send(smtp_message_t message, void *be_verbose)
     MessageQueueItem *mqi;
     const smtp_status_t *status;
 
-    send_lock();
+    g_mutex_lock(&send_messages_lock);
     /* Get the app data and decrement the reference count.  Only delete
        structures if refcount reaches zero */
     mqi = smtp_message_get_application_data (message);
@@ -1077,10 +1059,9 @@ handle_successful_send(smtp_message_t message, void *be_verbose)
     }
     if (mqi != NULL && mqi->refcount <= 0)
         msg_queue_item_destroy(mqi);
-    send_unlock();
+    g_mutex_unlock(&send_messages_lock);
 }
 
-#ifdef BALSA_USE_THREADS
 static void
 libbalsa_smtp_event_cb (smtp_session_t session, int event_no, void *arg, ...)
 {
@@ -1169,7 +1150,6 @@ libbalsa_smtp_event_cb (smtp_session_t session, int event_no, void *arg, ...)
 		      NULL, NULL, 0);
         break;
 
-#ifdef USE_TLS
         /* SMTP_TLS related things. Observe that we need to have SSL
 	 * enabled in balsa to properly interpret libesmtp
 	 * messages. */
@@ -1199,53 +1179,9 @@ libbalsa_smtp_event_cb (smtp_session_t session, int event_no, void *arg, ...)
 	*ok = 1;
 	break;
     }
-#endif /* USE_TLS */
     }
     va_end (ap);
 }
-#else /* BALSA: USE_THREADS */
-static void
-libbalsa_smtp_event_cb_serial(smtp_session_t session, int event_no,
-                              void *arg, ...)
-{
-    va_list ap;
-
-    va_start (ap, arg);
-    switch (event_no) {
-#ifdef USE_TLS
-        /* SMTP_TLS related things. Observe that we need to have SSL
-	 * enabled in balsa to properly interpret libesmtp
-	 * messages. */
-    case SMTP_EV_INVALID_PEER_CERTIFICATE: {
-        long vfy_result;
-	SSL  *ssl;
-	X509 *cert;
-        int *ok;
-        vfy_result = va_arg(ap, long); ok = va_arg(ap, int*);
-	ssl = va_arg(ap, SSL*);
-	cert = SSL_get_peer_certificate(ssl);
-	if(cert) {
-	    *ok = libbalsa_is_cert_known(cert, vfy_result);
-	    X509_free(cert);
-	}
-        break;
-    }
-    case SMTP_EV_NO_PEER_CERTIFICATE:
-    case SMTP_EV_WRONG_PEER_CERTIFICATE:
-#if LIBESMTP_1_0_3_AVAILABLE
-    case SMTP_EV_NO_CLIENT_CERTIFICATE:
-#endif
-    {
-	int *ok;
-	ok = va_arg(ap, int*);
-	*ok = 1;
-	break;
-    }
-#endif /* USE_TLS */
-    }
-    va_end (ap);
-}
-#endif /* BALSA_USE_THREADS */
 
 #else /* ESMTP */
 
@@ -1320,20 +1256,8 @@ libbalsa_process_queue(LibBalsaMailbox* outbox, LibBalsaFccboxFinder finder,
 
     send_message_info=send_message_info_new(outbox, finder, debug);
     
-#if 0 && defined(BALSA_USE_THREADS)
-    
-    pthread_create(&send_mail, NULL,
-		   (void *) &balsa_send_message_real, send_message_info);
-    /* Detach so we don't need to pthread_join
-     * This means that all resources will be
-     * reclaimed as soon as the thread exits
-     */
-    pthread_detach(send_mail);
-    
-#else				/*non-threaded code */
-    
     balsa_send_message_real(send_message_info);
-#endif
+
     send_unlock();
     return TRUE;
 }
@@ -1431,7 +1355,6 @@ static guint
 balsa_send_message_real(SendMessageInfo* info)
 {
     gboolean session_started;
-#ifdef BALSA_USE_THREADS
     SendThreadMessage *threadmsg;
 
     /* The event callback is used to write messages to the the progress
@@ -1440,9 +1363,6 @@ balsa_send_message_real(SendMessageInfo* info)
        feedback in non-MT version.
     */
     smtp_set_eventcb (info->session, libbalsa_smtp_event_cb, NULL);
-#else
-    smtp_set_eventcb (info->session, libbalsa_smtp_event_cb_serial, NULL);
-#endif
 
     /* Add a protocol monitor when debugging is enabled. */
     if(info->debug)
@@ -1499,12 +1419,10 @@ balsa_send_message_real(SendMessageInfo* info)
      * gdk_threads_leave();
      */
 
-#ifdef BALSA_USE_THREADS
-    send_lock();
+    g_mutex_lock(&send_messages_lock);
     MSGSENDTHREAD(threadmsg, MSGSENDTHREADFINISHED, "", NULL, NULL, 0);
     sending_threads--;
-    send_unlock();
-#endif
+    g_mutex_unlock(&send_messages_lock);
         
     smtp_destroy_session (info->session);
     send_message_info_destroy(info);	
@@ -1703,32 +1621,21 @@ parse_content_type(const char* content_type)
     return ret;
 }
 
-/* get_tz_offset() returns tz offset in minutes. NOTE: not all hours
-   have 60 seconds! Once in a while they get corrected.  */
-#define MIN_SEC		60		/* seconds in a minute */
-#define	HOUR_MIN	60		/* minutes in an hour */
-#define DAY_MIN		(24 * HOUR_MIN)	/* minutes in a day */
-
-static int
-get_tz_offset(time_t *t)
+/* get_tz_offset() returns tz offset in RFC 5322 format ([-]hhmm) */
+static gint
+get_tz_offset(time_t t)
 {
-    struct tm gmt, lt;
-    int off;
-    gmtime_r(t, &gmt);
-    localtime_r(t, &lt);
+	GTimeZone *local_tz;
+	gint interval;
+	gint32 offset;
+	gint hours;
 
-    off = (lt.tm_hour - gmt.tm_hour) * HOUR_MIN + lt.tm_min - gmt.tm_min;
-    if (lt.tm_year < gmt.tm_year)       off -= DAY_MIN;
-    else if (lt.tm_year > gmt.tm_year)	off += DAY_MIN;
-    else if (lt.tm_yday < gmt.tm_yday)  off -= DAY_MIN;
-    else if (lt.tm_yday > gmt.tm_yday)  off += DAY_MIN;
-
-    /* special case: funny minutes */
-    if (lt.tm_sec <= gmt.tm_sec - MIN_SEC) off -= 1;
-    else if (lt.tm_sec >= gmt.tm_sec + MIN_SEC)	off += 1;
-
-    return (off*100)/60; /* time zone offset in hundreds of hours (funny
-                          * unit required by gmime) */
+	local_tz = g_time_zone_new_local();
+	interval = g_time_zone_find_interval(local_tz, G_TIME_TYPE_UNIVERSAL, t);
+	offset = g_time_zone_get_offset(local_tz, interval);
+	g_time_zone_unref(local_tz);
+	hours = offset / 3600;
+	return (hours * 100) + ((offset - (hours * 3600)) / 60);
 }
 
 static LibBalsaMsgCreateResult
@@ -1827,9 +1734,9 @@ libbalsa_message_create_mime_message(LibBalsaMessage* message, gboolean flow,
 			    "application/octet-stream";
 
 			libbalsa_information(LIBBALSA_INFORMATION_WARNING,
-					     _("Cannot determine charset "
-					       "for text file `%s'; "
-					       "sending as mime type `%s'"),
+					     _("Cannot determine character set "
+					       "for text file “%s”; "
+					       "sending as MIME type “%s”"),
 					     libbalsa_vfs_get_uri_utf8(body->file_uri),
                                              default_type);
 			g_strfreev(mime_type);
@@ -1965,7 +1872,7 @@ libbalsa_message_create_mime_message(LibBalsaMessage* message, gboolean flow,
 				   LIBBALSA_MESSAGE_GET_SUBJECT(message));
 
     g_mime_message_set_date(mime_message, message->headers->date,
-                            get_tz_offset(&message->headers->date));
+                            get_tz_offset(message->headers->date));
 
     if ((ia_list = message->headers->to_list)) {
         InternetAddressList *recipients =
