@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -34,9 +32,7 @@
 #include <gnome-keyring.h>
 #endif                          /* defined(HAVE_LIBSECRET) */
 
-#ifdef USE_TLS
 #include <openssl/err.h>
-#endif
 
 #include "libbalsa.h"
 #include "libbalsa_private.h"
@@ -510,7 +506,6 @@ libbalsa_server_user_cb(ImapUserEventType ue, void *arg, ...)
         break;
     }
     case IME_TLS_VERIFY_ERROR:  {
-#ifdef USE_TLS
         long vfy_result;
         SSL *ssl;
         X509 *cert;
@@ -527,9 +522,6 @@ libbalsa_server_user_cb(ImapUserEventType ue, void *arg, ...)
 	    *ok = libbalsa_is_cert_known(cert, vfy_result);
 	    X509_free(cert);
 	}
-#else
-        g_warning("TLS error with TLS disabled!?");
-#endif
         break;
     }
     case IME_TLS_NO_PEER_CERT: {
