@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -212,9 +210,9 @@ balsa_init_create_to_directory(const gchar * dir, gchar ** complaint)
             if (stat(sofar, &sb) < 0) {
                 if (mkdir(sofar, S_IRUSR | S_IWUSR | S_IXUSR) < 0) {
                     (*complaint) =
-                        g_strdup_printf(_("Couldn't create a directory:"
-                                          " mkdir() failed on pathname \"%s\","
-                                          " with error \"%s\"."),
+                        g_strdup_printf(_("Couldn’t create a directory:"
+                                          " mkdir() failed on pathname “%s”,"
+                                          " with error “%s”."),
                                         sofar, g_strerror(errno));
                     g_free(sofar);
                     return TRUE;
@@ -224,7 +222,7 @@ balsa_init_create_to_directory(const gchar * dir, gchar ** complaint)
             if (!S_ISDIR(sb.st_mode)) {
                 (*complaint) =
                     g_strdup_printf(_
-                                    ("The file with pathname \"%s\" is not a directory."),
+                                    ("The file with pathname “%s” is not a directory."),
                                     sofar);
                 g_free(sofar);
                 return TRUE;
@@ -238,7 +236,7 @@ balsa_init_create_to_directory(const gchar * dir, gchar ** complaint)
         if (mkdir(dir, S_IRUSR | S_IWUSR | S_IXUSR) < 0) {
             (*complaint) =
                 g_strdup_printf(_
-                                ("Couldn't create a directory: mkdir() failed on pathname \"%s\"."),
+                                ("Couldn’t create a directory: mkdir() failed on pathname “%s”."),
                                 dir);
             return TRUE;
         }
@@ -247,7 +245,7 @@ balsa_init_create_to_directory(const gchar * dir, gchar ** complaint)
     if (!S_ISDIR(sb.st_mode)) {
         (*complaint) =
             g_strdup_printf(_
-                            ("The file with pathname \"%s\" is not a directory."),
+                            ("The file with pathname “%s” is not a directory."),
                             dir);
         return TRUE;
     }
