@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,22 +14,18 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __BALSA_DRUID_PAGE_USER_H__
 #define __BALSA_DRUID_PAGE_USER_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif                          /* __cplusplus */
-
 #include <gtk/gtk.h>
 #include "assistant_helper.h"
 #include "assistant_init.h"
 
+G_BEGIN_DECLS
+
 /*
  * Main object structure
  */
@@ -51,9 +47,7 @@ extern "C" {
 #endif
         GtkWidget *name;
         GtkWidget *email;
-#if !defined(ENABLE_TOUCH_UI)
         GtkWidget *localmaildir;
-#endif /* ENABLE_TOUCH_UI */
         EntryMaster emaster;
         EntryData ed0;
         EntryData ed1;
@@ -71,7 +65,6 @@ extern "C" {
  */
     void balsa_druid_page_user(GtkAssistant * druid);
 
-#ifdef __cplusplus
-}
-#endif                          /* __cplusplus */
+G_END_DECLS
+
 #endif
