@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "assistant_page_welcome.h"
@@ -30,11 +28,11 @@ balsa_druid_page_welcome(GtkAssistant * druid)
     static const gchar text[] =
         N_
         ("Before you can send or receive email:\n\n"
-         "-- either you should already have Internet access and an "
+         "• either you should already have Internet access and an "
          "email account, provided by an Internet Service Provider, "
          "and you should have made that Internet connection on your "
          "computer\n\n"
-         "-- or your Network Administrator at your place of "
+         "• or your network administrator at your place of "
          "work/study/similar may have set up your computer to "
          "connect to the network.");
 
