@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -117,9 +115,19 @@ balsa_ab_window_new(gboolean composing, GtkWindow* parent)
 {
     GtkWidget *ret;
     BalsaAbWindow *ab;
+    gint use_headerbar = 1;
+#if GTK_CHECK_VERSION(3, 12, 0)
+	const gchar *dialog_env;
+
+    /* header bar configuration */
+	dialog_env = g_getenv("BALSA_DIALOG_HEADERBAR");
+	if ((dialog_env != NULL) && (atoi(dialog_env) == 0)) {
+		use_headerbar = 0;
+	}
+#endif
 
     ret = g_object_new(BALSA_TYPE_AB_WINDOW,
-                       "use-header-bar", TRUE,
+                       "use-header-bar", use_headerbar,
                        "transient-for", parent,
                        NULL);
     g_return_val_if_fail(ret != NULL, NULL);
@@ -181,7 +189,7 @@ balsa_ab_window_list(BalsaAbWindow * ab, GCallback row_activated_cb)
 
     renderer = gtk_cell_renderer_text_new();
     column =
-        gtk_tree_view_column_new_with_attributes(_("E-Mail Address"),
+        gtk_tree_view_column_new_with_attributes(_("Email Address"),
                                                  renderer,
                                                  "text",
                                                  LIST_COLUMN_ADDRESS_STRING,
@@ -239,7 +247,7 @@ balsa_ab_window_init(BalsaAbWindow *ab)
 
     vbox = gtk_dialog_get_content_area(GTK_DIALOG(ab));
 
-    gtk_window_set_wmclass(GTK_WINDOW(ab), "addressbook", "Balsa");
+    gtk_window_set_role(GTK_WINDOW(ab), "addressbook");
 
     /* hig defaults */
     gtk_container_set_border_width(GTK_CONTAINER(ab), 6);
@@ -321,7 +329,7 @@ balsa_ab_window_init(BalsaAbWindow *ab)
     gtk_container_add(GTK_CONTAINER(hbox), w);
     gtk_widget_show(GTK_WIDGET(w));
 
-    w = gtk_button_new_with_mnemonic(_("_Re-Import"));
+    w = gtk_button_new_with_mnemonic(_("_Re-import"));
     g_signal_connect(G_OBJECT(w), "clicked",
                      G_CALLBACK(balsa_ab_window_reload),
 		       ab);
@@ -719,7 +727,7 @@ balsa_ab_window_load(BalsaAbWindow *ab)
 	    libbalsa_address_book_strerror(ab->current_address_book, err);
         balsa_information_parented(GTK_WINDOW(ab),
 				   LIBBALSA_INFORMATION_ERROR,
-				   _("Error opening address book '%s':\n%s"),
+				   _("Error opening address book “%s”:\n%s"),
 				   ab->current_address_book->name, desc);
     }
     balsa_ab_window_set_title(ab);
