@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -80,6 +78,9 @@ static GtkWidget *create_gpe_dialog(AddressBookConfig * abc);
 #ifdef HAVE_RUBRICA
 static GtkWidget *create_rubrica_dialog(AddressBookConfig * abc);
 #endif
+#ifdef HAVE_OSMO
+static GtkWidget *create_osmo_dialog(AddressBookConfig *abc);
+#endif
 
 static void help_button_cb(AddressBookConfig * abc);
 static gboolean handle_close(AddressBookConfig * abc);
@@ -163,7 +164,6 @@ edit_book_response(GtkWidget * dialog, gint response,
     gtk_widget_destroy(dialog);
     if (abc->address_book)
         g_object_set_data(G_OBJECT(abc->address_book), "balsa-abc", NULL);
-    g_free(abc);
 }
 
 /* Radio buttons */
@@ -305,6 +305,10 @@ create_dialog_from_type(AddressBookConfig * abc)
 #ifdef HAVE_RUBRICA
     } else if (abc->type == LIBBALSA_TYPE_ADDRESS_BOOK_RUBRICA) {
         return create_rubrica_dialog(abc);
+#endif
+#ifdef HAVE_OSMO
+    } else if (abc->type == LIBBALSA_TYPE_ADDRESS_BOOK_OSMO) {
+    	return create_osmo_dialog(abc);
 #endif
     } else {
         g_assert_not_reached();
@@ -332,7 +336,7 @@ create_generic_dialog(AddressBookConfig * abc, const gchar * type)
 
     dialog =
         gtk_dialog_new_with_buttons(title, abc->parent,
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Help"), GTK_RESPONSE_HELP,
                                     action, GTK_RESPONSE_APPLY,
                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
@@ -351,6 +355,60 @@ create_generic_dialog(AddressBookConfig * abc, const gchar * type)
     return dialog;
 }
 
+#ifdef HAVE_OSMO
+static GtkWidget *
+create_osmo_dialog(AddressBookConfig *abc)
+{
+    GtkWidget *dialog;
+    GtkWidget *content_area;
+    gchar *title;
+    const gchar *action;
+    const gchar *name;
+    GtkWidget *grid;
+    GtkWidget *label;
+    LibBalsaAddressBook *ab;
+    GtkSizeGroup *size_group;
+
+    ab = abc->address_book;
+    if (ab) {
+        title = g_strdup_printf(_("Modify Osmo Address Book"));
+        action = _("_Apply");
+        name = ab->name;
+    } else {
+        title = g_strdup_printf(_("Add Osmo Address Book"));
+        action = _("_Add");
+        name = NULL;
+    }
+
+    dialog =
+        gtk_dialog_new_with_buttons(title, abc->parent,
+                                    libbalsa_dialog_flags(),
+                                    _("_Help"), GTK_RESPONSE_HELP,
+                                    action, GTK_RESPONSE_APPLY,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                    NULL);
+    g_free(title);
+#if HAVE_MACOSX_DESKTOP
+    libbalsa_macosx_menu_for_parent(dialog, abc->parent);
+#endif
+    size_group = libbalsa_create_size_group(dialog);
+
+    grid = libbalsa_create_grid();
+    content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+    gtk_container_add(GTK_CONTAINER(content_area), grid);
+    gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(dialog), grid);
+    label = libbalsa_create_grid_label(_("A_ddress Book Name:"), grid, 0);
+    gtk_size_group_add_widget(size_group, label);
+    abc->name_entry =
+        libbalsa_create_grid_entry(grid, NULL, NULL, 0, name, label);
+    add_radio_buttons(grid, 1, abc);
+    g_signal_connect(G_OBJECT(dialog), "response",
+                     G_CALLBACK(edit_book_response), abc);
+
+    return dialog;
+}
+#endif /* HAVE_OSMO */
+
 static GtkWidget *
 create_externq_dialog(AddressBookConfig * abc)
 {
@@ -610,7 +668,7 @@ bad_path(gchar * path, GtkWindow * window, gint type)
 				 GTK_DIALOG_MODAL|
 				 GTK_DIALOG_DESTROY_WITH_PARENT,
                                  GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
-                                 _("No path found.  "
+                                 _("No path found. "
 				   "Do you want to give one?"));
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(ask, window);
@@ -681,6 +739,10 @@ create_book(AddressBookConfig * abc)
         if (path != NULL)
             address_book = libbalsa_address_book_rubrica_new(name, path);
         g_free(path);
+#endif
+#ifdef HAVE_OSMO
+    } else if (abc->type == LIBBALSA_TYPE_ADDRESS_BOOK_OSMO) {
+    	address_book = libbalsa_address_book_osmo_new(name);
 #endif
     } else
         g_assert_not_reached();
@@ -769,6 +831,10 @@ modify_book(AddressBookConfig * abc)
 #if HAVE_SQLITE
     } else if (abc->type == LIBBALSA_TYPE_ADDRESS_BOOK_GPE) {
 #endif /* HAVE_SQLITE */
+#if HAVE_OSMO
+    } else if (abc->type == LIBBALSA_TYPE_ADDRESS_BOOK_OSMO) {
+    	/* nothing to do here */
+#endif
     } else
         g_assert_not_reached();
 
@@ -785,8 +851,6 @@ modify_book(AddressBookConfig * abc)
 static void
 add_vcard_cb(GtkWidget * widget, AddressBookConfig * abc)
 {
-    g_object_weak_unref(G_OBJECT(gtk_widget_get_parent(widget)),
-                        (GWeakNotify) g_free, abc);
     abc->type = LIBBALSA_TYPE_ADDRESS_BOOK_VCARD;
     abc->window = create_vcard_dialog(abc);
     gtk_widget_show_all(abc->window);
@@ -795,8 +859,6 @@ add_vcard_cb(GtkWidget * widget, AddressBookConfig * abc)
 static void
 add_externq_cb(GtkWidget * widget, AddressBookConfig * abc)
 {
-    g_object_weak_unref(G_OBJECT(gtk_widget_get_parent(widget)),
-                        (GWeakNotify) g_free, abc);
     abc->type = LIBBALSA_TYPE_ADDRESS_BOOK_EXTERN;
     abc->window = create_externq_dialog(abc);
     gtk_widget_show_all(abc->window);
@@ -805,8 +867,6 @@ add_externq_cb(GtkWidget * widget, AddressBookConfig * abc)
 static void
 add_ldif_cb(GtkWidget * widget, AddressBookConfig * abc)
 {
-    g_object_weak_unref(G_OBJECT(gtk_widget_get_parent(widget)),
-                        (GWeakNotify) g_free, abc);
     abc->type = LIBBALSA_TYPE_ADDRESS_BOOK_LDIF;
     abc->window = create_ldif_dialog(abc);
     gtk_widget_show_all(abc->window);
@@ -816,8 +876,6 @@ add_ldif_cb(GtkWidget * widget, AddressBookConfig * abc)
 static void
 add_ldap_cb(GtkWidget * widget, AddressBookConfig * abc)
 {
-    g_object_weak_unref(G_OBJECT(gtk_widget_get_parent(widget)),
-                        (GWeakNotify) g_free, abc);
     abc->type = LIBBALSA_TYPE_ADDRESS_BOOK_LDAP;
     abc->window = create_ldap_dialog(abc);
     gtk_widget_show_all(abc->window);
@@ -828,8 +886,6 @@ add_ldap_cb(GtkWidget * widget, AddressBookConfig * abc)
 static void
 add_gpe_cb(GtkWidget * widget, AddressBookConfig * abc)
 {
-    g_object_weak_unref(G_OBJECT(gtk_widget_get_parent(widget)),
-                        (GWeakNotify) g_free, abc);
     abc->type = LIBBALSA_TYPE_ADDRESS_BOOK_GPE;
     abc->window = create_gpe_dialog(abc);
     gtk_widget_show_all(abc->window);
@@ -840,14 +896,22 @@ add_gpe_cb(GtkWidget * widget, AddressBookConfig * abc)
 static void
 add_rubrica_cb(GtkWidget * widget, AddressBookConfig * abc)
 {
-    g_object_weak_unref(G_OBJECT(gtk_widget_get_parent(widget)),
-                        (GWeakNotify) g_free, abc);
     abc->type = LIBBALSA_TYPE_ADDRESS_BOOK_RUBRICA;
     abc->window = create_rubrica_dialog(abc);
     gtk_widget_show_all(abc->window);
 }
 #endif /* HAVE_SQLITE */
 
+#ifdef HAVE_OSMO
+static void
+add_osmo_cb(GtkWidget * widget, AddressBookConfig * abc)
+{
+    abc->type = LIBBALSA_TYPE_ADDRESS_BOOK_OSMO;
+    abc->window = create_osmo_dialog(abc);
+    gtk_widget_show_all(abc->window);
+}
+#endif /* HAVE_OSMO */
+
 GtkWidget *
 balsa_address_book_add_menu(BalsaAddressBookCallback callback,
                             GtkWindow * parent)
@@ -863,7 +927,7 @@ balsa_address_book_add_menu(BalsaAddressBookCallback callback,
     g_object_weak_ref(G_OBJECT(menu), (GWeakNotify) g_free, abc);
 
     menuitem =
-        gtk_menu_item_new_with_label(_("VCard Address Book (GnomeCard)"));
+        gtk_menu_item_new_with_label(_("vCard Address Book (GnomeCard)"));
     g_signal_connect(G_OBJECT(menuitem), "activate",
                      G_CALLBACK(add_vcard_cb), abc);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
@@ -900,5 +964,12 @@ balsa_address_book_add_menu(BalsaAddressBookCallback callback,
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 #endif /* HAVE_RUBRICA */
 
+#ifdef HAVE_OSMO
+    menuitem = gtk_menu_item_new_with_label(_("Osmo Address Book"));
+    g_signal_connect(G_OBJECT(menuitem), "activate",
+                     G_CALLBACK(add_osmo_cb), abc);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
+#endif
+
     return menu;
 }
