@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -27,9 +25,6 @@
 
 #include <string.h>
 #include <stdlib.h>
-#ifdef BALSA_USE_THREADS
-#include <pthread.h>
-#endif
 
 /* for creat(2) */
 #include <sys/types.h>
@@ -88,7 +83,7 @@ ask_password_real(LibBalsaServer * server, LibBalsaMailbox * mbox)
     dialog = gtk_dialog_new_with_buttons(_("Password needed"),
                                          GTK_WINDOW(balsa_app.main_window),
                                          GTK_DIALOG_DESTROY_WITH_PARENT |
-                                         GTK_DIALOG_USE_HEADER_BAR,
+                                         libbalsa_dialog_flags(),
                                          _("_OK"), GTK_RESPONSE_OK,
                                          _("_Cancel"), GTK_RESPONSE_CANCEL,
                                          NULL); 
@@ -128,12 +123,12 @@ ask_password_real(LibBalsaServer * server, LibBalsaMailbox * mbox)
     return passwd;
 }
 
-#ifdef BALSA_USE_THREADS
 typedef struct {
-    pthread_cond_t cond;
+    GCond cond;
     LibBalsaServer* server;
     LibBalsaMailbox* mbox;
     gchar* res;
+    gboolean done;
 } AskPasswdData;
 
 /* ask_passwd_idle:
@@ -145,8 +140,9 @@ ask_passwd_idle(gpointer data)
     AskPasswdData* apd = (AskPasswdData*)data;
     gdk_threads_enter();
     apd->res = ask_password_real(apd->server, apd->mbox);
+    apd->done = TRUE;
     gdk_threads_leave();
-    pthread_cond_signal(&apd->cond);
+    g_cond_signal(&apd->cond);
     return FALSE;
 }
 
@@ -156,21 +152,23 @@ ask_passwd_idle(gpointer data)
 static gchar *
 ask_password_mt(LibBalsaServer * server, LibBalsaMailbox * mbox)
 {
-    static pthread_mutex_t ask_passwd_lock = PTHREAD_MUTEX_INITIALIZER;
+    static GMutex ask_passwd_lock;
     AskPasswdData apd;
 
-    pthread_mutex_lock(&ask_passwd_lock);
-    pthread_cond_init(&apd.cond, NULL);
+    g_mutex_lock(&ask_passwd_lock);
+    g_cond_init(&apd.cond);
     apd.server = server;
     apd.mbox   = mbox;
+    apd.done   = FALSE;
     g_idle_add(ask_passwd_idle, &apd);
-    pthread_cond_wait(&apd.cond, &ask_passwd_lock);
+    while (!apd.done) {
+    	g_cond_wait(&apd.cond, &ask_passwd_lock);
+    }
     
-    pthread_cond_destroy(&apd.cond);
-    pthread_mutex_unlock(&ask_passwd_lock);
+    g_cond_clear(&apd.cond);
+    g_mutex_unlock(&ask_passwd_lock);
     return apd.res;
 }
-#endif
 
 static gboolean
 set_passwd_from_matching_server(GtkTreeModel *model,
@@ -241,21 +239,15 @@ ask_password(LibBalsaServer *server, LibBalsaMailbox *mbox)
 	}
     }
 
-    if (!password)
-#ifdef BALSA_USE_THREADS
-    {
+    if (!password) {
         G_LOCK_DEFINE_STATIC(ask_password);
 
         G_LOCK(ask_password);
-	password = (pthread_self() == libbalsa_get_main_thread()) ?
+	password = !libbalsa_am_i_subthread() ?
             ask_password_real(server, mbox) : ask_password_mt(server, mbox);
         G_UNLOCK(ask_password);
 	return password;
     }
-#else
-	return ask_password_real(server, mbox);
-#endif
-    else
 	return password;
 }
 
@@ -369,11 +361,6 @@ balsa_app_init(void)
     /* compose: shown headers */
     balsa_app.compose_headers = NULL;
 
-    /* command line options */
-#if defined(ENABLE_TOUCH_UI)
-    balsa_app.open_inbox_upon_startup = TRUE;
-#endif /* ENABLE_TOUCH_UI */
-
     /* date format */
     balsa_app.date_string = g_strdup(DEFAULT_DATE_FORMAT);
 
@@ -395,13 +382,13 @@ balsa_app_init(void)
     balsa_app.filters=NULL;
 
     /* spell check */
-#if HAVE_GTKSPELL
+#if HAVE_GSPELL || HAVE_GTKSPELL
     balsa_app.spell_check_lang = NULL;
     balsa_app.spell_check_active = FALSE;
-#else                           /* HAVE_GTKSPELL */
+#else                           /* HAVE_GSPELL */
     balsa_app.check_sig = DEFAULT_CHECK_SIG;
     balsa_app.check_quoted = DEFAULT_CHECK_QUOTED;
-#endif                          /* HAVE_GTKSPELL */
+#endif                          /* HAVE_GSPELL */
 
     /* Information messages */
     balsa_app.information_message = 0;
@@ -468,7 +455,7 @@ check_new_messages_auto_cb(gpointer data)
     check_new_messages_real(balsa_app.main_window, TYPE_BACKGROUND);
 
     if (balsa_app.debug)
-        fprintf(stderr, "Auto-checked for new messages...\n");
+        fprintf(stderr, "Auto-checked for new messages…\n");
 
     /*  preserver timer */
     return TRUE;
@@ -539,7 +526,7 @@ open_mailbox_by_url(const gchar * url, gboolean hidden)
             libbalsa_mailbox_view_free(view);
         }
         balsa_information(LIBBALSA_INFORMATION_WARNING,
-                          _("Couldn't open mailbox \"%s\""), url);
+                          _("Couldn’t open mailbox “%s”"), url);
     }
 }
 
@@ -899,7 +886,6 @@ balsa_find_index_by_mailbox(LibBalsaMailbox * mailbox)
     return NULL;
 }
 
-#if USE_GREGEX
 GRegex *
 balsa_quote_regex_new(void)
 {
@@ -927,4 +913,3 @@ balsa_quote_regex_new(void)
 
     return g_regex_ref(regex);
 }
-#endif                          /* USE_GREGEX */
