@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* SORTING METHOD discussion:
@@ -266,10 +264,8 @@ static void
 bi_apply_other_column_settings(GtkTreeViewColumn *column,
                                gboolean sortable, gint typeid)
 {
-#if !defined(ENABLE_TOUCH_UI)
     if(sortable)
         gtk_tree_view_column_set_sort_column_id(column, typeid);
-#endif /* ENABLE_TOUCH_UI */
 
     gtk_tree_view_column_set_alignment(column, 0.5);
 
@@ -1812,19 +1808,19 @@ bndx_popup_menu_create(BalsaIndex * index)
         GCallback func;
     } entries[] = {
         {
-        BALSA_PIXMAP_REPLY, N_("_Reply..."),
+        BALSA_PIXMAP_REPLY, N_("_Reply…"),
                 G_CALLBACK(balsa_message_reply)}, {
-        BALSA_PIXMAP_REPLY_ALL, N_("Reply To _All..."),
+        BALSA_PIXMAP_REPLY_ALL, N_("Reply To _All…"),
                 G_CALLBACK(balsa_message_replytoall)}, {
-        BALSA_PIXMAP_REPLY_GROUP, N_("Reply To _Group..."),
+        BALSA_PIXMAP_REPLY_GROUP, N_("Reply To _Group…"),
                 G_CALLBACK(balsa_message_replytogroup)}, {
-        BALSA_PIXMAP_FORWARD, N_("_Forward Attached..."),
+        BALSA_PIXMAP_FORWARD, N_("_Forward Attached…"),
                 G_CALLBACK(balsa_message_forward_attached)}, {
-        BALSA_PIXMAP_FORWARD, N_("Forward _Inline..."),
+        BALSA_PIXMAP_FORWARD, N_("Forward _Inline…"),
                 G_CALLBACK(balsa_message_forward_inline)}, {
-        NULL,                 N_("_Pipe through..."),
+        NULL,                 N_("_Pipe through…"),
                 G_CALLBACK(balsa_index_pipe)}, {
-        BALSA_PIXMAP_BOOK_RED, N_("_Store Address..."),
+        BALSA_PIXMAP_BOOK_RED, N_("_Store Address…"),
                 G_CALLBACK(bndx_store_address)}};
     GtkWidget *menu, *menuitem, *submenu;
     unsigned i;
@@ -1886,6 +1882,7 @@ bndx_popup_menu_create(BalsaIndex * index)
 /* If the menu is popped up in response to a keystroke, center it
  * below the headers of the tree-view.
  */
+#if !GTK_CHECK_VERSION(3, 22, 0)
 static void
 bndx_popup_position_func(GtkMenu * menu, gint * x, gint * y,
                          gboolean * push_in, gpointer user_data)
@@ -1918,6 +1915,7 @@ bndx_popup_position_func(GtkMenu * menu, gint * x, gint * y,
 
     *push_in = FALSE;
 }
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
 
 static void
 bndx_do_popup(BalsaIndex * index, GdkEventButton * event)
@@ -1975,6 +1973,14 @@ bndx_do_popup(BalsaIndex * index, GdkEventButton * event)
 
     gtk_widget_show_all(menu);
 
+#if GTK_CHECK_VERSION(3, 22, 0)
+    if (event)
+        gtk_menu_popup_at_pointer(GTK_MENU(menu), (GdkEvent *) event);
+    else
+        gtk_menu_popup_at_widget(GTK_MENU(menu), GTK_WIDGET(index),
+                                 GDK_GRAVITY_CENTER, GDK_GRAVITY_CENTER,
+                                 NULL);
+#else                           /*GTK_CHECK_VERSION(3, 22, 0) */
     if (event)
         gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
                        event->button, event->time);
@@ -1982,6 +1988,7 @@ bndx_do_popup(BalsaIndex * index, GdkEventButton * event)
         gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
                        bndx_popup_position_func, index,
                        0, gtk_get_current_event_time());
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
 }
 
 static GtkWidget *
@@ -2106,8 +2113,8 @@ balsa_index_transfer(BalsaIndex *index, GArray * msgnos,
     if (!success) {
 	balsa_information
             (LIBBALSA_INFORMATION_WARNING,
-             ngettext("Failed to copy %d message to mailbox \"%s\": %s",
-                      "Failed to copy %d messages to mailbox \"%s\": %s",
+             ngettext("Failed to copy %d message to mailbox “%s”: %s",
+                      "Failed to copy %d messages to mailbox “%s”: %s",
                       msgnos->len),
              msgnos->len, to_mailbox->name, e ? e->message : "?");
 	return;
@@ -2118,8 +2125,8 @@ balsa_index_transfer(BalsaIndex *index, GArray * msgnos,
     else if (to_mailbox == balsa_app.trash)
         enable_empty_trash(balsa_app.main_window, TRASH_FULL);
     balsa_information(LIBBALSA_INFORMATION_MESSAGE,
-                      copy ? _("Copied to \"%s\".")
-                      : _("Moved to \"%s\"."), to_mailbox->name);
+                      copy ? _("Copied to “%s”.")
+                      : _("Moved to “%s”."), to_mailbox->name);
     if (!copy)
 	/* Note when message was flagged as deleted, for use in
 	 * auto-expunge. */
@@ -2404,7 +2411,7 @@ pipe_out_watch(GIOChannel *channel, GIOCondition condition, gpointer data)
 
     if ( (condition & G_IO_ERR) == G_IO_ERR) {
 	fprintf(stderr,
-		"pipe_out_watch encountered error...\n");
+		"pipe_out_watch encountered error…\n");
 	pipe_data_destroy(pipe);
 	return FALSE;
     }
@@ -2642,7 +2649,7 @@ balsa_index_pipe(BalsaIndex * index)
         gtk_dialog_new_with_buttons(_("Pipe message through a program"),
                                     GTK_WINDOW(balsa_app.main_window),
                                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Run"), GTK_RESPONSE_OK,
                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     NULL);
