@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -730,8 +728,10 @@ bmbl_do_popup(GtkTreeView * tree_view, GtkTreePath * path,
               GdkEventButton * event)
 {
     BalsaMailboxNode *mbnode = NULL;
+#if !GTK_CHECK_VERSION(3, 22, 0)
     gint event_button;
     guint event_time;
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
     GtkWidget *menu;
 
     if (path) {
@@ -743,6 +743,7 @@ bmbl_do_popup(GtkTreeView * tree_view, GtkTreePath * path,
         gtk_tree_path_free(path);
     }
 
+#if !GTK_CHECK_VERSION(3, 22, 0)
     if (event) {
         event_button = event->button;
         event_time = event->time;
@@ -750,12 +751,22 @@ bmbl_do_popup(GtkTreeView * tree_view, GtkTreePath * path,
         event_button = 0;
         event_time = gtk_get_current_event_time();
     }
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
 
     menu = balsa_mailbox_node_get_context_menu(mbnode);
     g_object_ref(menu);
     g_object_ref_sink(menu);
+#if GTK_CHECK_VERSION(3, 22, 0)
+    if (event)
+        gtk_menu_popup_at_pointer(GTK_MENU(menu), (GdkEvent *) event);
+    else
+        gtk_menu_popup_at_widget(GTK_MENU(menu), GTK_WIDGET(tree_view),
+                                 GDK_GRAVITY_CENTER, GDK_GRAVITY_CENTER,
+                                 NULL);
+#else                           /*GTK_CHECK_VERSION(3, 22, 0) */
     gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
 		   event_button, event_time);
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
     g_object_unref(menu);
 
     if (mbnode)
@@ -1572,19 +1583,11 @@ bmbl_core_mailbox(LibBalsaMailbox* mailbox)
 {
     static const int num_core_mailboxes = 5;
     LibBalsaMailbox* core_mailbox[] = {
-#if !defined(ENABLE_TOUCH_UI)
         balsa_app.inbox,
         balsa_app.sentbox,
         balsa_app.draftbox,
         balsa_app.outbox,
         balsa_app.trash
-#else /* defined(ENABLE_TOUCH_UI) */
-        balsa_app.inbox,
-        balsa_app.draftbox,
-        balsa_app.outbox,
-        balsa_app.sentbox,
-        balsa_app.trash
-#endif /* defined(ENABLE_TOUCH_UI) */
     };
     gint i = 0;
 
@@ -1769,7 +1772,7 @@ bmbl_mru_menu(GtkWindow * window, GList ** url_list,
     mru = bmbl_mru_new(url_list, user_func, user_data, NULL);
     mru->window = window;
     mru->setup_cb = setup_cb;
-    item = gtk_menu_item_new_with_mnemonic(_("_Other..."));
+    item = gtk_menu_item_new_with_mnemonic(_("_Other…"));
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
     g_signal_connect_data(item, "activate",
                           G_CALLBACK(bmbl_mru_show_tree), mru,
@@ -1844,14 +1847,21 @@ bmbl_mru_size_allocate_cb(GtkWidget * widget, GdkRectangle * allocation,
                           gpointer user_data)
 {
     GdkWindow *gdk_window;
+    gboolean maximized;
+
+    gdk_window = gtk_widget_get_window(widget);
+    if (gdk_window == NULL)
+        return;
 
     /* Maximizing a GtkDialog may not be possible, but we check anyway. */
-    if ((gdk_window = gtk_widget_get_window(widget))
-        && !(gdk_window_get_state(gdk_window)
-             & GDK_WINDOW_STATE_MAXIMIZED)) {
-        balsa_app.mru_tree_width  = allocation->width;
-        balsa_app.mru_tree_height = allocation->height;
-    }
+    maximized =
+        (gdk_window_get_state(gdk_window) &
+         (GDK_WINDOW_STATE_MAXIMIZED | GDK_WINDOW_STATE_FULLSCREEN)) != 0;
+
+    if (!maximized)
+        gtk_window_get_size(GTK_WINDOW(widget),
+                            & balsa_app.mru_tree_width,
+                            & balsa_app.mru_tree_height);
 }
 
 static void
@@ -1882,7 +1892,7 @@ bmbl_mru_show_tree(GtkWidget * widget, gpointer data)
         gtk_dialog_new_with_buttons(_("Choose destination folder"),
                                     mru->window,
                                     GTK_DIALOG_MODAL |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
@@ -2073,7 +2083,7 @@ bmbl_mru_combo_box_setup(GtkComboBox * combo_box)
     gtk_list_store_set(store, &iter, 1, TRUE, -1);
     gtk_list_store_append(store, &iter);
     gtk_list_store_set(store, &iter,
-                       0, _("Other..."),
+                       0, _("Other…"),
 		       1, FALSE, -1);
     gtk_combo_box_set_active(combo_box, 0);
 }
