@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -177,8 +177,12 @@ balsa_image_button_press_cb(GtkWidget * widget, GdkEventButton * event,
                             GtkMenu * menu)
 {
     if (menu && event->type == GDK_BUTTON_PRESS && event->button == 3) {
+#if GTK_CHECK_VERSION(3, 22, 0)
+        gtk_menu_popup_at_pointer(menu, (GdkEvent *) event);
+#else                           /*GTK_CHECK_VERSION(3, 22, 0) */
         gtk_menu_popup(menu, NULL, NULL, NULL, NULL,
                        event->button, event->time);
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
         return TRUE;
     } else
         return FALSE;
