@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -432,7 +430,7 @@ bm_header_extend_popup(GtkWidget * widget, GtkMenu * menu, gpointer arg)
 
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), separator);
     gtk_widget_show(separator);
-    menu_item = gtk_menu_item_new_with_label(_("Reply..."));
+    menu_item = gtk_menu_item_new_with_label(_("Reply…"));
     g_signal_connect(G_OBJECT(menu_item), "activate",
                      G_CALLBACK(bm_header_ctx_menu_reply),
                      arg);
@@ -440,7 +438,7 @@ bm_header_extend_popup(GtkWidget * widget, GtkMenu * menu, gpointer arg)
     gtk_widget_show(menu_item);
 
 
-    menu_item = gtk_menu_item_new_with_mnemonic(_("_Copy to folder..."));
+    menu_item = gtk_menu_item_new_with_mnemonic(_("_Copy to folder…"));
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_item);
     gtk_widget_show(menu_item);
 
@@ -547,13 +545,9 @@ label_size_allocate_cb(GtkLabel * label, GdkRectangle * rectangle,
 static void
 expanded_cb(GtkExpander * expander, GParamSpec * arg1, GtkLabel * label)
 {
-    if (gtk_expander_get_expanded(expander)) {
-        gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
-        gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_NONE);
-    } else {
-        gtk_label_set_line_wrap(GTK_LABEL(label), FALSE);
-        gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_END);
-    }
+    gtk_label_set_ellipsize(label,
+                            gtk_expander_get_expanded(expander) ?
+                            PANGO_ELLIPSIZE_NONE : PANGO_ELLIPSIZE_END);
 }
 
 #define BALSA_MESSAGE_HEADER "balsa-message-header"
@@ -562,7 +556,6 @@ static void
 add_header_gchar(GtkGrid * grid, const gchar * header, const gchar * label,
 		 const gchar * value, gboolean show_all_headers)
 {
-    gint row;
     gchar *css;
     GtkCssProvider *css_provider;
     GtkWidget *lab;
@@ -571,10 +564,6 @@ add_header_gchar(GtkGrid * grid, const gchar * header, const gchar * label,
 	  libbalsa_find_word(header, balsa_app.selected_headers)))
 	return;
 
-    row = 0;
-    while (gtk_grid_get_child_at(grid, 0, row))
-        row++;
-
     if (balsa_app.use_system_fonts) {
         if (strcmp(header, "subject") == 0)
             /* Use bold for the subject line */
@@ -582,11 +571,10 @@ add_header_gchar(GtkGrid * grid, const gchar * header, const gchar * label,
         else
             css = g_strdup("");
     } else {
-        css =
-            g_strconcat("#" BALSA_MESSAGE_HEADER " {font:",
-                        strcmp(header, "subject")
-                        ? balsa_app.message_font
-                        : balsa_app.subject_font, "}", NULL);
+        css = libbalsa_font_string_to_css(strcmp(header, "subject")
+                                          ? balsa_app.message_font
+                                          : balsa_app.subject_font,
+                                          BALSA_MESSAGE_HEADER);
     }
 
     css_provider = gtk_css_provider_new();
@@ -599,7 +587,7 @@ add_header_gchar(GtkGrid * grid, const gchar * header, const gchar * label,
                                    GTK_STYLE_PROVIDER(css_provider),
                                    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
-    gtk_grid_attach(grid, lab, 0, row, 1, 1);
+    gtk_grid_attach_next_to(grid, lab, NULL, GTK_POS_BOTTOM, 1, 1);
     gtk_label_set_selectable(GTK_LABEL(lab), TRUE);
     gtk_widget_set_halign(lab, GTK_ALIGN_START);
     gtk_widget_set_valign(lab, GTK_ALIGN_START);
@@ -607,51 +595,58 @@ add_header_gchar(GtkGrid * grid, const gchar * header, const gchar * label,
 
     if (value && *value != '\0') {
         gchar *sanitized;
+        GtkWidget *value_label;
         GtkWidget *expander;
         GtkWidget *hbox;
 
         sanitized = g_strdup(value);
         libbalsa_utf8_sanitize(&sanitized,
                                balsa_app.convert_unknown_8bit, NULL);
-        lab = gtk_label_new(sanitized);
+        g_strdelimit(sanitized, "\r\n", ' ');
+        value_label = gtk_label_new(sanitized);
         g_free(sanitized);
 
-        gtk_widget_set_name(lab, BALSA_MESSAGE_HEADER);
-        gtk_style_context_add_provider(gtk_widget_get_style_context(lab) ,
+        gtk_widget_set_name(value_label, BALSA_MESSAGE_HEADER);
+        gtk_style_context_add_provider(gtk_widget_get_style_context(value_label) ,
                                        GTK_STYLE_PROVIDER(css_provider),
                                        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
-        gtk_label_set_line_wrap_mode(GTK_LABEL(lab), PANGO_WRAP_WORD_CHAR);
-        gtk_label_set_selectable(GTK_LABEL(lab), TRUE);
+        gtk_label_set_line_wrap(GTK_LABEL(value_label), TRUE);
+        gtk_label_set_line_wrap_mode(GTK_LABEL(value_label), PANGO_WRAP_WORD_CHAR);
+        gtk_label_set_selectable(GTK_LABEL(value_label), TRUE);
 #if GTK_CHECK_VERSION(3, 16, 0)
-        gtk_label_set_xalign((GtkLabel *) lab, 0.0);
+        gtk_label_set_xalign((GtkLabel *) value_label, 0.0);
 #else                           /* GTK_CHECK_VERSION(3, 16, 0) */
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-        gtk_misc_set_alignment((GtkMisc *) lab, 0.0, 0.0);
+        gtk_misc_set_alignment((GtkMisc *) value_label, 0.0, 0.0);
 G_GNUC_END_IGNORE_DEPRECATIONS
 #endif                          /* GTK_CHECK_VERSION(3, 16, 0) */
-        gtk_widget_set_halign(lab, GTK_ALIGN_START);
-        gtk_widget_set_hexpand(lab, TRUE);
+        gtk_widget_set_halign(value_label, GTK_ALIGN_START);
+        gtk_widget_set_hexpand(value_label, TRUE);
 
         expander = gtk_expander_new(NULL);
-        g_signal_connect(expander, "notify::expanded",
-                         G_CALLBACK(expanded_cb), lab);
 
-        if(show_all_headers) {
-            gtk_label_set_line_wrap(GTK_LABEL(lab), TRUE);
+        /*
+         * If we are showing all headers, we initially expand the
+         * header, otherwise collapse it.
+         */
+        if (show_all_headers) {
+            gtk_label_set_ellipsize(GTK_LABEL(value_label), PANGO_ELLIPSIZE_NONE);
             gtk_expander_set_expanded(GTK_EXPANDER(expander), TRUE);
         } else {
-            gtk_label_set_ellipsize(GTK_LABEL(lab), PANGO_ELLIPSIZE_END);
+            gtk_label_set_ellipsize(GTK_LABEL(value_label), PANGO_ELLIPSIZE_END);
             gtk_expander_set_expanded(GTK_EXPANDER(expander), FALSE);
         }
-        g_signal_connect(lab, "size-allocate",
+        g_signal_connect(expander, "notify::expanded",
+                         G_CALLBACK(expanded_cb), value_label);
+        g_signal_connect(value_label, "size-allocate",
                          G_CALLBACK(label_size_allocate_cb), expander);
 
         hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-        gtk_container_add(GTK_CONTAINER(hbox), lab);
+        gtk_container_add(GTK_CONTAINER(hbox), value_label);
         gtk_container_add(GTK_CONTAINER(hbox), expander);
         gtk_widget_show_all(hbox);
-        gtk_grid_attach(grid, hbox, 1, row, 1, 1);
+        gtk_grid_attach_next_to(grid, hbox, lab, GTK_POS_RIGHT, 1, 1);
     }
 
     g_object_unref(css_provider);
@@ -660,7 +655,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 static void
 add_header_address_list(BalsaMessage * bm, GtkGrid * grid,
 			gchar * header, gchar * label,
-			InternetAddressList * list)
+			InternetAddressList * list,
+                        gboolean show_all_headers)
 {
     gchar *value;
 
@@ -673,7 +669,7 @@ add_header_address_list(BalsaMessage * bm, GtkGrid * grid,
 
     value = internet_address_list_to_string(list, FALSE);
 
-    add_header_gchar(grid, header, label, value, FALSE);
+    add_header_gchar(grid, header, label, value, show_all_headers);
 
     g_free(value);
 }
@@ -748,13 +744,16 @@ bmw_message_set_headers_d(BalsaMessage           * bm,
                          show_all_headers);
 	g_free(reply_to);
     }
-    add_header_address_list(bm, grid, "to", _("To:"), headers->to_list);
-    add_header_address_list(bm, grid, "cc", _("Cc:"), headers->cc_list);
-    add_header_address_list(bm, grid, "bcc", _("Bcc:"), headers->bcc_list);
+    add_header_address_list(bm, grid, "to", _("To:"), headers->to_list,
+                            show_all_headers);
+    add_header_address_list(bm, grid, "cc", _("CC:"), headers->cc_list,
+                            show_all_headers);
+    add_header_address_list(bm, grid, "bcc", _("BCC:"), headers->bcc_list,
+                            show_all_headers);
 
 #if BALSA_SHOW_FCC_AS_WELL_AS_X_BALSA_FCC
     if (headers->fcc_url)
-	add_header_gchar(grid, "fcc", _("Fcc:"), headers->fcc_url,
+	add_header_gchar(grid, "fcc", _("FCC:"), headers->fcc_url,
                          show_all_headers);
 #endif
 
@@ -844,7 +843,6 @@ add_header_sigstate(GtkGrid * grid, GMimeGpgmeSigstat * siginfo)
     gchar *format;
     gchar *msg;
     GtkWidget *label;
-    gint row;
 
     format = siginfo->status ==
         GPG_ERR_NO_ERROR ? "<i>%s%s</i>" : "<b><i>%s%s</i></b>";
@@ -859,9 +857,6 @@ add_header_sigstate(GtkGrid * grid, GMimeGpgmeSigstat * siginfo)
     gtk_widget_set_halign(label, GTK_ALIGN_START);
     gtk_widget_show(label);
 
-    row = 0;
-    while (gtk_grid_get_child_at(grid, 0, row))
-        row++;
-    gtk_grid_attach(grid, label, 0, row, 2, 1);
+    gtk_grid_attach_next_to(grid, label, NULL, GTK_POS_BOTTOM, 2, 1);
 }
 #endif
