@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -37,14 +35,7 @@
 #include "balsa-cite-bar.h"
 
 #if HAVE_GTKSOURCEVIEW
-#include <gtksourceview/gtksourceview.h>
-#include <gtksourceview/gtksourcebuffer.h>
-#include <gtksourceview/gtksourcelanguage.h>
-#if (HAVE_GTKSOURCEVIEW == 1)
-#  include <gtksourceview/gtksourcelanguagesmanager.h>
-#else
-#  include <gtksourceview/gtksourcelanguagemanager.h>
-#endif
+#include <gtksourceview/gtksource.h>
 #endif
 
 
@@ -258,32 +249,7 @@ balsa_mime_widget_new_text(BalsaMessage * bm, LibBalsaMessageBody * mime_body,
 static GtkWidget *
 create_text_widget(const char * content_type)
 {
-#if (HAVE_GTKSOURCEVIEW == 1)
-    static GtkSourceLanguagesManager * lm = NULL;
-    GtkSourceLanguage * lang;
-    GtkSourceBuffer * buffer;
-    GtkWidget * widget;
-
-    /* we use or own highlighting for text/plain */
-    if (!g_ascii_strcasecmp(content_type, "text/plain"))
-	return gtk_text_view_new();
-
-    /* check if GtkSourceView knows our content type */
-    if (!lm)
-	lm = gtk_source_languages_manager_new();
-    if (!lm ||
-	!(lang = gtk_source_languages_manager_get_language_from_mime_type(lm, content_type)))
-	return gtk_text_view_new();
-
-    /* create a GtkSourceView for our content type */
-    buffer = gtk_source_buffer_new_with_language(lang);
-    gtk_source_buffer_set_highlight(buffer, TRUE);
-    // TODO: maybe we want to use (a) our own highlighting styles or (b) use
-    // GEdit-2's here?
-    widget = gtk_source_view_new_with_buffer(buffer);
-    g_object_unref(buffer);
-    return widget;
-#elif (HAVE_GTKSOURCEVIEW > 1)
+#if HAVE_GTKSOURCEVIEW
     static GtkSourceLanguageManager * lm = NULL;
     static const gchar * const * lm_ids = NULL;
     GtkWidget * widget = NULL;
@@ -343,7 +309,7 @@ bm_modify_font_from_string(GtkWidget * widget, const char *font)
     GtkCssProvider *css_provider;
 
     gtk_widget_set_name(widget, BALSA_MESSAGE_TEXT_HEADER);
-    css = g_strconcat("#" BALSA_MESSAGE_TEXT_HEADER " {font:", font, "}", NULL);
+    css = libbalsa_font_string_to_css(font, BALSA_MESSAGE_TEXT_HEADER);
 
     css_provider = gtk_css_provider_new();
     gtk_css_provider_load_from_data(css_provider, css, -1, NULL);
@@ -506,7 +472,11 @@ text_view_url_popup(GtkTextView *textview, GtkMenu *menu)
     gint x, y;
     GdkWindow *window;
     GdkDisplay *display;
+#if GTK_CHECK_VERSION(3, 19, 0)
+    GdkSeat *seat;
+#else                           /* GTK_CHECK_VERSION(3, 20, 0) */
     GdkDeviceManager *manager;
+#endif                          /* GTK_CHECK_VERSION(3, 20, 0) */
     GdkDevice *device;
     GtkWidget *menu_item;
 
@@ -517,8 +487,13 @@ text_view_url_popup(GtkTextView *textview, GtkMenu *menu)
     /* check if we are over an url */
     window = gtk_text_view_get_window(textview, GTK_TEXT_WINDOW_TEXT);
     display = gdk_window_get_display(window);
+#if GTK_CHECK_VERSION(3, 19, 0)
+    seat = gdk_display_get_default_seat(display);
+    device = gdk_seat_get_pointer(seat);
+#else                           /* GTK_CHECK_VERSION(3, 20, 0) */
     manager = gdk_display_get_device_manager(display);
     device = gdk_device_manager_get_client_pointer(manager);
+#endif                          /* GTK_CHECK_VERSION(3, 20, 0) */
     gdk_window_get_device_position(window, device, &x, &y, NULL);
 
     url = find_url(GTK_WIDGET(textview), x, y, url_list);
@@ -539,7 +514,7 @@ text_view_url_popup(GtkTextView *textview, GtkMenu *menu)
                       G_CALLBACK (url_open_cb), (gpointer)url);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
-    menu_item = gtk_menu_item_new_with_label (_("Send link..."));
+    menu_item = gtk_menu_item_new_with_label (_("Send link…"));
     g_signal_connect (G_OBJECT (menu_item), "activate",
                       G_CALLBACK (url_send_cb), (gpointer)url);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
@@ -570,7 +545,7 @@ text_view_populate_popup(GtkTextView *textview, GtkMenu *menu,
 					   G_CALLBACK (balsa_mime_widget_ctx_menu_cb),
 					   (gpointer)mime_body);
 
-    menu_item = gtk_menu_item_new_with_label (_("Save..."));
+    menu_item = gtk_menu_item_new_with_label (_("Save…"));
     g_signal_connect (G_OBJECT (menu_item), "activate",
                       G_CALLBACK (balsa_mime_widget_ctx_menu_save), (gpointer)mime_body);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
@@ -704,8 +679,13 @@ prepare_url_offsets(GtkTextBuffer * buffer, GList * url_list)
         gtk_text_iter_backward_to_tag_toggle(&iter, url_tag);
 #else
         while (gtk_text_iter_backward_char(&iter))
+#if GTK_CHECK_VERSION(3, 19, 0)
+            if (gtk_text_iter_starts_tag(&iter, url_tag))
+                break;
+#else                           /* GTK_CHECK_VERSION(3, 20, 0) */
             if (gtk_text_iter_begins_tag(&iter, url_tag))
                 break;
+#endif                          /* GTK_CHECK_VERSION(3, 20, 0) */
 #endif                          /* BUG_102711_FIXED */
         url->start = gtk_text_iter_get_offset(&iter);
     }
@@ -802,7 +782,7 @@ handle_url(const gchar * url)
     } else {
         GtkStatusbar *statusbar;
         guint context_id;
-        gchar *notice = g_strdup_printf(_("Calling URL %s..."), url);
+        gchar *notice = g_strdup_printf(_("Calling URL %s…"), url);
         GdkScreen *screen;
         GError *err = NULL;
 
@@ -1095,7 +1075,7 @@ bmwt_populate_popup_menu(BalsaMessage * bm,
                                            (balsa_mime_widget_ctx_menu_cb),
                                            mime_body);
 
-    menuitem = gtk_menu_item_new_with_label(_("Save..."));
+    menuitem = gtk_menu_item_new_with_label(_("Save…"));
     g_signal_connect(G_OBJECT(menuitem), "activate",
                      G_CALLBACK(balsa_mime_widget_ctx_menu_save),
                      mime_body);
@@ -1104,7 +1084,7 @@ bmwt_populate_popup_menu(BalsaMessage * bm,
     menuitem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 
-    menuitem = gtk_menu_item_new_with_label(_("Print..."));
+    menuitem = gtk_menu_item_new_with_label(_("Print…"));
     g_signal_connect_swapped(G_OBJECT(menuitem), "activate",
                              G_CALLBACK(libbalsa_html_print), html);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
@@ -1117,8 +1097,10 @@ balsa_gtk_html_popup(GtkWidget * html, BalsaMessage * bm)
     GtkWidget *menu;
     const GdkEvent *event;
     GdkEvent *current_event = NULL;
+#if !GTK_CHECK_VERSION(3, 22, 0)
     guint32 time;
     guint button;
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
 
     menu = gtk_menu_new();
     bmwt_populate_popup_menu(bm, html, GTK_MENU(menu));
@@ -1131,6 +1113,18 @@ balsa_gtk_html_popup(GtkWidget * html, BalsaMessage * bm)
     event = g_object_get_data(G_OBJECT(html), LIBBALSA_HTML_POPUP_EVENT);
     if (!event)
         event = current_event = gtk_get_current_event();
+#if GTK_CHECK_VERSION(3, 22, 0)
+    if (event)
+        gtk_menu_popup_at_pointer(GTK_MENU(menu),
+                                  (GdkEvent *) event);
+    else
+        gtk_menu_popup_at_widget(GTK_MENU(menu),
+                                 GTK_WIDGET(bm),
+                                 GDK_GRAVITY_CENTER, GDK_GRAVITY_CENTER,
+                                 NULL);
+    if (current_event)
+        gdk_event_free(current_event);
+#else                           /*GTK_CHECK_VERSION(3, 22, 0) */
     time = gdk_event_get_time(event);
     button = 0;
     gdk_event_get_button(event, &button);
@@ -1138,6 +1132,7 @@ balsa_gtk_html_popup(GtkWidget * html, BalsaMessage * bm)
         gdk_event_free(current_event);
 
     gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, button, time);
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
 
     return TRUE;
 }
@@ -1268,11 +1263,11 @@ check_text_encoding(BalsaMessage * bm, gchar *text_buf)
                                NULL);
         libbalsa_information
             (LIBBALSA_INFORMATION_MESSAGE,
-             _("The message sent by %s with subject \"%s\" contains 8-bit "
+             _("The message sent by %s with subject “%s” contains 8-bit "
                "characters, but no header describing the used codeset "
                "(converted to %s)"),
              from, subject,
-             target_cs ? target_cs : "\"?\"");
+             target_cs ? target_cs : "“?”");
         g_free(subject);
         g_free(from);
         /* Avoid multiple notifications: */
@@ -1301,26 +1296,14 @@ fill_text_buf_cited(GtkWidget *widget, const gchar *text_body,
     PangoContext *context = gtk_widget_get_pango_context(widget);
     PangoFontDescription *desc = pango_context_get_font_description(context);
     GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
-#if USE_GREGEX
     GRegex *rex = NULL;
-#else                           /* USE_GREGEX */
-    regex_t rex;
-#endif                          /* USE_GREGEX */
     gboolean have_regex;
     GdkRGBA *rgba;
 
     /* prepare citation regular expression for plain bodies */
     if (is_plain) {
-#if USE_GREGEX
         rex = balsa_quote_regex_new();
         have_regex = rex ? TRUE : FALSE;
-#else                           /* USE_GREGEX */
-        if (!balsa_app.mark_quoted
-            || regcomp(&rex, balsa_app.quote_regex, REG_EXTENDED))
-            have_regex = FALSE;
-        else
-            have_regex = TRUE;
-#endif                          /* USE_GREGEX */
     } else
         have_regex = FALSE;
 
@@ -1368,13 +1351,8 @@ fill_text_buf_cited(GtkWidget *widget, const gchar *text_body,
             guint cite_idx;
 
             /* get the cite level only for text/plain parts */
-#if USE_GREGEX
             libbalsa_match_regex(text_body, rex, &quote_level,
                                  &cite_idx);
-#else                           /* USE_GREGEX */
-            libbalsa_match_regex(text_body, &rex, &quote_level,
-                                 &cite_idx);
-#endif                          /* USE_GREGEX */
 
             /* check if the citation level changed */
             if (cite_level != quote_level) {
@@ -1444,11 +1422,7 @@ fill_text_buf_cited(GtkWidget *widget, const gchar *text_body,
     }
 
     if (have_regex)
-#if USE_GREGEX
         g_regex_unref(rex);
-#else                           /* USE_GREGEX */
-        regfree(&rex);
-#endif                          /* USE_GREGEX */
 
     return url_list;
 }
