@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -64,7 +62,7 @@ balsa_mime_widget_new_vcalendar(BalsaMessage * bm,
     mw = g_object_new(BALSA_TYPE_MIME_WIDGET, NULL);
     mw->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, 12);
 
-    text = g_strdup_printf(_("This is an iTIP calendar \"%s\" message."),
+    text = g_strdup_printf(_("This is an iTIP calendar “%s” message."),
 			   libbalsa_vcal_method_to_str(vcal_obj->method));
     label = gtk_label_new(text);
     g_free(text);
@@ -124,7 +122,7 @@ balsa_mime_widget_new_vcalendar(BalsaMessage * bm,
     do {                                                                \
         if (date != (time_t) -1) {                                      \
             gchar * _dstr =                                             \
-                libbalsa_date_to_utf8(&date, balsa_app.date_string);    \
+                libbalsa_date_to_utf8(date, balsa_app.date_string);     \
             GRID_ATTACH(g, _dstr, label);                               \
             g_free(_dstr);                                              \
         }                                                               \
@@ -302,7 +300,7 @@ vevent_reply(GObject * button, GtkWidget * box)
 
     /* create the message subject */
     dummy = g_strdup_printf("%s: %s",
-			    event->summary ? event->summary : _("iTip Calendar Request"),
+			    event->summary ? event->summary : _("iTIP Calendar Request"),
 			    libbalsa_vcal_part_stat_to_str(pstat));
     libbalsa_message_set_subject(message, dummy);
     g_free(dummy);
@@ -340,7 +338,7 @@ vevent_reply(GObject * button, GtkWidget * box)
 #endif
     if (result != LIBBALSA_MESSAGE_CREATE_OK)
 	libbalsa_information(LIBBALSA_INFORMATION_ERROR,
-			     _("Sending the iTip calendar reply failed: %s"),
+			     _("Sending the iTIP calendar reply failed: %s"),
 			     error ? error->message : "?");
     if (error)
 	g_error_free(error);
