@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2015 Stuart Parmenter and others
+ * Copyright (C) 1997-2016 Stuart Parmenter and others
  * Written by (C) Albrecht Dre <albrecht.dress@arcor.de> 2007
  *
  * This program is free software; you can redistribute it and/or modify
@@ -170,11 +170,11 @@ balsa_print_object_header_new_real(GList * list,
 		    headers->from, &p_label_width, print_all_headers);
     header_add_list(test_layout, header_buf, "to", _("To:"),
 		    headers->to_list, &p_label_width, print_all_headers);
-    header_add_list(test_layout, header_buf, "cc", _("Cc:"),
+    header_add_list(test_layout, header_buf, "cc", _("CC:"),
 		    headers->cc_list, &p_label_width, print_all_headers);
-    header_add_list(test_layout, header_buf, "bcc", _("Bcc:"),
+    header_add_list(test_layout, header_buf, "bcc", _("BCC:"),
 		    headers->bcc_list, &p_label_width, print_all_headers);
-    header_add_string(test_layout, header_buf, "fcc", _("Fcc:"),
+    header_add_string(test_layout, header_buf, "fcc", _("FCC:"),
 		      headers->fcc_url, &p_label_width, print_all_headers);
     header_add_list(test_layout, header_buf, "disposition-notification-to",
 		    _("Disposition-Notification-To:"),
