@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others
- * Written by (C) Albrecht Dre <albrecht.dress@arcor.de> 2007
+ * Copyright (C) 1997-2016 Stuart Parmenter and others
+ * Written by (C) Albrecht Dreß <albrecht.dress@arcor.de> 2007
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -137,11 +135,7 @@ balsa_print_object_text_plain(GList *list, GtkPrintContext * context,
 			      LibBalsaMessageBody * body,
 			      BalsaPrintSetup * psetup)
 {
-#if USE_GREGEX
     GRegex *rex;
-#else                           /* USE_GREGEX */
-    regex_t rex;
-#endif                          /* USE_GREGEX */
     gchar *textbuf;
     PangoFontDescription *font;
     gdouble c_at_x;
@@ -152,11 +146,7 @@ balsa_print_object_text_plain(GList *list, GtkPrintContext * context,
     gint par_len;
 
     /* set up the regular expression for qouted text */
-#if USE_GREGEX
     if (!(rex = balsa_quote_regex_new()))
-#else                           /* USE_GREGEX */
-    if (regcomp(&rex, balsa_app.quote_regex, REG_EXTENDED) != 0)
-#endif                          /* USE_GREGEX */
 	return balsa_print_object_default(list, context, body, psetup);
 
     /* start on new page if less than 2 lines can be printed */
@@ -223,13 +213,7 @@ balsa_print_object_text_plain(GList *list, GtkPrintContext * context,
 	    thispar = g_strndup(par_start, par_len);
 
 	    /* get the cite level and strip off the prefix */
-#if USE_GREGEX
-	    if (libbalsa_match_regex
-		(thispar, rex, &cite_level, &cite_idx))
-#else                           /* USE_GREGEX */
-	    if (libbalsa_match_regex
-		(thispar, &rex, &cite_level, &cite_idx))
-#endif                          /* USE_GREGEX */
+	    if (libbalsa_match_regex(thispar, rex, &cite_level, &cite_idx))
             {
 		gchar *new;
 
@@ -335,9 +319,7 @@ balsa_print_object_text_plain(GList *list, GtkPrintContext * context,
     /* clean up */
     pango_font_description_free(font);
     g_free(textbuf);
-#if USE_GREGEX
     g_regex_unref(rex);
-#endif                          /* USE_GREGEX */
     return list;
 }
 
@@ -577,7 +559,7 @@ balsa_print_object_text_vcard(GList * list,
     do {                                                                \
         if (date != (time_t) -1) {                                      \
             gchar * _dstr =                                             \
-                libbalsa_date_to_utf8(&date, balsa_app.date_string);    \
+                libbalsa_date_to_utf8(date, balsa_app.date_string);     \
             ADD_VCAL_FIELD(buf, labwidth, layout, _dstr, descr);        \
             g_free(_dstr);                                              \
         }                                                               \
