@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; indent-tab-mode: nil; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -27,10 +25,6 @@
 # include "config.h"
 #endif                          /* HAVE_CONFIG_H */
 
-/* yellow dog has crappy libc and needs pthread.h to be included here */
-#ifdef BALSA_USE_THREADS
-#  include <pthread.h>
-#endif
 #include <time.h>
 
 #include <string.h>
@@ -79,7 +73,6 @@ GtkWidget *fe_search_option_menu;
 extern GtkWidget *fe_op_codes_option_menu;
     
 /* Name field */
-extern GtkWidget *fe_name_label;
 extern GtkWidget *fe_name_entry;
     
 /* widgets for the matching fields */
@@ -725,8 +718,8 @@ fill_condition_widgets(LibBalsaCondition* cnd)
     GtkTreeModel *model =
         gtk_tree_view_get_model(fe_type_regex_list);
 #endif                  /* REGULAR_EXPRESSION_FILTERING_IS_IMPLEMENTED */
-    gchar str[20];
-    struct tm date;
+    gchar *str;
+    GDateTime *date;
     gint row,col;
     gboolean andmask;
     static gchar xformat[] = "%x"; /* to suppress error in strftime */
@@ -801,18 +794,22 @@ fill_condition_widgets(LibBalsaCondition* cnd)
 #endif
         break;
     case CONDITION_DATE:
-        if (cnd->match.date.date_low==0) str[0]='\0';
+        if (cnd->match.date.date_low==0) str = g_strdup("");
         else {
-            localtime_r(&cnd->match.date.date_low, &date);
-            strftime(str, sizeof(str), xformat, &date);
+        	date = g_date_time_new_from_unix_local(cnd->match.date.date_low);
+            str = g_date_time_format(date, xformat);
+            g_date_time_unref(date);
         }
         gtk_entry_set_text(GTK_ENTRY(fe_type_date_low_entry),str);
-        if (cnd->match.date.date_high==0) str[0]='\0';
+        g_free(str);
+        if (cnd->match.date.date_high==0) str = g_strdup("");
         else {
-            localtime_r(&cnd->match.date.date_high, &date);
-            strftime(str,sizeof(str), xformat, &date);
+        	date = g_date_time_new_from_unix_local(cnd->match.date.date_low);
+            str = g_date_time_format(date, xformat);
+            g_date_time_unref(date);
         }
         gtk_entry_set_text(GTK_ENTRY(fe_type_date_high_entry),str);
+        g_free(str);
         fe_update_label(fe_type_date_label, &date_label);
         break;
     case CONDITION_FLAG:
@@ -959,7 +956,7 @@ get_field_frame(void)
     fe_matching_fields_to      = add_check(grid, _("_To:"),     0,1);
     fe_matching_fields_from    = add_check(grid, _("_From:"),   1,1);
     fe_matching_fields_subject = add_check(grid, _("_Subject"), 0,2);
-    fe_matching_fields_cc      = add_check(grid, _("_Cc:"),     1,2);
+    fe_matching_fields_cc      = add_check(grid, _("_CC:"),     1,2);
     fe_matching_fields_us_head =
         gtk_check_button_new_with_mnemonic(_("_User header:"));
     gtk_widget_set_hexpand(fe_matching_fields_us_head, TRUE);
@@ -1237,7 +1234,7 @@ fe_edit_condition(GtkWidget * throwaway,gpointer is_new_cnd)
             gtk_dialog_new_with_buttons("",
                                         GTK_WINDOW(fe_window),
                                         GTK_DIALOG_DESTROY_WITH_PARENT |
-                                        GTK_DIALOG_USE_HEADER_BAR,
+                                        libbalsa_dialog_flags(),
                                         _("_OK"), GTK_RESPONSE_OK,
                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
                                         _("_Help"), GTK_RESPONSE_HELP,
@@ -1833,7 +1830,7 @@ fe_apply_pressed(GtkWidget * widget, gpointer data)
     } 
     if(!unique_filter_name(temp)) {
         balsa_information(LIBBALSA_INFORMATION_ERROR,
-                          _("Filter \"%s\" already exists."), temp);
+                          _("Filter “%s” already exists."), temp);
         return;
     }
     
