@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -399,7 +397,7 @@ build_action_page(GtkWindow * window)
     gtk_grid_attach(GTK_GRID(grid), fe_sound_button, 0, 0, 1, 1);
 
     dialog =
-        gtk_file_chooser_dialog_new(_("Use Sound..."), NULL,
+        gtk_file_chooser_dialog_new(_("Use Sound…"), NULL,
                                     GTK_FILE_CHOOSER_ACTION_OPEN,
                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     _("_Open"),   GTK_RESPONSE_ACCEPT,
@@ -417,7 +415,7 @@ build_action_page(GtkWindow * window)
     g_signal_connect(G_OBJECT(dialog), "response",
                      G_CALLBACK(fe_sound_response), NULL);
 
-    fe_popup_button = gtk_check_button_new_with_label(_("Popup text:"));
+    fe_popup_button = gtk_check_button_new_with_label(_("Pop-up text:"));
     gtk_widget_set_hexpand(fe_popup_button, TRUE);
     gtk_grid_attach(GTK_GRID(grid), fe_popup_button, 0, 1, 1, 1);
     fe_popup_entry = gtk_entry_new();
@@ -568,7 +566,7 @@ filters_edit_dialog(GtkWindow * parent)
 
     fe_window = gtk_dialog_new_with_buttons(_("Filters"),
                                             parent,
-                                            GTK_DIALOG_USE_HEADER_BAR,
+                                            libbalsa_dialog_flags(),
                                             _("_OK"), GTK_RESPONSE_OK,
                                             _("_Cancel"), GTK_RESPONSE_CANCEL,
                                             _("_Help"), GTK_RESPONSE_HELP,
@@ -579,7 +577,7 @@ filters_edit_dialog(GtkWindow * parent)
     g_signal_connect(G_OBJECT(fe_window), "destroy",
 	             G_CALLBACK(fe_destroy_window_cb), NULL);
 
-    gtk_window_set_wmclass(GTK_WINDOW (fe_window), "filter-edit", "Balsa");
+    gtk_window_set_role(GTK_WINDOW (fe_window), "filter-edit");
     gtk_dialog_set_response_sensitive(GTK_DIALOG(fe_window),
                                       GTK_RESPONSE_OK, FALSE);
 
@@ -634,7 +632,7 @@ filters_edit_dialog(GtkWindow * parent)
             cpfil->condition = libbalsa_condition_ref(fil->condition);
         else
             balsa_information(LIBBALSA_INFORMATION_WARNING,
-                              _("Filter \"%s\" has no condition."),
+                              _("Filter “%s” has no condition."),
                               fil->name);
 
 	fe_collect_user_headers(fil->condition);
