@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -236,7 +234,7 @@ fr_apply_selected_pressed(BalsaFilterRunDialog * p)
                                    _("Error when applying filters"));
     else
         balsa_information(LIBBALSA_INFORMATION_MESSAGE,
-                          _("Filter applied to \"%s\"."),
+                          _("Filter applied to “%s”."),
                           p->mbox->name);
 
     g_slist_free(p->filters);
@@ -258,7 +256,7 @@ fr_apply_now_pressed(BalsaFilterRunDialog* p)
                                    _("Error when applying filters"));
     else
         balsa_information(LIBBALSA_INFORMATION_MESSAGE,
-                          _("Filter applied to \"%s\"."),
+                          _("Filter applied to “%s”."),
                           p->mbox->name);
 }
 
@@ -298,15 +296,15 @@ fr_add_pressed_func(GtkTreeModel * model, GtkTreePath * path,
     } else
         balsa_information(LIBBALSA_INFORMATION_ERROR,
                           _("The destination mailbox of "
-                            "the filter \"%s\" is \"%s\".\n"
-                            "You can't associate it with the same "
+                            "the filter “%s” is “%s”.\n"
+                            "You can’t associate it with the same "
                             "mailbox (that causes recursion)."),
                           fil->name, p->mbox->name);
 
     if (!libbalsa_mailbox_can_match(p->mbox, fil->condition))
 	balsa_information(LIBBALSA_INFORMATION_WARNING,
-			  _("The filter \"%s\" is not compatible with "
-			    "the mailbox type of \"%s\".\n"
+			  _("The filter “%s” is not compatible with "
+			    "the mailbox type of “%s”.\n"
 			    "This happens for example when you use"
 			    " regular expressions match with IMAP mailboxes,"
 			    " it is done by a very slow method; if possible, use substring match"
