@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -197,11 +195,9 @@ folder_conf_clicked_ok(FolderDialogData * fcw)
         (LIBBALSA_IMAP_SERVER(s),
          gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON
                                           (fcw->connection_limit)));
-#if !defined(ENABLE_TOUCH_UI)
     libbalsa_imap_server_enable_persistent_cache
         (LIBBALSA_IMAP_SERVER(s),
          gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fcw->enable_persistent)));
-#endif
     libbalsa_imap_server_set_use_idle
         (LIBBALSA_IMAP_SERVER(s), 
          gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fcw->use_idle)));
@@ -303,7 +299,7 @@ folder_conf_imap_node(BalsaMailboxNode *mn)
                    (_("Remote IMAP folder"),
                     GTK_WINDOW(balsa_app.main_window),
                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                    GTK_DIALOG_USE_HEADER_BAR,
+                    libbalsa_dialog_flags(),
                     mn ? _("_Update") : _("C_reate"), GTK_RESPONSE_OK,
                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                     _("_Help"), GTK_RESPONSE_HELP,
@@ -313,8 +309,7 @@ folder_conf_imap_node(BalsaMailboxNode *mn)
 #endif
     g_object_add_weak_pointer(G_OBJECT(fcw->dialog),
                               (gpointer) &fcw->dialog);
-    gtk_window_set_wmclass(GTK_WINDOW(fcw->dialog), 
-			   "folder_config_dialog", "Balsa");
+    gtk_window_set_role(GTK_WINDOW(fcw->dialog), "folder_config_dialog");
     if (mn) {
         g_object_set_data_full(G_OBJECT(mn),
                                BALSA_FOLDER_CONF_IMAP_KEY, fcw, 
@@ -340,7 +335,6 @@ folder_conf_imap_node(BalsaMailboxNode *mn)
          s 
          ? libbalsa_imap_server_get_max_connections(LIBBALSA_IMAP_SERVER(s))
          : 20);
-#if !defined(ENABLE_TOUCH_UI)
     fcw->enable_persistent = 
         balsa_server_conf_add_checkbox(&fcw->bsc,
                                        _("Enable _persistent cache"));
@@ -348,7 +342,6 @@ folder_conf_imap_node(BalsaMailboxNode *mn)
        libbalsa_imap_server_has_persistent_cache(LIBBALSA_IMAP_SERVER(s)))
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fcw->enable_persistent),
                                      TRUE);
-#endif
     fcw->use_idle = 
         balsa_server_conf_add_checkbox(&fcw->bsc,
                                        _("Use IDLE command"));
@@ -416,7 +409,7 @@ folder_conf_imap_node(BalsaMailboxNode *mn)
         libbalsa_create_grid_check(_("Subscribed _folders only"), grid, r++,
                                    mn ? mn->subscribed : FALSE);
     fcw->list_inbox =
-        libbalsa_create_grid_check(_("Always show _INBOX"), grid, r++,
+        libbalsa_create_grid_check(_("Always show _Inbox"), grid, r++,
                                    mn ? mn->list_inbox : TRUE);
 
     label = libbalsa_create_grid_label(_("Pr_efix:"), grid, r);
@@ -569,7 +562,7 @@ browse_button_cb(GtkWidget * widget, SubfolderDialogData * sdd)
         gtk_dialog_new_with_buttons(_("Select parent folder"),
                                     GTK_WINDOW(sdd->dialog),
                                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     _("_Help"), GTK_RESPONSE_HELP,
                                     NULL);
@@ -645,18 +638,18 @@ subfolder_conf_clicked_ok(SubfolderDialogData * sdd)
                 (!sdd->old_parent || !*sdd->old_parent)) {
                 gchar *msg =
                     g_strdup_printf(_
-                                    ("Renaming INBOX is special!\n"
+                                    ("Renaming Inbox is special!\n"
                                      "You will create a subfolder %s in %s\n"
-                                     "containing the messages from INBOX.\n"
-                                     "INBOX and its subfolders will remain.\n"
+                                     "containing the messages from Inbox.\n"
+                                     "Inbox and its subfolders will remain.\n"
                                      "What would you like to do?"),
 folder, parent);
                 GtkWidget *ask =
                     gtk_dialog_new_with_buttons(_("Question"),
                                                 GTK_WINDOW(sdd->dialog),
                                                 GTK_DIALOG_MODAL |
-                                                GTK_DIALOG_USE_HEADER_BAR,
-                                                _("Rename INBOX"),
+                                                libbalsa_dialog_flags(),
+                                                _("Rename Inbox"),
                                                 GTK_RESPONSE_OK,
                                                 _("Cancel"),
                                                 GTK_RESPONSE_CANCEL,
@@ -801,7 +794,7 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
                    (_("Remote IMAP subfolder"), 
                     GTK_WINDOW(balsa_app.main_window),
                     GTK_DIALOG_DESTROY_WITH_PARENT | /* must NOT be modal */
-                    GTK_DIALOG_USE_HEADER_BAR,
+                    libbalsa_dialog_flags(),
                     mn ? _("_Update") : _("_Create"), GTK_RESPONSE_OK,
                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                     _("_Help"), GTK_RESPONSE_HELP,
@@ -813,8 +806,7 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
                               (gpointer) &sdd->dialog);
     /* `Enter' key => Create: */
     gtk_dialog_set_default_response(GTK_DIALOG(sdd->dialog), GTK_RESPONSE_OK);
-    gtk_window_set_wmclass(GTK_WINDOW(sdd->dialog), 
-			   "subfolder_config_dialog", "Balsa");
+    gtk_window_set_role(GTK_WINDOW(sdd->dialog), "subfolder_config_dialog");
 
     if (sdd->mbnode) {
         g_object_set_data_full(G_OBJECT(sdd->mbnode),
@@ -861,7 +853,7 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
     gtk_editable_set_editable(GTK_EDITABLE(sdd->parent_folder), FALSE);
     gtk_entry_set_text(GTK_ENTRY(sdd->parent_folder), sdd->old_parent);
 
-    button = gtk_button_new_with_mnemonic(_("_Browse..."));
+    button = gtk_button_new_with_mnemonic(_("_Browse…"));
     g_signal_connect(G_OBJECT(button), "clicked",
 		     G_CALLBACK(browse_button_cb), (gpointer) sdd);
 
@@ -901,7 +893,7 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
                 rights_str = g_string_new(std_acls[mn->mailbox->readonly ? 1 : 3]);
                 rights_str =
                     g_string_append(rights_str,
-                                    _("\nthe server does not support ACL's"));
+                                    _("\nthe server does not support ACLs"));
             } else {
                 gint n;
                 gchar **acls;
@@ -1011,8 +1003,8 @@ folder_conf_delete(BalsaMailboxNode* mbnode)
                                  GTK_MESSAGE_QUESTION,
                                  GTK_BUTTONS_OK_CANCEL,
                                  _("This will remove the folder "
-                                   "\"%s\" from the list.\n"
-                                   "You may use \"New IMAP Folder\" "
+                                   "“%s” from the list.\n"
+                                   "You may use “New IMAP Folder” "
                                    "later to add this folder again.\n"),
                                  mbnode->name);
 #if HAVE_MACOSX_DESKTOP
