@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* GENERAL NOTES:
@@ -212,14 +210,6 @@ balsa_server_conf_get_advanced_widget(BalsaServerConf *bsc, LibBalsaServer *s,
 
     box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 
-#if !defined(USE_SSL)
-    gtk_box_pack_start(GTK_BOX(box),
-                       gtk_label_new
-                       (_("Balsa was built without SSL support.\n"
-                          "Neither SSL nor TLS can be used.")),
-                       FALSE, FALSE, 0);
-#endif                          /* !defined(USE_SSL) */
-
     bsc->grid = GTK_GRID(libbalsa_create_grid());
     gtk_container_set_border_width(GTK_CONTAINER(bsc->grid), 12);
     gtk_box_pack_start(GTK_BOX(box), GTK_WIDGET(bsc->grid),
@@ -230,9 +220,6 @@ balsa_server_conf_get_advanced_widget(BalsaServerConf *bsc, LibBalsaServer *s,
     bsc->use_ssl = balsa_server_conf_add_checkbox(bsc, _("Use _SSL"));
     if(use_ssl)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bsc->use_ssl), TRUE);
-#if !defined(USE_SSL)
-    gtk_widget_set_sensitive(bsc->use_ssl, FALSE);
-#endif                          /* !defined(USE_SSL) */
 
     label =
         libbalsa_create_grid_label(_("Use _TLS:"), GTK_WIDGET(bsc->grid), 1);
@@ -251,10 +238,6 @@ balsa_server_conf_get_advanced_widget(BalsaServerConf *bsc, LibBalsaServer *s,
     gtk_widget_show_all(GTK_WIDGET(bsc->grid));
     bsc->used_rows = 2;
     gtk_widget_set_sensitive(bsc->tls_option, !use_ssl);
-#if !defined(USE_TLS)
-    gtk_widget_set_sensitive(label, FALSE);
-    gtk_widget_set_sensitive(bsc->tls_option, FALSE);
-#endif                          /* !defined(USE_TLS) */
 
     return box;
 }
@@ -392,7 +375,7 @@ mailbox_conf_delete(BalsaMailboxNode * mbnode)
     if(BALSA_IS_MAILBOX_SPECIAL(mailbox)) {
 	balsa_information(
 	    LIBBALSA_INFORMATION_ERROR,
-	    _("Mailbox \"%s\" is used by Balsa and I cannot remove it.\n"
+	    _("Mailbox “%s” is used by Balsa and I cannot remove it.\n"
 	      "If you really want to remove it, assign its function\n"
 	      "to some other mailbox."), mailbox->name);
 	return;
@@ -403,13 +386,13 @@ mailbox_conf_delete(BalsaMailboxNode * mbnode)
                                      GTK_MESSAGE_QUESTION,
                                      GTK_BUTTONS_NONE,
                                      _("This will remove the mailbox "
-                                       "\"%s\" from the list "
-                                       "of mailboxes.  "
+                                       "“%s” from the list "
+                                       "of mailboxes. "
                                        "You may also delete the disk "
                                        "file or files associated with "
                                        "this mailbox.\n"
                                        "If you do not remove the file "
-                                       "on disk you may \"Add  Mailbox\" "
+                                       "on disk you may “Add Mailbox” "
                                        "to access the mailbox again.\n"
                                        "What would you like to do?"),
                                      mailbox->name);
@@ -424,13 +407,13 @@ mailbox_conf_delete(BalsaMailboxNode * mbnode)
                                      GTK_MESSAGE_QUESTION,
                                      GTK_BUTTONS_NONE,
 	                             _("This will remove the mailbox "
-                                       "\"%s\" and all its messages "
-                                       "from your IMAP server.  "
+                                       "“%s” and all its messages "
+                                       "from your IMAP server. "
 	                               "If %s has subfolders, it will "
                                        "still appear as a node in the "
                                        "folder tree.\n"
 	                               "You may use "
-                                       "\"New IMAP subfolder\" "
+                                       "“New IMAP subfolder” "
                                        "later to add a mailbox "
                                        "with this name.\n"
 	                               "What would you like to do?"),
@@ -444,9 +427,9 @@ mailbox_conf_delete(BalsaMailboxNode * mbnode)
                                      GTK_MESSAGE_QUESTION,
                                      GTK_BUTTONS_NONE,
 	                             _("This will remove the mailbox "
-                                       "\"%s\" from the list "
+                                       "“%s” from the list "
                                        "of mailboxes.\n"
-				       "You may use \"Add Mailbox\" "
+				       "You may use “Add Mailbox” "
                                        "later to access "
                                        "this mailbox again.\n"
 			 	       "What would you like to do?"),
@@ -716,13 +699,11 @@ mailbox_conf_set_values(MailboxConfWindow *mcw)
 	    gtk_entry_set_text(GTK_ENTRY(mcw->mb_data.imap.folderpath),
 			       path);
         balsa_server_conf_set_values(&mcw->mb_data.imap.bsc, server);
-#if !defined(ENABLE_TOUCH_UI)
         if(libbalsa_imap_server_has_persistent_cache
            (LIBBALSA_IMAP_SERVER(server)))
             gtk_toggle_button_set_active
                 (GTK_TOGGLE_BUTTON(mcw->mb_data.imap.enable_persistent),
                  TRUE);
-#endif
         if(libbalsa_imap_server_has_bug(LIBBALSA_IMAP_SERVER(server),
                                         ISBUG_FETCH))
             gtk_toggle_button_set_active
@@ -747,7 +728,12 @@ mailbox_conf_set_values(MailboxConfWindow *mcw)
 static void
 check_for_blank_fields(GtkWidget *widget, MailboxConfWindow *mcw)
 {
-    gboolean sensitive = TRUE;
+    gboolean sensitive;
+
+    if (mcw == NULL || mcw->window == NULL)
+        return;
+
+    sensitive = TRUE;
 
     if (mcw->mailbox_name &&!*gtk_entry_get_text(GTK_ENTRY(mcw->mailbox_name)))
 	sensitive = FALSE;
@@ -873,12 +859,10 @@ update_imap_mailbox(MailboxConfWindow *mcw)
     libbalsa_server_set_password(server,
 				 gtk_entry_get_text(GTK_ENTRY
 						    (mcw->mb_data.imap.password)));
-#if !defined(ENABLE_TOUCH_UI)
     libbalsa_imap_server_enable_persistent_cache
         (LIBBALSA_IMAP_SERVER(server),
          gtk_toggle_button_get_active
          GTK_TOGGLE_BUTTON(mcw->mb_data.imap.enable_persistent));
-#endif
     libbalsa_imap_server_set_bug
         (LIBBALSA_IMAP_SERVER(server), ISBUG_FETCH,
          gtk_toggle_button_get_active
@@ -1171,7 +1155,7 @@ create_generic_dialog(MailboxConfWindow * mcw)
         gtk_dialog_new_with_buttons(_("Remote Mailbox Configurator"),
                                     GTK_WINDOW(balsa_app.main_window),
                                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     mcw->ok_button_name, MCW_RESPONSE,
                                     _("_Close"), GTK_RESPONSE_CLOSE,
                                     NULL);
@@ -1363,11 +1347,9 @@ create_imap_mailbox_dialog(MailboxConfWindow *mcw)
     advanced =
         balsa_server_conf_get_advanced_widget(&mcw->mb_data.imap.bsc,
                                               NULL, 1);
-#if !defined(ENABLE_TOUCH_UI)
     mcw->mb_data.imap.enable_persistent = 
         balsa_server_conf_add_checkbox(&mcw->mb_data.imap.bsc,
                                        _("Enable _persistent cache"));
-#endif
     mcw->mb_data.imap.has_bugs = 
         balsa_server_conf_add_checkbox(&mcw->mb_data.imap.bsc,
                                        _("Enable _bug workarounds"));
@@ -1408,6 +1390,12 @@ create_imap_mailbox_dialog(MailboxConfWindow *mcw)
  * grid:       the grid in which to place the widgets;
  * row:         the row of the grid in which to start.
  */
+enum {
+    IDENTITY_COMBO_BOX_ADDRESS_COLUMN = 0,
+    IDENTITY_COMBO_BOX_IDENTITY_NAME_COLUMN,
+    IDENTITY_COMBO_BOX_N_COLUMNS
+};
+
 static BalsaMailboxConfView *
 mailbox_conf_view_new_full(LibBalsaMailbox * mailbox,
                            GtkWindow * window,
@@ -1419,9 +1407,7 @@ mailbox_conf_view_new_full(LibBalsaMailbox * mailbox,
     GtkWidget *label;
     BalsaMailboxConfView *view_info;
     GtkWidget *widget;
-    GList *list;
     const gchar *identity_name;
-    gint active;
 
     view_info = g_new(BalsaMailboxConfView, 1);
     g_object_weak_ref(G_OBJECT(window), (GWeakNotify) g_free, view_info);
@@ -1431,29 +1417,18 @@ mailbox_conf_view_new_full(LibBalsaMailbox * mailbox,
     if (size_group)
         gtk_size_group_add_widget(size_group, label);
 
-    view_info->identity_combo_box = widget = gtk_combo_box_text_new();
-    if (mcw)
-        g_signal_connect(view_info->identity_combo_box, "changed",
-                         G_CALLBACK(check_for_blank_fields), mcw);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), widget);
     identity_name = libbalsa_mailbox_get_identity_name(mailbox);
-    for (list = balsa_app.identities, active = 0; list;
-         list = list->next, ++active) {
-        LibBalsaIdentity *ident = list->data;
-        gchar *name;
+    view_info->identity_combo_box = widget =
+        libbalsa_identity_combo_box(balsa_app.identities, identity_name,
+                                    G_CALLBACK(check_for_blank_fields), mcw);
+
+    gtk_label_set_mnemonic_widget(GTK_LABEL(label), widget);
 
-        name = internet_address_to_string(ident->ia, FALSE);
-        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(widget), name);
-        g_free(name);
-        if (identity_name
-            && strcmp(identity_name, ident->identity_name) == 0)
-            gtk_combo_box_set_active(GTK_COMBO_BOX(widget), active);
-    }
     gtk_widget_set_hexpand(widget, TRUE);
     gtk_grid_attach(GTK_GRID(grid), widget, 1, row, 1, 1);
+
     if (callback)
-        g_signal_connect_swapped(view_info->identity_combo_box, "changed",
-                                 callback, window);
+        g_signal_connect_swapped(widget, "changed", callback, window);
 
 #ifdef HAVE_GPGME
     {
@@ -1555,6 +1530,8 @@ mailbox_conf_view_check(BalsaMailboxConfView * view_info,
 			LibBalsaMailbox * mailbox)
 {
     gboolean changed;
+    GtkComboBox *combo_box;
+    GtkTreeIter iter;
     gint active;
 
     g_return_if_fail(LIBBALSA_IS_MAILBOX(mailbox));
@@ -1563,7 +1540,7 @@ mailbox_conf_view_check(BalsaMailboxConfView * view_info,
 
     changed = FALSE;
 
-    g_warn_if_fail(mailbox->view == NULL);
+    libbalsa_mailbox_view_free(mailbox->view);
     g_print("%s set view on %s\n", __func__, mailbox->name);
     mailbox->view = config_load_mailbox_view(mailbox->url);
     if (!mailbox->view) {
@@ -1571,13 +1548,15 @@ mailbox_conf_view_check(BalsaMailboxConfView * view_info,
 	mailbox->view = libbalsa_mailbox_view_new();
     }
 
-    active =
-        gtk_combo_box_get_active(GTK_COMBO_BOX
-                                 (view_info->identity_combo_box));
-    if (active >= 0) {
-        LibBalsaIdentity *ident =
-            g_list_nth_data(balsa_app.identities, active);
+    combo_box = GTK_COMBO_BOX(view_info->identity_combo_box);
+    if (gtk_combo_box_get_active_iter(combo_box, &iter)) {
+        GtkTreeModel *model;
+        LibBalsaIdentity *ident;
+
+        model = gtk_combo_box_get_model(combo_box);
+        gtk_tree_model_get(model, &iter, 2, &ident, -1);
         libbalsa_mailbox_set_identity_name(mailbox, ident->identity_name);
+        g_object_unref(ident);
         changed = TRUE;
     }
 
