@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -27,10 +25,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#ifdef BALSA_USE_THREADS
-#include <pthread.h>
-#endif
-
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif
@@ -53,6 +47,7 @@
 #include "information.h"
 #include "imap-server.h"
 #include "libbalsa-conf.h"
+#include "threads.h"
 
 #include "libinit_balsa/assistant_init.h"
 
@@ -61,14 +56,9 @@
 #include "libbalsa-gpgme-cb.h"
 #endif
 
-#ifdef BALSA_USE_THREADS
-#include "threads.h"
-
 /* Globals for Thread creation, messaging, pipe I/O */
-pthread_t get_mail_thread;
-pthread_t send_mail;
-pthread_mutex_t send_messages_lock;
-int checking_mail;
+GMutex send_messages_lock;
+gboolean checking_mail;
 int mail_thread_pipes[2];
 int send_thread_pipes[2];
 GIOChannel *mail_thread_msg_send;
@@ -78,9 +68,7 @@ GIOChannel *send_thread_msg_receive;
 
 static void threads_init(void);
 static void threads_destroy(void);
-#endif				/* BALSA_USE_THREADS */
 
-static gboolean balsa_init(int argc, char **argv);
 static void config_init(gboolean check_only);
 static void mailboxes_init(gboolean check_only);
 static void balsa_cleanup(void);
@@ -123,70 +111,6 @@ balsa_main_check_new_messages(gpointer data)
     return FALSE;
 }
 
-/* balsa_init:
-   FIXME - check for memory leaks.
-*/
-static gchar **remaining_args = NULL;
-static GOptionEntry option_entries[] = {
-    {"checkmail", 'c', 0, G_OPTION_ARG_NONE,
-     &(cmd_check_mail_on_startup),
-     N_("Get new mail on startup"), NULL},
-    {"compose", 'm', 0, G_OPTION_ARG_STRING, &(opt_compose_email),
-     N_("Compose a new email to EMAIL@ADDRESS"), "EMAIL@ADDRESS"},
-    {"attach", 'a', 0, G_OPTION_ARG_FILENAME_ARRAY, &(opt_attach_list),
-     N_("Attach file at URI"), "URI"},
-    {"open-mailbox", 'o', 0, G_OPTION_ARG_STRING_ARRAY,
-     &(cmd_line_open_mailboxes),
-     N_("Opens MAILBOXNAME"), N_("MAILBOXNAME")},
-    {"open-unread-mailbox", 'u', 0, G_OPTION_ARG_NONE,
-     &(cmd_open_unread_mailbox),
-     N_("Opens first unread mailbox"), NULL},
-    {"open-inbox", 'i', 0, G_OPTION_ARG_NONE,
-     &(cmd_open_inbox),
-     N_("Opens default Inbox on startup"), NULL},
-    {"get-stats", 's', 0, G_OPTION_ARG_NONE,
-     &(cmd_get_stats),
-     N_("Prints number unread and unsent messages"), NULL},
-    {"debug-pop", 'd', 0, G_OPTION_ARG_NONE, &PopDebug,
-     N_("Debug POP3 connection"), NULL},
-    {"debug-imap", 'D', 0, G_OPTION_ARG_NONE, &ImapDebug,
-     N_("Debug IMAP connection"), NULL},
-    /* last but not least a special option that collects filenames */
-    { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY,
-      &remaining_args,
-      "Special option that collects any remaining arguments for us" },
-    { NULL }
-};
-
-static gboolean
-balsa_init(int argc, char **argv)
-{
-    GError *err = NULL;
-
-    if (!gtk_init_with_args(&argc, &argv, PACKAGE, option_entries, NULL,
-                            &err)) {
-        g_print("%s\n", err->message);
-        g_print(_("Run '%s --help' to see a full list"
-                  " of available command line options.\n"), argv[0]);
-        g_error_free(err);
-        return FALSE;
-    }
-
-    if (remaining_args != NULL) {
-        gint i, num_args;
-
-        num_args = g_strv_length (remaining_args);
-        for (i = 0; i < num_args; ++i) {
-            /* process remaining_args[i] here */
-            /* we do nothing for now */
-        }
-        g_strfreev (remaining_args);
-        remaining_args = NULL;
-    }
-
-    return TRUE;
-}
-
 /* check_special_mailboxes:
    check for special mailboxes. Cannot use GUI because main window is not
    initialized yet.
@@ -197,30 +121,30 @@ check_special_mailboxes(void)
     gboolean bomb = FALSE;
 
     if (balsa_app.inbox == NULL) {
-	g_warning(_("Balsa cannot open your \"%s\" mailbox."), _("Inbox"));
+	g_warning(_("Balsa cannot open your “%s” mailbox."), _("Inbox"));
 	bomb = TRUE;
     }
 
     if (balsa_app.outbox == NULL) {
-	g_warning(_("Balsa cannot open your \"%s\" mailbox."),
+	g_warning(_("Balsa cannot open your “%s” mailbox."),
 		  _("Outbox"));
 	bomb = TRUE;
     }
 
     if (balsa_app.sentbox == NULL) {
-	g_warning(_("Balsa cannot open your \"%s\" mailbox."),
+	g_warning(_("Balsa cannot open your “%s” mailbox."),
 		  _("Sentbox"));
 	bomb = TRUE;
     }
 
     if (balsa_app.draftbox == NULL) {
-	g_warning(_("Balsa cannot open your \"%s\" mailbox."),
+	g_warning(_("Balsa cannot open your “%s” mailbox."),
 		  _("Draftbox"));
 	bomb = TRUE;
     }
 
     if (balsa_app.trash == NULL) {
-	g_warning(_("Balsa cannot open your \"%s\" mailbox."), _("Trash"));
+	g_warning(_("Balsa cannot open your “%s” mailbox."), _("Trash"));
 	bomb = TRUE;
     }
 
@@ -248,14 +172,12 @@ mailboxes_init(gboolean check_only)
     }
 }
 
-#ifdef BALSA_USE_THREADS
-
-pthread_mutex_t checking_mail_lock = PTHREAD_MUTEX_INITIALIZER;
+GMutex checking_mail_lock;
 
 static void
 threads_init(void)
 {
-    pthread_mutex_init(&send_messages_lock, NULL);
+    g_mutex_init(&send_messages_lock);
     if (pipe(mail_thread_pipes) < 0) {
 	g_log("BALSA Init", G_LOG_LEVEL_DEBUG,
 	      "Error opening pipes.\n");
@@ -282,12 +204,10 @@ threads_init(void)
 static void
 threads_destroy(void)
 {
-    pthread_mutex_destroy(&checking_mail_lock);
-    pthread_mutex_destroy(&send_messages_lock);
+    g_mutex_clear(&checking_mail_lock);
+    g_mutex_clear(&send_messages_lock);
 }
 
-#endif				/* BALSA_USE_THREADS */
-
 /* initial_open_mailboxes:
    open mailboxes on startup if requested so.
    This is an idle handler. Be sure to use gdk_threads_{enter/leave}
@@ -473,14 +393,12 @@ periodic_expunge_cb(void)
 {
     GSList *list = NULL, *l;
 
-#if !defined(ENABLE_TOUCH_UI)
     /* should we enforce expunging now and then? Perhaps not... */
     if(!balsa_app.expunge_auto) return TRUE;
-#endif
 
     gdk_threads_enter();
     libbalsa_information(LIBBALSA_INFORMATION_DEBUG,
-                         _("Compressing mail folders..."));
+                         _("Compressing mail folders…"));
     gtk_tree_model_foreach(GTK_TREE_MODEL(balsa_app.mblist_tree_store),
 			   (GtkTreeModelForeachFunc)mbnode_expunge_func,
 			   &list);
@@ -628,20 +546,14 @@ real_main(int argc, char *argv[])
     setlocale(LC_ALL, "");
 #endif
 
-#ifdef BALSA_USE_THREADS
     /* initiate thread mutexs, variables */
     threads_init();
-#endif
 
 #ifdef HAVE_RUBRICA
     /* initialise libxml */
     LIBXML_TEST_VERSION
 #endif
 
-    /* FIXME: do we need to allow a non-GUI mode? */
-    if (!balsa_init(argc, argv))
-        return 0;
-
 #ifdef HAVE_GPGME
     /* initialise the gpgme library and set the callback funcs */
     libbalsa_gpgme_init(lb_gpgme_passphrase, lb_gpgme_select_key,
@@ -679,11 +591,12 @@ real_main(int argc, char *argv[])
     config_load_sections();
     mailboxes_init(cmd_get_stats);
 
-    if(cmd_get_stats) {
+    if (cmd_get_stats) {
         long unread, unsent;
         balsa_get_stats(&unread, &unsent);
         printf("Unread: %ld Unsent: %ld\n", unread, unsent);
-        return(0);
+        g_application_quit(G_APPLICATION(balsa_app.application));
+        return 0;
     }
 
 #ifdef HAVE_GPGME
@@ -695,9 +608,8 @@ real_main(int argc, char *argv[])
 
     balsa_check_open_compose_window();
 
-    gtk_widget_show(window);
-
     g_idle_add((GSourceFunc) scan_mailboxes_idle_cb, NULL);
+    g_idle_add((GSourceFunc) balsa_window_fix_paned, balsa_app.main_window);
     g_timeout_add_seconds(1801, (GSourceFunc) periodic_expunge_cb, NULL);
 
     if (cmd_check_mail_on_startup || balsa_app.check_mail_upon_startup)
@@ -712,9 +624,8 @@ real_main(int argc, char *argv[])
     balsa_cleanup();
     accel_map_save();
 
-#ifdef BALSA_USE_THREADS
     threads_destroy();
-#endif
+
     libbalsa_imap_server_close_all_connections();
     return 0;
 }
@@ -722,40 +633,55 @@ real_main(int argc, char *argv[])
 static void
 balsa_cleanup(void)
 {
-#ifdef BALSA_USE_THREADS
-    /* move threads shutdown to separate routine?
-       There are actually many things to do, e.g. threads should not
-       be started after this point.
-    */
-    pthread_mutex_lock(&checking_mail_lock);
-    if(checking_mail) {
-        /* We want to quit but there is a checking thread active.
-           The alternatives are to:
-           a. wait for the checking thread to finish - but it could be
-           time consuming.
-           b. send cancel signal to it.
-        */
-        pthread_cancel(get_mail_thread);
-        printf("Mail check thread cancelled. I know it is rough.\n");
-        sleep(1);
-    }
-    pthread_mutex_unlock(&checking_mail_lock);
-#endif
     balsa_app_destroy();
 
     libbalsa_conf_drop_all();
 }
 
-static int
-handle_remote(int argc, char **argv,
+/*
+ * Parse command line options
+ */
+static gint
+parse_options(int                       argc,
+              char                   ** argv,
               GApplicationCommandLine * command_line)
 {
-    gboolean help;
-    GOptionContext *context;
-    GOptionEntry help_entries[] = {
-        {"help", '?', 0, G_OPTION_ARG_NONE, &help, NULL, NULL},
+    static gboolean help;
+    static gboolean version;
+    static gchar **remaining_args;
+    static GOptionEntry option_entries[] = {
+        {"checkmail", 'c', 0, G_OPTION_ARG_NONE,
+         &(cmd_check_mail_on_startup),
+         N_("Get new mail on start-up"), NULL},
+        {"compose", 'm', 0, G_OPTION_ARG_STRING, &(opt_compose_email),
+         N_("Compose a new email to EMAIL@ADDRESS"), "EMAIL@ADDRESS"},
+        {"attach", 'a', 0, G_OPTION_ARG_FILENAME_ARRAY, &(opt_attach_list),
+         N_("Attach file at URI"), "URI"},
+        {"open-mailbox", 'o', 0, G_OPTION_ARG_STRING_ARRAY,
+         &(cmd_line_open_mailboxes),
+         N_("Opens MAILBOXNAME"), N_("MAILBOXNAME")},
+        {"open-unread-mailbox", 'u', 0, G_OPTION_ARG_NONE,
+         &(cmd_open_unread_mailbox),
+         N_("Opens first unread mailbox"), NULL},
+        {"open-inbox", 'i', 0, G_OPTION_ARG_NONE,
+         &(cmd_open_inbox),
+         N_("Opens default Inbox on start-up"), NULL},
+        {"get-stats", 's', 0, G_OPTION_ARG_NONE,
+         &(cmd_get_stats),
+         N_("Prints number unread and unsent messages"), NULL},
+        {"debug-pop", 'd', 0, G_OPTION_ARG_NONE, &PopDebug,
+         N_("Debug POP3 connection"), NULL},
+        {"debug-imap", 'D', 0, G_OPTION_ARG_NONE, &ImapDebug,
+         N_("Debug IMAP connection"), NULL},
+        {"help", 'h', 0, G_OPTION_ARG_NONE, &help, N_("Show help options"), NULL},
+        {"version", 'v', 0, G_OPTION_ARG_NONE, &version, N_("Show version"), NULL},
+        /* last but not least a special option that collects filenames */
+        {G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY,
+         &remaining_args,
+         "Special option that collects any remaining arguments for us"},
         {NULL}
     };
+    GOptionContext *context;
     gboolean rc;
     GError *error;
     gint status = 0;
@@ -767,21 +693,22 @@ handle_remote(int argc, char **argv,
      * calls exit() after printing help, which is not what we want to
      * happen in the primary instance. */
     g_option_context_set_help_enabled(context, FALSE);
-    g_option_context_add_main_entries(context, help_entries, NULL);
 
-    error = NULL;
-    help = FALSE;
     cmd_check_mail_on_startup = FALSE;
     cmd_get_stats = FALSE;
     cmd_open_unread_mailbox = FALSE;
     cmd_open_inbox = FALSE;
+    help = FALSE;
+    version = FALSE;
+    remaining_args = NULL;
+    error = NULL;
 
     rc = g_option_context_parse(context, &argc, &argv, &error);
-    /* We offer --help and -? as help options;
-     * GOptionContext promises --help and -h, but -h causes an error.
-     * If we got an error, we check to see if it was caused by -h,
+    /* We offer the usual --help and -h as help options, but we should
+     * also support the legacy "-?".
+     * If we got an error, we check to see if it was caused by -?,
      * and if so, honor it: */
-    if (!rc && strcmp(*++argv, "-h") == 0) {
+    if (!rc && strcmp(*++argv, "-?") == 0) {
         rc = help = TRUE;
         g_error_free(error);
     }
@@ -798,7 +725,36 @@ handle_remote(int argc, char **argv,
         text = g_option_context_get_help(context, FALSE, NULL);
         g_application_command_line_print(command_line, "%s", text);
         g_free(text);
-    } else if (cmd_get_stats) {
+        status = 2;
+    } else if (version) {
+        g_application_command_line_print(command_line,
+                                         "Balsa email client %s\n",
+                                         BALSA_VERSION);
+        status = 2;
+    }
+
+    if (remaining_args != NULL) {
+        gint i, num_args;
+
+        num_args = g_strv_length(remaining_args);
+        for (i = 0; i < num_args; ++i) {
+            /* process remaining_args[i] here */
+            /* we do nothing for now */
+        }
+        g_strfreev(remaining_args);
+        remaining_args = NULL;
+    }
+
+    g_option_context_free(context);
+
+    return status;
+}
+
+static void
+handle_remote(int argc, char **argv,
+              GApplicationCommandLine * command_line)
+{
+    if (cmd_get_stats) {
         glong unread, unsent;
 
         balsa_get_stats(&unread, &unsent);
@@ -827,10 +783,6 @@ handle_remote(int argc, char **argv,
 
         gdk_threads_leave();
     }
-
-    g_option_context_free(context);
-
-    return status;
 }
 
 static int
@@ -850,14 +802,18 @@ command_line_cb(GApplication            * application,
 
     /* The signal is emitted when the GApplication is run, but is always
      * handled by the primary instance of Balsa. */
-    if (g_application_command_line_get_is_remote(command_line)) {
-        /* A remote instance caused the emission; skip start-up, just
-         * handle the command line. */
-        status = handle_remote(argc, argv, command_line);
-    } else {
-        /* This is the primary instance; start up as usual. */
-        status = real_main(argc, argv);
-    }
+    status = parse_options(argc, argv, command_line);
+    if (status == 0) {
+        if (g_application_command_line_get_is_remote(command_line)) {
+            /* A remote instance caused the emission; skip start-up, just
+             * handle the command line. */
+            handle_remote(argc, argv, command_line);
+        } else {
+            /* This is the primary instance; start up as usual. */
+            status = real_main(argc, argv);
+        }
+    } else if (status == 2) /* handled a "help" or "version" request */
+        status = 0;
 
     g_free(argv);
     g_strfreev(args);
@@ -871,6 +827,12 @@ main(int argc, char **argv)
     GtkApplication *application;
     int status;
 
+# if defined(USE_WEBKIT2)
+    /* temporary fix to avoid some webkit warnings, if the user has not
+     * set it: */
+    g_setenv("WEBKIT_DISABLE_COMPOSITING_MODE", "1", FALSE);
+#endif                          /* defined(USE_WEBKIT2) */
+
     balsa_app.application = application =
         gtk_application_new("org.desktop.Balsa",
                             G_APPLICATION_HANDLES_COMMAND_LINE);
