@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -73,7 +71,7 @@ mw_set_enabled(MessageWindow * mw, const gchar * action_name,
     if (action)
         g_simple_action_set_enabled(G_SIMPLE_ACTION(action), enabled);
     else
-        g_print("%s action \"%s\" not found\n", __func__, action_name);
+        g_print("%s action “%s” not found\n", __func__, action_name);
 }
 
 /*
@@ -90,7 +88,7 @@ mw_set_active(MessageWindow * mw,
     if (action)
         g_action_change_state(action, g_variant_new_boolean(state));
     else
-        g_print("%s action \"%s\" not found\n", __func__, action_name);
+        g_print("%s action “%s” not found\n", __func__, action_name);
 }
 
 /*
@@ -139,19 +137,6 @@ message_window_idle_handler(MessageWindow * mw)
 
 /* Standard buttons; "" means a separator. */
 static const BalsaToolbarEntry message_toolbar[] = {
-#if defined(ENABLE_TOUCH_UI)
-    BALSA_PIXMAP_NEXT_UNREAD,
-    "",
-    BALSA_PIXMAP_REPLY,
-    BALSA_PIXMAP_REPLY_ALL,
-    BALSA_PIXMAP_FORWARD,
-    "",
-    "document-print",
-    "",
-    "edit-delete",
-    "",
-    "window-close"
-#else /* ENABLE_TOUCH_UI */
     { "next-unread",      BALSA_PIXMAP_NEXT_UNREAD   },
     { "", ""                                         },
     { "reply",            BALSA_PIXMAP_REPLY         },
@@ -166,7 +151,6 @@ static const BalsaToolbarEntry message_toolbar[] = {
     { "print",           "document-print"            },
     { "", ""                                         },
     { "move-to-trash",   "edit-delete"               }
-#endif /* ENEBLE_TOUCH_UI */
 };
 
 /* Optional extra buttons */
@@ -280,7 +264,7 @@ mw_header_change_state(GSimpleAction * action,
     else if (strcmp(value, "all") == 0)
         sh = HEADERS_ALL;
     else {
-        g_print("%s unknown value \"%s\"\n", __func__, value);
+        g_print("%s unknown value “%s”\n", __func__, value);
         return;
     }
 
@@ -535,15 +519,18 @@ size_alloc_cb(GtkWidget * window, GtkAllocation * alloc)
 {
     GdkWindow *gdk_window;
 
-    if (!(gdk_window = gtk_widget_get_window(window)))
+    gdk_window = gtk_widget_get_window(window);
+    if (gdk_window == NULL)
         return;
 
-    if (!(balsa_app.message_window_maximized =
-          (gdk_window_get_state(gdk_window)
-           & GDK_WINDOW_STATE_MAXIMIZED))) {
-        balsa_app.message_window_height = alloc->height;
-        balsa_app.message_window_width = alloc->width;
-    }
+    balsa_app.message_window_maximized =
+        (gdk_window_get_state(gdk_window) &
+         (GDK_WINDOW_STATE_MAXIMIZED | GDK_WINDOW_STATE_FULLSCREEN)) != 0;
+
+    if (!balsa_app.message_window_maximized)
+        gtk_window_get_size(GTK_WINDOW(window),
+                            & balsa_app.message_window_width,
+                            & balsa_app.message_window_height);
 }
 
 static void
@@ -880,7 +867,7 @@ message_window_new(LibBalsaMailbox * mailbox, guint msgno)
     mw->toolbar = balsa_toolbar_new(model, G_ACTION_MAP(window));
     gtk_box_pack_start(GTK_BOX(vbox), mw->toolbar, FALSE, FALSE, 0);
 
-    gtk_window_set_wmclass(GTK_WINDOW(window), "message", "Balsa");
+    gtk_window_set_role(GTK_WINDOW(window), "message");
 
     g_signal_connect(G_OBJECT(window), "destroy",
 		     G_CALLBACK(destroy_message_window), mw);
