@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -39,10 +37,7 @@
 #include "filter-funcs.h"
 #include "mailbox-filter.h"
 #include "libbalsa-conf.h"
-
-#ifdef BALSA_USE_THREADS
 #include "threads.h"
-#endif
 
 #if ENABLE_ESMTP
 #include "smtp-server.h"
@@ -154,18 +149,11 @@ load_toolbars(void)
 
    WARNING: may destroy mailbox.
 */
-#if defined(ENABLE_TOUCH_UI)
-#define INBOX_NAME   "In"
-#define SENTBOX_NAME "Sent"
-#define DRAFTS_NAME  "Drafts"
-#define OUTBOX_NAME  "Out"
-#else
 #define INBOX_NAME   "Inbox"
 #define SENTBOX_NAME "Sentbox"
 #define DRAFTS_NAME  "Draftbox"
 #define OUTBOX_NAME  "Outbox"
-#endif /* ENABLE_TOUCH_UI */
-#define TRASH_NAME "Trash"
+#define TRASH_NAME   "Trash"
 
 static void
 sr_special_notify(gpointer data, GObject * mailbox)
@@ -386,7 +374,6 @@ static void
 pop3_progress_notify(LibBalsaMailbox* mailbox, int msg_type, int prog, int tot,
                      const char* msg)
 {
-#ifdef BALSA_USE_THREADS
     MailThreadMessage *message;
 
     message = g_new(MailThreadMessage, 1);
@@ -404,11 +391,6 @@ pop3_progress_notify(LibBalsaMailbox* mailbox, int msg_type, int prog, int tot,
     if (write(mail_thread_pipes[1], (void *) &message, sizeof(void *))
         != sizeof(void *))
         g_warning("pipe error");
-#else
-    while(gtk_events_pending())
-        gtk_main_iteration_do(FALSE);
-#endif
-    /* cppcheck-suppress memleak */
 }
 
 /* Initialize the specified mailbox, creating the internal data
@@ -730,7 +712,7 @@ config_global_load(void)
                                        &def_used);
     if (!def_used)
         g_idle_add((GSourceFunc) config_warning_idle,
-                   _("The option not to recognize \"format=flowed\" "
+                   _("The option not to recognize “format=flowed” "
                      "text has been removed."));
 
     {
@@ -799,11 +781,6 @@ config_global_load(void)
     balsa_app.pgdown_percent = libbalsa_conf_get_int("PageDownPercent=50");
     if (balsa_app.pgdown_percent < 10)
 	balsa_app.pgdown_percent = 10;
-#if defined(ENABLE_TOUCH_UI)
-    balsa_app.do_file_format_check =
-        libbalsa_conf_get_bool("FileFormatCheck=true");
-    balsa_app.enable_view_filter = libbalsa_conf_get_bool("ViewFilter=false");
-#endif /* ENABLE_TOUCH_UI */
 
     balsa_app.show_main_toolbar =
         libbalsa_conf_get_bool("ShowMainWindowToolbar=true");
@@ -895,7 +872,7 @@ config_global_load(void)
     /* Spelling options ... */
     libbalsa_conf_push_group("Spelling");
 
-#if HAVE_GTKSPELL
+#if HAVE_GSPELL || HAVE_GTKSPELL
     balsa_app.spell_check_lang =
         libbalsa_conf_get_string("SpellCheckLanguage");
     balsa_app.spell_check_active =
@@ -1014,7 +991,7 @@ config_global_load(void)
                                        &def_used);
     if (!def_used)
         g_idle_add((GSourceFunc) config_warning_idle,
-                   _("The option not to send \"format=flowed\" text is now "
+                   _("The option not to send “format=flowed” text is now "
                      "on the Options menu of the compose window."));
 
     balsa_app.autoquote = 
@@ -1067,13 +1044,8 @@ config_global_load(void)
     balsa_app.root_node =
         balsa_mailbox_node_new_from_dir(balsa_app.local_mail_directory);
 
-#if defined(ENABLE_TOUCH_UI)
-     balsa_app.open_inbox_upon_startup =
-	libbalsa_conf_get_bool("OpenInboxOnStartup=true");
-#else
      balsa_app.open_inbox_upon_startup =
 	libbalsa_conf_get_bool("OpenInboxOnStartup=false");
-#endif /* ENABLE_TOUCH_UI */
     /* debugging enabled */
     balsa_app.debug = libbalsa_conf_get_bool("Debug=false");
 
@@ -1129,7 +1101,7 @@ config_global_load(void)
         if (!libbalsa_conf_get_bool("GtkUIManager")) {
             g_idle_add((GSourceFunc) config_warning_idle,
                        _("This version of Balsa uses a new user interface; "
-                         "if you have changed Balsa's keyboard accelerators, "
+                         "if you have changed Balsa’s keyboard accelerators, "
                          "you will need to set them again."));
             libbalsa_conf_set_bool("GtkUIManager", TRUE);
         }
@@ -1312,10 +1284,6 @@ config_save(void)
     libbalsa_conf_set_bool("AskBeforeSelect", balsa_app.ask_before_select);
     libbalsa_conf_set_bool("PageDownMod", balsa_app.pgdownmod);
     libbalsa_conf_set_int("PageDownPercent", balsa_app.pgdown_percent);
-#if defined(ENABLE_TOUCH_UI)
-    libbalsa_conf_set_bool("FileFormatCheck", balsa_app.do_file_format_check);
-    libbalsa_conf_set_bool("ViewFilter",      balsa_app.enable_view_filter);
-#endif /* ENABLE_TOUCH_UI */
 
     libbalsa_conf_set_bool("ShowMainWindowToolbar",
                            balsa_app.show_main_toolbar);
@@ -1383,7 +1351,7 @@ config_save(void)
     libbalsa_conf_remove_group("Spelling");
     libbalsa_conf_push_group("Spelling");
 
-#if HAVE_GTKSPELL
+#if HAVE_GSPELL || HAVE_GTKSPELL
     libbalsa_conf_set_string("SpellCheckLanguage",
                              balsa_app.spell_check_lang);
     libbalsa_conf_set_bool("SpellCheckActive", 
@@ -2080,7 +2048,7 @@ config_defclient_save(void)
     info = g_desktop_app_info_new("balsa.desktop");
     if (!info) {
         g_warning("Failed to create default application for Balsa "
-                  "for \"mailto\"");
+                  "for “mailto”");
         return;
     }
 
@@ -2088,7 +2056,7 @@ config_defclient_save(void)
     if (!g_app_info_set_as_default_for_type
         (G_APP_INFO(info), "x-scheme-handler/mailto", &err)) {
         g_warning("Failed to set Balsa as the default application "
-                  "for \"mailto\": %s", err->message);
+                  "for “mailto”: %s", err->message);
         g_error_free(err);
     }
     g_object_unref(info);
