@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __BALSA_SENDMSG_H__
@@ -26,14 +24,12 @@
 # error "Include config.h before this file."
 #endif
 
-#ifdef __cplusplus
-extern "C" {
-#endif				/* __cplusplus */
-
 #include "libbalsa.h"
 #include "address-view.h"
 #include "toolbar-factory.h"
 
+G_BEGIN_DECLS
+
     typedef enum {
        SEND_NORMAL,            /* initialized by Compose */
        SEND_REPLY,             /* by Reply               */
@@ -50,11 +46,8 @@ extern "C" {
         SENDMSG_STATE_AUTO_SAVED
     } SendmsgState;
 
-#if defined(ENABLE_TOUCH_UI)
-#define VIEW_MENU_LENGTH 4
-#else
 #define VIEW_MENU_LENGTH 5
-#endif
+
     typedef struct _BalsaSendmsg BalsaSendmsg;
 
     struct _BalsaSendmsg {
@@ -62,9 +55,7 @@ extern "C" {
 	GtkWidget *toolbar;
         LibBalsaAddressView *recipient_view, *replyto_view;
 	GtkWidget *from[2], *recipients[2], *subject[2], *fcc[2];
-#if !defined(ENABLE_TOUCH_UI)
 	GtkWidget *replyto[2];
-#endif                          /* ENABLE_TOUCH_UI */
 	GtkWidget *tree_view;
         gchar *in_reply_to;
         GList *references;
@@ -114,7 +105,6 @@ extern "C" {
         GtkTextMark *insert_mark;
 
         GtkWidget *paned;
-        GtkSizeGroup *size_group;
         gboolean ready_to_send;
     };
 
@@ -151,7 +141,6 @@ extern "C" {
 
 #define SENDMSG_WINDOW_QUIT_ON_CLOSE(bsmsg) ((bsmsg)->quit_on_close=TRUE)
 
-#ifdef __cplusplus
-}
-#endif				/* __cplusplus */
+G_END_DECLS
+
 #endif				/* __BALSA_SENDMSG_H__ */
