@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -27,21 +25,12 @@
 #include <enchant.h>
 #include <glib/gi18n.h>
 
-#if !USE_GREGEX
-#  ifdef HAVE_PCRE
-#    include <pcreposix.h>
-#  else
-#    include <sys/types.h>
-#    include <regex.h>
-#  endif
-#endif                          /* USE_GREGEX */
-
 #include "balsa-app.h"
 #include "quote-color.h"
 #include "balsa-icons.h"
 
 #if HAVE_GTKSOURCEVIEW
-#include <gtksourceview/gtksourcebuffer.h>
+#include <gtksourceview/gtksource.h>
 #endif                          /* HAVE_GTKSOURCEVIEW */
 
 #define BALSA_SPELL_CHECK_PADDING 6
@@ -552,11 +541,7 @@ done_cb(GtkButton * button, gpointer data)
  * dictionary to do the checking.
  * */
 
-#if USE_GREGEX
 static GRegex *quoted_rex;
-#else                           /* USE_GREGEX */
-static regex_t quoted_rex;
-#endif                          /* USE_GREGEX */
 static gboolean quoted_rex_compiled = FALSE;
 
 void
@@ -632,7 +617,6 @@ balsa_spell_check_start(BalsaSpellCheck * spell_check)
      * balsa_app.quote_regex may change, so compile it new every
      * time!)
      */
-#if USE_GREGEX
     if (quoted_rex_compiled)
         g_regex_unref(quoted_rex);
     quoted_rex = balsa_quote_regex_new();
@@ -640,17 +624,6 @@ balsa_spell_check_start(BalsaSpellCheck * spell_check)
         quoted_rex_compiled = FALSE;
     else
         quoted_rex_compiled = TRUE;
-#else                           /* USE_GREGEX */
-    if (quoted_rex_compiled)
-        regfree(&quoted_rex);
-    if (regcomp(&quoted_rex, balsa_app.quote_regex, REG_EXTENDED)) {
-        balsa_information(LIBBALSA_INFORMATION_ERROR,
-                          _("BalsaSpellCheck: Quoted text "
-                            "regular expression compilation failed\n"));
-        quoted_rex_compiled = FALSE;
-    } else
-        quoted_rex_compiled = TRUE;
-#endif                          /* USE_GREGEX */
 
     spell_check->end_iter = start;
 
@@ -868,11 +841,7 @@ balsa_spell_check_destroy(GObject * object)
     }
 
     if (quoted_rex_compiled) {
-#if USE_GREGEX
         g_regex_unref(quoted_rex);
-#else                           /* USE_GREGEX */
-        regfree(&quoted_rex);
-#endif                          /* USE_GREGEX */
         quoted_rex_compiled = FALSE;
     }
 
@@ -1005,7 +974,7 @@ check_word(BalsaSpellCheck * spell_check)
 
 	if (balsa_app.debug)
 	    balsa_information(LIBBALSA_INFORMATION_DEBUG,
-			      " ...incorrect.\n");
+			      " …incorrect.\n");
 
 	spell_check->suggestions =
 	    enchant_dict_suggest(spell_check->dict, word, -1, &n_suggs);
@@ -1013,7 +982,7 @@ check_word(BalsaSpellCheck * spell_check)
     } else {
 	if (balsa_app.debug)
 	    balsa_information(LIBBALSA_INFORMATION_DEBUG,
-			      " ...correct.\n");
+			      " …correct.\n");
     }
 
     g_free(word);
@@ -1108,13 +1077,8 @@ next_word(BalsaSpellCheck * spell_check)
                                         &line_end, FALSE);
             skip_sig = (!balsa_app.check_sig
                         && strcmp(line, "-- \n") == 0);
-#if USE_GREGEX
             skip_quoted = (!balsa_app.check_quoted && quoted_rex_compiled
                            && is_a_quote(line, quoted_rex));
-#else                           /* USE_GREGEX */
-            skip_quoted = (!balsa_app.check_quoted && quoted_rex_compiled
-                           && is_a_quote(line, &quoted_rex));
-#endif                          /* USE_GREGEX */
             g_free(line);
 
             if (skip_sig)
