@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -206,7 +204,7 @@ store_address_dialog(StoreAddressInfo * info)
         gtk_dialog_new_with_buttons(_("Store Address"),
                                     GTK_WINDOW(balsa_app.main_window),
                                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     _("_OK"), GTK_RESPONSE_OK,
                                     NULL);
@@ -219,6 +217,7 @@ store_address_dialog(StoreAddressInfo * info)
     libbalsa_macosx_menu_for_parent(dialog, GTK_WINDOW(balsa_app.main_window));
 #endif
 
+    info->current_address_book = balsa_app.default_address_book;
     if (balsa_app.address_book_list && balsa_app.address_book_list->next) {
         /* User has more than one address book, so show the options */
         frame = store_address_book_frame(info);
@@ -244,7 +243,7 @@ store_address_from_entries(GtkWindow *window, StoreAddressInfo * info,
 
     if (info->current_address_book == NULL) {
         balsa_information(LIBBALSA_INFORMATION_WARNING,
-    		      _("No address book selected...."));
+    		      _("No address book selected…"));
         return FALSE;
     }
 
@@ -280,8 +279,11 @@ store_address_from_entries(GtkWindow *window, StoreAddressInfo * info,
 static GtkWidget *
 store_address_book_frame(StoreAddressInfo * info)
 {
+    guint default_ab_offset = 0;
     GtkWidget *hbox;
     GtkWidget *combo_box;
+    guint off;
+    GList *ab_list;
 
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
@@ -292,32 +294,24 @@ store_address_book_frame(StoreAddressInfo * info)
     g_signal_connect(combo_box, "changed",
                      G_CALLBACK(store_address_book_menu_cb), info);
 
-    if (balsa_app.address_book_list) {
-        guint default_ab_offset = 0, off;
-        GList *ab_list;
+    /* NOTE: we have to store the default address book index and
+       call set_active() after all books are added to the list or
+       gtk-2.10.4 will lose the setting. */
+    for (off = 0, ab_list = balsa_app.address_book_list;
+         ab_list != NULL;
+         off++, ab_list = ab_list->next) {
+        LibBalsaAddressBook *address_book;
 
-	info->current_address_book = balsa_app.default_address_book;
+        address_book = LIBBALSA_ADDRESS_BOOK(ab_list->data);
+        if (info->current_address_book == NULL)
+            info->current_address_book = address_book;
 
-	/* NOTE: we have to store the default address book index and
-           call set_active() after all books are added to the list or
-           gtk-2.10.4 will lose the setting. */
-	for(off=0, ab_list = balsa_app.address_book_list;
-            ab_list;
-            off++, ab_list = ab_list->next) {
-            LibBalsaAddressBook *address_book;
-
-	    address_book = LIBBALSA_ADDRESS_BOOK(ab_list->data);
-	    if (info->current_address_book == NULL)
-		info->current_address_book = address_book;
-
-	    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo_box),
-                                           address_book->name);
-	    if (address_book == balsa_app.default_address_book)
-                default_ab_offset = off;
-	}
-        gtk_combo_box_set_active(GTK_COMBO_BOX(combo_box),
-                                 default_ab_offset);
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo_box),
+                                       address_book->name);
+        if (address_book == balsa_app.default_address_book)
+            default_ab_offset = off;
     }
+    gtk_combo_box_set_active(GTK_COMBO_BOX(combo_box), default_ab_offset);
 
     gtk_box_pack_start(GTK_BOX(hbox), combo_box, TRUE, TRUE, 0);
 
@@ -341,8 +335,8 @@ store_address_note_frame(StoreAddressInfo *info)
 	if (message->headers) {
 	    store_address_add_list(info, _("From: "), message->headers->from);
 	    store_address_add_list(info, _("To: "), message->headers->to_list);
-	    store_address_add_list(info, _("Cc: "), message->headers->cc_list);
-	    store_address_add_list(info, _("Bcc: "), message->headers->bcc_list);
+	    store_address_add_list(info, _("CC: "), message->headers->cc_list);
+	    store_address_add_list(info, _("BCC: "), message->headers->bcc_list);
 	}
     }
 
