@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -169,7 +167,7 @@ button_data toolbar_buttons[]={
     {BALSA_PIXMAP_MARK_ALL,      N_("Mark all"),        FALSE},
     {BALSA_PIXMAP_SHOW_HEADERS,  N_("All\nheaders"),    FALSE},
     {"gtk-cancel",           N_("Reset\nFilter"),   FALSE},
-    {BALSA_PIXMAP_SHOW_PREVIEW,  N_("Msg Preview"),     FALSE},
+    {BALSA_PIXMAP_SHOW_PREVIEW,  N_("Message Preview"),     FALSE},
 #ifdef HAVE_GPGME
     {BALSA_PIXMAP_GPG_SIGN,      N_("Sign"),            FALSE},
     {BALSA_PIXMAP_GPG_ENCRYPT,   N_("Encrypt"),         FALSE},
@@ -404,7 +402,7 @@ balsa_toolbar_model_insert_icon(BalsaToolbarModel * model, gchar * icon,
         else
             g_array_append_val(model->current, entry);
     } else
-        g_warning(_("Unknown toolbar icon \"%s\""), icon);
+        g_warning(_("Unknown toolbar icon “%s”"), icon);
 }
 
 /* Remove all icons from the BalsaToolbarModel.
@@ -663,6 +661,7 @@ tm_remove_underscore(const gchar * text)
     return r;
 }
 
+#if !GTK_CHECK_VERSION(3, 22, 0)
 /* If the menu is popped up in response to a keystroke, center it
  * immediately below the toolbar.
  */
@@ -698,13 +697,16 @@ tm_popup_position_func(GtkMenu * menu, gint * x, gint * y,
 
     *push_in = FALSE;
 }
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
 
 static gboolean
 tm_do_popup_menu(GtkWidget * toolbar, GdkEventButton * event,
                  toolbar_info * info)
 {
     GtkWidget *menu;
+#if !GTK_CHECK_VERSION(3, 22, 0)
     int button, event_time;
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
     guint i;
     GSList *group = NULL;
     GtkToolbarStyle default_style = tm_default_style();
@@ -781,7 +783,7 @@ tm_do_popup_menu(GtkWidget * toolbar, GdkEventButton * event,
         gtk_menu_shell_append(GTK_MENU_SHELL(menu),
                               gtk_separator_menu_item_new());
         item =
-            gtk_menu_item_new_with_mnemonic(_("_Customize Toolbars..."));
+            gtk_menu_item_new_with_mnemonic(_("_Customize Toolbars…"));
         g_signal_connect(item, "activate", G_CALLBACK(customize_dialog_cb),
                          gtk_widget_get_toplevel(toolbar));
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
@@ -794,6 +796,17 @@ tm_do_popup_menu(GtkWidget * toolbar, GdkEventButton * event,
 
     gtk_widget_show_all(menu);
 
+#if GTK_CHECK_VERSION(3, 22, 0)
+    gtk_menu_attach_to_widget(GTK_MENU(menu), toolbar, NULL);
+    if (event)
+        gtk_menu_popup_at_pointer(GTK_MENU(menu),
+                                  (GdkEvent *) event);
+    else
+        gtk_menu_popup_at_widget(GTK_MENU(menu),
+                                 GTK_WIDGET(toolbar),
+                                 GDK_GRAVITY_CENTER, GDK_GRAVITY_CENTER,
+                                 NULL);
+#else                           /*GTK_CHECK_VERSION(3, 22, 0) */
     if (event) {
         button = event->button;
         event_time = event->time;
@@ -809,6 +822,7 @@ tm_do_popup_menu(GtkWidget * toolbar, GdkEventButton * event,
     else
         gtk_menu_popup(GTK_MENU(menu), NULL, NULL, tm_popup_position_func,
                        toolbar, button, event_time);
+#endif                          /*GTK_CHECK_VERSION(3, 22, 0) */
 
     return TRUE;
 }
