@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
@@ -138,7 +136,7 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
         gtk_dialog_new_with_buttons(_("Customize Toolbars"),
                                     GTK_WINDOW(active_window),
                                     GTK_DIALOG_DESTROY_WITH_PARENT |
-                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    libbalsa_dialog_flags(),
                                     _("_Close"), GTK_RESPONSE_CLOSE,
                                     _("_Help"),  GTK_RESPONSE_HELP,
                                     NULL);
@@ -155,8 +153,7 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
         gtk_dialog_get_content_area(GTK_DIALOG(customize_widget));
     gtk_box_pack_start(GTK_BOX(content_area), notebook, TRUE, TRUE, 0);
 
-    gtk_window_set_wmclass(GTK_WINDOW(customize_widget), "customize",
-                           "Balsa");
+    gtk_window_set_role(GTK_WINDOW(customize_widget), "customize");
     gtk_window_set_default_size(GTK_WINDOW(customize_widget), 600, 440);
 
     /* The order of pages must be consistent with the BalsaToolbarType
@@ -436,12 +433,7 @@ create_toolbar_page(BalsaToolbarModel * model, GActionMap * map)
     gtk_box_pack_start(GTK_BOX(toolbar_ctlbox), toolbar_scroll,
                        TRUE, TRUE, 0);
 
-#if GTK_CHECK_VERSION(3, 8, 0)
     gtk_container_add(GTK_CONTAINER(toolbar_scroll), page->toolbar);
-#else                           /* GTK_CHECK_VERSION(3, 8, 0) */
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(toolbar_scroll),
-                                          page->toolbar);
-#endif                          /* GTK_CHECK_VERSION(3, 8, 0) */
 
     /* Button box */
     button_box = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
@@ -454,7 +446,7 @@ create_toolbar_page(BalsaToolbarModel * model, GActionMap * map)
     gtk_container_add(GTK_CONTAINER(button_box), page->standard_button);
 
     /* Style button */
-    style_button = gtk_button_new_with_mnemonic(_("Toolbar _style..."));
+    style_button = gtk_button_new_with_mnemonic(_("Toolbar _style…"));
     gtk_container_add(GTK_CONTAINER(button_box), style_button);
 
     /* Done with preview */
@@ -632,7 +624,7 @@ tp_page_refresh_available(ToolbarPage * page, GActionMap * map)
 
                 action = g_hash_table_lookup(legal, toolbar_buttons[item].pixmap_id);
                 if (action && !g_action_map_lookup_action(map, action))
-                    g_print("undefined action: \"%s\"\n", action);
+                    g_print("undefined action: “%s”\n", action);
             }
         }
 #endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
